import { Component, EventEmitter, HostBinding, Inject, Injectable, InjectionToken, Input, NgModule, Output } from '@angular/core';
import { CommonModule } from '@angular/common';
import { BehaviorSubject as BehaviorSubject$1 } from 'rxjs/BehaviorSubject';
import { FormBuilder, FormsModule, ReactiveFormsModule, Validators } from '@angular/forms';
import { Http } from '@angular/http';
import 'rxjs/add/operator/map';

class SimulatorState {
    constructor() {
        this.nonRelevantDataElementIds = [];
        this.endPointId = '';
        this.selectedDecisionPointId = '';
        this.selectedDecisionPointLabel = '';
        this.selectedBranchLabel = '';
    }
}

class DataElementValues {
    /**
     * @param {?} values
     */
    constructor(values) {
        this.values = values;
    }
    /**
     * @param {?} key
     * @param {?} value
     * @return {?}
     */
    addOrUpdate(key, value) {
        this.values[key] = value;
    }
    /**
     * @param {?} key
     * @return {?}
     */
    get(key) {
        return this.values[key];
    }
    /**
     * @param {?} key
     * @return {?}
     */
    delete(key) {
        return this.values.delete(key);
    }
    /**
     * @return {?}
     */
    getAll() {
        return this.values;
    }
}

class SimulatorEngineService {
    constructor() {
        this.endOfRoadReached = false;
        this.lastConditionMetBranchLevel = 1;
        this.simulatorStateChanged = new BehaviorSubject$1(new SimulatorState());
        this.dataElementValues = new Map();
        this.dataElementTexts = new Map();
    }
    /**
     * @return {?}
     */
    getAllDataElementValues() {
        return this.dataElementValues;
    }
    /**
     * @return {?}
     */
    getAllDataElementTexts() {
        return this.dataElementTexts;
    }
    /**
     * @param {?} dataElementId
     * @return {?}
     */
    getDataElementValue(dataElementId) {
        return this.dataElementValues[dataElementId];
    }
    /**
     * @param {?} dataElementId
     * @return {?}
     */
    getDataElementText(dataElementId) {
        return this.dataElementTexts[dataElementId];
    }
    /**
     * @param {?} dataElementId
     * @param {?} value
     * @param {?} text
     * @return {?}
     */
    addOrUpdateDataElement(dataElementId, value, text) {
        this.dataElementValues[dataElementId] = value;
        this.dataElementTexts[dataElementId] = text;
        this.evaluateDecisionPoints();
    }
    /**
     * @param {?} decisionPoint
     * @param {?} branchingLevel
     * @param {?=} nonRelevantDataElementIds
     * @return {?}
     */
    evaluateDecisionPoint(decisionPoint, branchingLevel, nonRelevantDataElementIds = []) {
        let /** @type {?} */ currentBranchCount = 0;
        const /** @type {?} */ totalBranchesInDecisionPoint = decisionPoint.branches.length;
        for (const /** @type {?} */ branch of decisionPoint.branches) {
            currentBranchCount++;
            let /** @type {?} */ conditionMet = false;
            if (this.endOfRoadReached) {
                break;
            }
            if (branch.compositeCondition !== undefined) {
                conditionMet = branch.compositeCondition.evaluate(new DataElementValues(this.dataElementValues));
            }
            else if (branch.condition !== undefined) {
                conditionMet = branch.condition.evaluate(new DataElementValues(this.dataElementValues));
            }
            // console.log( 'Decision Point:- ' + decisionPoint.id +  ', Branch:- ' + branch.label + ', Condition Met :- ' + conditionMet);
            if (conditionMet) {
                this.lastConditionMetBranchLevel = branchingLevel;
                if (nonRelevantDataElementIds === undefined) {
                    nonRelevantDataElementIds = new Array();
                }
                if (branch.notRelevantDataElements !== undefined) {
                    for (const /** @type {?} */ nonRelevantDataElementReference of branch.notRelevantDataElements.dataElementReferences) {
                        nonRelevantDataElementIds.push(nonRelevantDataElementReference.dataElementId);
                    }
                }
                if (branch.decisionPoints !== undefined) {
                    for (const /** @type {?} */ branchDecisionPoint of branch.decisionPoints) {
                        const /** @type {?} */ newBranchingLevel = branchingLevel + 1;
                        this.evaluateDecisionPoint(branchDecisionPoint, newBranchingLevel, nonRelevantDataElementIds);
                    }
                }
                else if (branch.endPointRef !== undefined) {
                    const /** @type {?} */ simulatorState = new SimulatorState();
                    simulatorState.endPointId = branch.endPointRef.endPointId;
                    simulatorState.nonRelevantDataElementIds = nonRelevantDataElementIds;
                    simulatorState.selectedBranchLabel = branch.label;
                    simulatorState.selectedDecisionPointId = decisionPoint.id;
                    simulatorState.selectedDecisionPointLabel = decisionPoint.label;
                    this.resetValuesOfNonRelevantDataElements(nonRelevantDataElementIds);
                    this.simulatorStateChanged.next(simulatorState);
                    this.endOfRoadReached = true;
                    break;
                }
            }
            else {
                if (currentBranchCount >= totalBranchesInDecisionPoint) {
                    this.endOfRoadReached = true;
                    const /** @type {?} */ simulatorState = new SimulatorState();
                    simulatorState.nonRelevantDataElementIds = nonRelevantDataElementIds;
                    this.resetValuesOfNonRelevantDataElements(nonRelevantDataElementIds);
                    this.simulatorStateChanged.next(simulatorState);
                    return;
                }
                else {
                    continue;
                }
            }
        }
    }
    /**
     * @param {?} nonRelevantDataElementIds
     * @return {?}
     */
    resetValuesOfNonRelevantDataElements(nonRelevantDataElementIds) {
        for (const /** @type {?} */ nonRelevantDataElementId of nonRelevantDataElementIds) {
            let /** @type {?} */ defaultValue;
            for (const /** @type {?} */ dataElement of this.template.dataElements) {
                if (dataElement.id === nonRelevantDataElementId) {
                    defaultValue = dataElement.defaultValue;
                    break;
                }
            }
            this.dataElementValues[nonRelevantDataElementId] = defaultValue;
        }
    }
    /**
     * @param {?} elementId
     * @param {?} decisionPoint
     * @param {?} branchingLevel
     * @return {?}
     */
    evaluateComputedElementDecisionPoint(elementId, decisionPoint, branchingLevel) {
        let /** @type {?} */ currentBranchCount = 0;
        const /** @type {?} */ totalBranchesInDecisionPoint = decisionPoint.branches.length;
        for (const /** @type {?} */ branch of decisionPoint.branches) {
            currentBranchCount++;
            let /** @type {?} */ conditionMet = false;
            if (this.endOfRoadReached) {
                break;
            }
            if (branch.compositeCondition !== undefined) {
                conditionMet = branch.compositeCondition.evaluate(new DataElementValues(this.dataElementValues));
            }
            else if (branch.condition !== undefined) {
                conditionMet = branch.condition.evaluate(new DataElementValues(this.dataElementValues));
            }
            if (conditionMet) {
                this.lastConditionMetBranchLevel = branchingLevel;
                if (branch.decisionPoints !== undefined) {
                    for (const /** @type {?} */ branchDecisionPoint of branch.decisionPoints) {
                        const /** @type {?} */ newBranchingLevel = branchingLevel + 1;
                        this.evaluateComputedElementDecisionPoint(elementId, branchDecisionPoint, newBranchingLevel);
                    }
                }
                else if (branch.computedValue !== undefined) {
                    this.dataElementValues[elementId] = branch.computedValue.expressionText;
                    this.endOfRoadReached = true;
                    break;
                }
            }
            else {
                if (currentBranchCount >= totalBranchesInDecisionPoint) {
                    this.endOfRoadReached = true;
                    this.dataElementValues[elementId] = undefined;
                    return;
                }
                else {
                    continue;
                }
            }
        }
    }
    /**
     * @return {?}
     */
    evaluateComputedExpressions() {
        this.endOfRoadReached = false;
        for (const /** @type {?} */ element of this.template.dataElements) {
            if (element.dataElementType === 'ComputedDataElement') {
                const /** @type {?} */ computedElement = (element);
                for (const /** @type {?} */ decisionPoint of computedElement.decisionPoints) {
                    this.evaluateComputedElementDecisionPoint(element.id, decisionPoint, 1);
                    if (this.dataElementValues[element.id] === undefined && decisionPoint.defaultBranch &&
                        decisionPoint.defaultBranch.computedValue) {
                        this.dataElementValues[element.id] = decisionPoint.defaultBranch.computedValue.expressionText;
                    }
                    this.endOfRoadReached = false;
                }
            }
        }
    }
    /**
     * @return {?}
     */
    evaluateDecisionPoints() {
        console.log(this.dataElementValues);
        this.evaluateComputedExpressions();
        this.endOfRoadReached = false;
        for (const /** @type {?} */ decisionPoint of this.template.rules.decisionPoints) {
            if (this.evaluateDecisionPoint(decisionPoint, 1, new Array())) {
                break;
            }
        }
    }
    /**
     * @param {?} template
     * @return {?}
     */
    initialize(template) {
        this.template = template;
        for (const /** @type {?} */ dataElement of this.template.dataElements) {
            this.dataElementValues[dataElement.id] = dataElement.currentValue;
        }
    }
}
SimulatorEngineService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
SimulatorEngineService.ctorParameters = () => [];

class CoreModule {
    /**
     * @return {?}
     */
    static forRoot() {
        return {
            ngModule: CoreModule,
            providers: [SimulatorEngineService]
        };
    }
}
CoreModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: []
            },] },
];
/**
 * @nocollapse
 */
CoreModule.ctorParameters = () => [];

class Template {
}

class Metadata {
}

class Diagram {
}

class ArrayCheckerService {
    constructor() { }
    /**
     * @param {?} item
     * @return {?}
     */
    isArray(item) {
        return item instanceof Array;
    }
}
ArrayCheckerService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
ArrayCheckerService.ctorParameters = () => [];

class DiagramService {
    /**
     * @param {?} arrayCheckerSeviceService
     */
    constructor(arrayCheckerSeviceService) {
        this.arrayCheckerSeviceService = arrayCheckerSeviceService;
    }
    /**
     * @param {?} diagramJSON
     * @return {?}
     */
    returnDiagram(diagramJSON) {
        const /** @type {?} */ diagram = new Diagram();
        if (diagramJSON.Attr) {
            diagram.displaySequence = diagramJSON.Attr.DisplaySequence;
            diagram.keyDiagram = diagramJSON.Attr.IsKeyDiagram ? diagramJSON.Attr.IsKeyDiagram : false;
        }
        else {
            diagram.displaySequence = undefined;
            diagram.keyDiagram = false;
        }
        diagram.label = diagramJSON.Label;
        diagram.location = diagramJSON.Location;
        return diagram;
    }
    /**
     * @param {?} diagramsAsJSON
     * @return {?}
     */
    returnDiagrams(diagramsAsJSON) {
        const /** @type {?} */ diagrams = new Array();
        if (diagramsAsJSON !== undefined) {
            if (this.arrayCheckerSeviceService.isArray(diagramsAsJSON)) {
                for (const /** @type {?} */ diagram of diagramsAsJSON) {
                    diagrams.push(this.returnDiagram(diagram));
                }
            }
            else {
                diagrams.push(this.returnDiagram(diagramsAsJSON));
            }
        }
        return diagrams;
    }
}
DiagramService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
DiagramService.ctorParameters = () => [
    { type: ArrayCheckerService, },
];

const CreationServiceInjectorToken = new InjectionToken('one');

class DecisionPoint {
}

class Branch {
}

class EndPointRef {
}

class DataElementRef {
}

class NotRelevantDataElements {
}

class EqualCondition {
    /**
     * @param {?} conditionType
     */
    constructor(conditionType) {
        this.conditionType = conditionType;
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    evaluate(dataElementValues) {
        const /** @type {?} */ value = dataElementValues.get(this.conditionType.dataElementId);
        return value === this.conditionType.comparisonValue;
    }
}

class ConditionType {
}

class GreaterThanCondition {
    /**
     * @param {?} conditionType
     */
    constructor(conditionType) {
        this.conditionType = conditionType;
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    evaluate(dataElementValues) {
        const /** @type {?} */ value = (+dataElementValues.get(this.conditionType.dataElementId));
        let /** @type {?} */ comparisonValue = -1;
        if (isNaN(this.conditionType.comparisonValue)) {
            comparisonValue = (+dataElementValues.get(this.conditionType.comparisonValue));
        }
        else {
            comparisonValue = (+this.conditionType.comparisonValue);
        }
        return value > comparisonValue;
    }
}

class LessThanCondition {
    /**
     * @param {?} conditionType
     */
    constructor(conditionType) {
        this.conditionType = conditionType;
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    evaluate(dataElementValues) {
        const /** @type {?} */ value = (+dataElementValues.get(this.conditionType.dataElementId));
        let /** @type {?} */ comparisonValue = -1;
        if (isNaN(this.conditionType.comparisonValue)) {
            comparisonValue = (+dataElementValues.get(this.conditionType.comparisonValue));
        }
        else {
            comparisonValue = (+this.conditionType.comparisonValue);
        }
        return value < comparisonValue;
    }
}

class GreaterThanOrEqualsCondition {
    /**
     * @param {?} conditionType
     */
    constructor(conditionType) {
        this.conditionType = conditionType;
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    evaluate(dataElementValues) {
        const /** @type {?} */ value = (+dataElementValues.get(this.conditionType.dataElementId));
        let /** @type {?} */ comparisonValue = -1;
        if (isNaN(this.conditionType.comparisonValue)) {
            comparisonValue = (+dataElementValues.get(this.conditionType.comparisonValue));
        }
        else {
            comparisonValue = (+this.conditionType.comparisonValue);
        }
        return value >= comparisonValue;
    }
}

class LessThanOrEqualsCondition {
    /**
     * @param {?} conditionType
     */
    constructor(conditionType) {
        this.conditionType = conditionType;
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    evaluate(dataElementValues) {
        const /** @type {?} */ value = (+dataElementValues.get(this.conditionType.dataElementId));
        let /** @type {?} */ comparisonValue = -1;
        if (isNaN(this.conditionType.comparisonValue)) {
            comparisonValue = (+dataElementValues.get(this.conditionType.comparisonValue));
        }
        else {
            comparisonValue = (+this.conditionType.comparisonValue);
        }
        return value <= comparisonValue;
    }
}

class ContainsCondition {
    /**
     * @param {?} conditionType
     */
    constructor(conditionType) {
        this.conditionType = conditionType;
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    evaluate(dataElementValues) {
        let /** @type {?} */ returnValue = false;
        const /** @type {?} */ value = dataElementValues.get(this.conditionType.dataElementId);
        if (value !== undefined) {
            returnValue = value.indexOf(this.conditionType.comparisonValue) >= 0;
        }
        return returnValue;
    }
}

class AndCondition {
    constructor() {
        this.conditions = [];
        this.conditionType = 'AndCondition';
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    evaluate(dataElementValues) {
        let /** @type {?} */ returnValue = true;
        for (let /** @type {?} */ conditionCounter = 0; conditionCounter < this.conditions.length; conditionCounter++) {
            const /** @type {?} */ condition = this.conditions[conditionCounter];
            const /** @type {?} */ executedCondition = condition.evaluate(dataElementValues);
            returnValue = (!executedCondition) ? false : (returnValue && executedCondition);
            if (!returnValue) {
                break;
            }
        }
        return returnValue;
    }
}

class OrCondition {
    constructor() {
        this.conditions = [];
        this.conditionType = 'OrCondition';
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    evaluate(dataElementValues) {
        let /** @type {?} */ returnValue = false;
        for (let /** @type {?} */ conditionCounter = 0; conditionCounter < this.conditions.length; conditionCounter++) {
            const /** @type {?} */ condition = this.conditions[conditionCounter];
            const /** @type {?} */ executedCondition = condition.evaluate(dataElementValues);
            returnValue = (returnValue || executedCondition);
            if (returnValue) {
                break;
            }
        }
        return returnValue;
    }
}

class NotCondition {
    constructor() {
        this.conditions = [];
        this.conditionType = 'NotCondition';
    }
    /**
     * @param {?} dataElementValues
     * @return {?}
     */
    evaluate(dataElementValues) {
        const /** @type {?} */ results = new Array();
        for (const /** @type {?} */ condition of this.conditions) {
            results.push(condition.evaluate(dataElementValues));
        }
        return !(results[0]);
    }
}

class ConditionsCreationService {
    /**
     * @param {?} arrayCheckerService
     */
    constructor(arrayCheckerService) {
        this.arrayCheckerService = arrayCheckerService;
    }
    /**
     * @param {?} conditionJSON
     * @return {?}
     */
    returnConditionType(conditionJSON) {
        const /** @type {?} */ conditionType = new ConditionType();
        conditionType.comparisonValue = conditionJSON.Attr.ComparisonValue;
        conditionType.dataElementId = conditionJSON.Attr.DataElementId;
        return conditionType;
    }
    /**
     * @param {?} branchJSON
     * @return {?}
     */
    returnCondition(branchJSON) {
        let /** @type {?} */ condition;
        if (branchJSON.hasOwnProperty('EqualCondition')) {
            condition = new EqualCondition(this.returnConditionType(branchJSON.EqualCondition));
        }
        if (branchJSON.hasOwnProperty('GreaterThanCondition')) {
            condition = new GreaterThanCondition(this.returnConditionType(branchJSON.GreaterThanCondition));
        }
        if (branchJSON.hasOwnProperty('LessThanCondition')) {
            condition = new LessThanCondition(this.returnConditionType(branchJSON.LessThanCondition));
        }
        if (branchJSON.hasOwnProperty('GreaterThanOrEqualsCondition')) {
            condition = new GreaterThanOrEqualsCondition(this.returnConditionType(branchJSON.GreaterThanOrEqualsCondition));
        }
        if (branchJSON.hasOwnProperty('LessThanOrEqualsCondition')) {
            condition = new LessThanOrEqualsCondition(this.returnConditionType(branchJSON.LessThanOrEqualsCondition));
        }
        if (branchJSON.hasOwnProperty('ContainsCondition')) {
            condition = new ContainsCondition(this.returnConditionType(branchJSON.ContainsCondition));
        }
        return condition;
    }
    /**
     * @param {?} compositeElementJSON
     * @return {?}
     */
    isComposite(compositeElementJSON) {
        return compositeElementJSON.hasOwnProperty('AndCondition') ||
            compositeElementJSON.hasOwnProperty('OrCondition') ||
            compositeElementJSON.hasOwnProperty('NotCondition');
    }
    /**
     * @param {?} conditionIdentifier
     * @param {?} conditionJSON
     * @return {?}
     */
    returnConditionFromJSON(conditionIdentifier, conditionJSON) {
        let /** @type {?} */ condition;
        if (conditionIdentifier === 'EqualCondition') {
            condition = new EqualCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'GreaterThanCondition') {
            condition = new GreaterThanCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'LessThanCondition') {
            condition = new LessThanCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'GreaterThanOrEqualsCondition') {
            condition = new GreaterThanOrEqualsCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'LessThanOrEqualsCondition') {
            condition = new LessThanOrEqualsCondition(this.returnConditionType(conditionJSON));
        }
        if (conditionIdentifier === 'ContainsCondition') {
            condition = new ContainsCondition(this.returnConditionType(conditionJSON));
        }
        return condition;
    }
    /**
     * @param {?} conditionsJSON
     * @return {?}
     */
    returnConditions(conditionsJSON) {
        let /** @type {?} */ conditions;
        const /** @type {?} */ conditionIdentifiers = ['EqualCondition', 'GreaterThanCondition', 'LessThanCondition',
            'GreaterThanOrEqualsCondition', 'LessThanOrEqualsCondition', 'ContainsCondition'];
        for (const /** @type {?} */ conditionIdentifier of conditionIdentifiers) {
            const /** @type {?} */ conditionJSON = conditionsJSON[conditionIdentifier];
            if (conditionJSON !== undefined) {
                conditions = new Array();
                if (this.arrayCheckerService.isArray(conditionJSON)) {
                    for (const /** @type {?} */ jsonValue of conditionJSON) {
                        conditions.push(this.returnConditionFromJSON(conditionIdentifier, jsonValue));
                    }
                }
                else {
                    conditions.push(this.returnConditionFromJSON(conditionIdentifier, conditionJSON));
                }
            }
        }
        return conditions;
    }
    /**
     * @param {?} compositeElementJSON
     * @return {?}
     */
    isHybrid(compositeElementJSON) {
        const /** @type {?} */ compositeExists = compositeElementJSON.hasOwnProperty('AndCondition') ||
            compositeElementJSON.hasOwnProperty('OrCondition') ||
            compositeElementJSON.hasOwnProperty('NotCondition');
        const /** @type {?} */ primitiveExists = compositeElementJSON.hasOwnProperty('EqualCondition') ||
            compositeElementJSON.hasOwnProperty('GreaterThanCondition') ||
            compositeElementJSON.hasOwnProperty('LessThanCondition') ||
            compositeElementJSON.hasOwnProperty('GreaterThanOrEqualsCondition') ||
            compositeElementJSON.hasOwnProperty('LessThanOrEqualsCondition') ||
            compositeElementJSON.hasOwnProperty('ContainsCondition');
        return compositeExists && primitiveExists;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    returnCompositeCondition(data) {
        if (!this.isComposite(data)) {
            return;
        }
        let /** @type {?} */ compositeConditionJSON;
        let /** @type {?} */ compositeCondition;
        if (data.hasOwnProperty('AndCondition')) {
            compositeConditionJSON = data.AndCondition;
            compositeCondition = new AndCondition();
        }
        else if (data.hasOwnProperty('OrCondition')) {
            compositeConditionJSON = data.OrCondition;
            compositeCondition = new OrCondition();
        }
        else if (data.hasOwnProperty('NotCondition')) {
            compositeConditionJSON = data.NotCondition;
            compositeCondition = new NotCondition();
        }
        if (!this.isComposite(compositeConditionJSON)) {
            compositeCondition.conditions = this.returnConditions(compositeConditionJSON);
        }
        else if (this.isHybrid(compositeConditionJSON)) {
            const /** @type {?} */ jsonKeys = Object.keys(compositeConditionJSON);
            for (const /** @type {?} */ jsonKey of jsonKeys) {
                const /** @type {?} */ jsonValue = compositeConditionJSON[jsonKey];
                const /** @type {?} */ jsonString = '{"' + jsonKey + '":' + JSON.stringify(jsonValue) + '}';
                const /** @type {?} */ jsonObject = JSON.parse(jsonString);
                if (this.isComposite(jsonObject)) {
                    this.returnInnerConditions(jsonObject, compositeCondition);
                }
                else {
                    if (this.arrayCheckerService.isArray(jsonValue)) {
                        for (const /** @type {?} */ arrayValue of jsonValue) {
                            compositeCondition.conditions.push(this.returnConditionFromJSON(jsonKey, arrayValue));
                        }
                    }
                    else {
                        compositeCondition.conditions.push(this.returnConditionFromJSON(jsonKey, jsonValue));
                    }
                }
            }
        }
        else {
            this.returnInnerConditions(compositeConditionJSON, compositeCondition);
        }
        return compositeCondition;
    }
    /**
     * @param {?} elementName
     * @return {?}
     */
    returnCompositeConditionFromName(elementName) {
        let /** @type {?} */ compositeCondition;
        switch (elementName) {
            case 'AndCondition':
                {
                    compositeCondition = new AndCondition();
                    break;
                }
            case 'OrCondition':
                {
                    compositeCondition = new OrCondition();
                    break;
                }
            case 'NotCondition':
                {
                    compositeCondition = new NotCondition();
                }
        }
        return compositeCondition;
    }
    /**
     * @param {?} key
     * @param {?} value
     * @param {?} compositeCondition
     * @return {?}
     */
    addConditionsToInnerConditions(key, value, compositeCondition) {
        const /** @type {?} */ condition = this.returnCompositeConditionFromName(key);
        compositeCondition.conditions.push(condition);
        if (this.isHybrid(value)) {
            const /** @type {?} */ jsonKeys = Object.keys(value);
            for (const /** @type {?} */ jsonKey of jsonKeys) {
                const /** @type {?} */ jsonValue = value[jsonKey];
                const /** @type {?} */ jsonString = '{"' + jsonKey + '":' + JSON.stringify(jsonValue) + '}';
                const /** @type {?} */ jsonObject = JSON.parse(jsonString);
                if (this.isComposite(jsonObject)) {
                    this.returnInnerConditions(jsonObject, condition);
                }
                else {
                    if (this.arrayCheckerService.isArray(jsonValue)) {
                        for (const /** @type {?} */ arrayValue of jsonValue) {
                            condition.conditions.push(this.returnConditionFromJSON(jsonKey, arrayValue));
                        }
                    }
                    else {
                        condition.conditions.push(this.returnConditionFromJSON(jsonKey, jsonValue));
                    }
                }
            }
        }
        else if (this.isComposite(value)) {
            // console.log( 'isComposite');
        }
        else {
            condition.conditions = this.returnConditions(value);
        }
    }
    /**
     * @param {?} innerConditionsJSON
     * @param {?} compositeCondition
     * @return {?}
     */
    returnInnerConditions(innerConditionsJSON, compositeCondition) {
        const /** @type {?} */ jsonKeys = Object.keys(innerConditionsJSON);
        for (const /** @type {?} */ key of jsonKeys) {
            const /** @type {?} */ values = innerConditionsJSON[key];
            if (this.arrayCheckerService.isArray(values)) {
                for (const /** @type {?} */ value of values) {
                    this.addConditionsToInnerConditions(key, value, compositeCondition);
                }
            }
            else {
                this.addConditionsToInnerConditions(key, innerConditionsJSON[key], compositeCondition);
            }
        }
    }
}
ConditionsCreationService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
ConditionsCreationService.ctorParameters = () => [
    { type: ArrayCheckerService, },
];

class TextExpression {
}

class ArithmeticExpression {
}

class ComputedValueCreationService {
    constructor() { }
    /**
     * @param {?} dataAsJSON
     * @return {?}
     */
    createComputedValue(dataAsJSON) {
        if (dataAsJSON['TextExpression'] !== undefined) {
            const /** @type {?} */ computedValue = new TextExpression();
            computedValue.expressionText = dataAsJSON.TextExpression;
            return computedValue;
        }
        if (dataAsJSON['ArithmeticExpression'] !== undefined) {
            {
                const /** @type {?} */ computedValue = new ArithmeticExpression();
                computedValue.expressionText = dataAsJSON.ArithmeticExpression;
                return computedValue;
            }
        }
    }
}
ComputedValueCreationService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
ComputedValueCreationService.ctorParameters = () => [];

class DecisionPointsCreationService {
    /**
     * @param {?} arrayCheckerService
     * @param {?} conditionsCreationService
     * @param {?} computedValueCreationService
     */
    constructor(arrayCheckerService, conditionsCreationService, computedValueCreationService) {
        this.arrayCheckerService = arrayCheckerService;
        this.conditionsCreationService = conditionsCreationService;
        this.computedValueCreationService = computedValueCreationService;
    }
    /**
     * @param {?} dataElementRefJSON
     * @return {?}
     */
    createRelevantDataElementReferences(dataElementRefJSON) {
        const /** @type {?} */ dataElementRef = new DataElementRef();
        dataElementRef.dataElementId = dataElementRefJSON.Attr.DataElementId;
        return dataElementRef;
    }
    /**
     * @param {?} branchJSON
     * @return {?}
     */
    returnBranch(branchJSON) {
        const /** @type {?} */ branch = new Branch();
        branch.label = branchJSON.Label;
        if (branchJSON.EndPointRef) {
            branch.endPointRef = new EndPointRef();
            branch.endPointRef.endPointId = branchJSON.EndPointRef.Attr.EndPointId;
        }
        branch.condition = this.conditionsCreationService.returnCondition(branchJSON);
        branch.computedValue = this.computedValueCreationService.createComputedValue(branchJSON);
        if (this.conditionsCreationService.isComposite(branchJSON)) {
            branch.compositeCondition = this.conditionsCreationService.returnCompositeCondition(branchJSON);
        }
        if (branchJSON.NotRelevantDataElements) {
            const /** @type {?} */ notRelevantDataElements = new NotRelevantDataElements();
            notRelevantDataElements.dataElementReferences = new Array();
            const /** @type {?} */ dataElementRefs = branchJSON.NotRelevantDataElements.DataElementRef;
            if (this.arrayCheckerService.isArray(dataElementRefs)) {
                for (const /** @type {?} */ dataElementRefJSON of dataElementRefs) {
                    notRelevantDataElements.dataElementReferences.push(this.createRelevantDataElementReferences(dataElementRefJSON));
                }
            }
            else {
                notRelevantDataElements.dataElementReferences.push(this.createRelevantDataElementReferences(dataElementRefs));
            }
            branch.notRelevantDataElements = notRelevantDataElements;
        }
        if (branchJSON.DecisionPoint) {
            branch.decisionPoints = new Array();
            this.addDecisionPoints(branchJSON.DecisionPoint, branch.decisionPoints);
        }
        return branch;
    }
    /**
     * @param {?} decsionPointAsJSON
     * @param {?} decisionPoints
     * @return {?}
     */
    addDecisionPoint(decsionPointAsJSON, decisionPoints) {
        const /** @type {?} */ decisionPoint = new DecisionPoint();
        if (decsionPointAsJSON.Attr && decsionPointAsJSON.Attr.Id) {
            decisionPoint.id = decsionPointAsJSON.Attr.Id;
        }
        decisionPoint.label = decsionPointAsJSON.Label;
        const /** @type {?} */ branchesJSON = decsionPointAsJSON.Branch;
        if (branchesJSON !== undefined) {
            decisionPoint.branches = new Array();
            if (this.arrayCheckerService.isArray(branchesJSON)) {
                for (const /** @type {?} */ branchJSON of branchesJSON) {
                    decisionPoint.branches.push(this.returnBranch(branchJSON));
                }
            }
            else {
                decisionPoint.branches.push(this.returnBranch(branchesJSON));
            }
            const /** @type {?} */ defaultBranchJSON = decsionPointAsJSON.DefaultBranch;
            if (defaultBranchJSON !== undefined) {
                decisionPoint.defaultBranch = this.createDefaultBranch(defaultBranchJSON);
            }
        }
        decisionPoints.push(decisionPoint);
    }
    /**
     * @param {?} decsionPointsAsJSON
     * @param {?} decisionPoints
     * @return {?}
     */
    addDecisionPoints(decsionPointsAsJSON, decisionPoints) {
        if (this.arrayCheckerService.isArray(decsionPointsAsJSON)) {
            for (const /** @type {?} */ decisionPoint of decsionPointsAsJSON) {
                this.addDecisionPoint(decisionPoint, decisionPoints);
            }
        }
        else {
            this.addDecisionPoint(decsionPointsAsJSON, decisionPoints);
        }
    }
    /**
     * @param {?} data
     * @return {?}
     */
    createDecisionPoints(data) {
        const /** @type {?} */ decisionPoints = new Array();
        this.addDecisionPoints(data, decisionPoints);
        return decisionPoints;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    createDefaultBranch(data) {
        const /** @type {?} */ defaultBranch = new Branch();
        defaultBranch.label = 'Default Branch';
        defaultBranch.computedValue = this.computedValueCreationService.createComputedValue(data);
        return defaultBranch;
    }
}
DecisionPointsCreationService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
DecisionPointsCreationService.ctorParameters = () => [
    { type: ArrayCheckerService, },
    { type: ConditionsCreationService, },
    { type: ComputedValueCreationService, },
];

class Rules {
}

class TemplatePartial {
}

class TemplateManagerService {
    /**
     * @param {?} diagramService
     * @param {?} elememtcreationService
     * @param {?} arrayCheckerService
     * @param {?} decisionPointsCreationService
     */
    constructor(diagramService, elememtcreationService, arrayCheckerService, decisionPointsCreationService) {
        this.diagramService = diagramService;
        this.elememtcreationService = elememtcreationService;
        this.arrayCheckerService = arrayCheckerService;
        this.decisionPointsCreationService = decisionPointsCreationService;
        this.endPointXMLString = [];
        this.stringParser = require('string');
    }
    /**
     * @param {?} templateContent
     * @return {?}
     */
    getTemplate(templateContent) {
        const /** @type {?} */ template = new Template();
        let /** @type {?} */ templateContentAsJSON;
        templateContentAsJSON = this.parseToJson(templateContent);
        if (template === undefined) {
            throw new Error('Unable to parse the template');
        }
        template.metadata = this.getMetaData(templateContentAsJSON.Metadata);
        template.dataElements = this.getDataElements(templateContentAsJSON.DataElements);
        if (templateContentAsJSON.Rules) {
            template.rules = new Rules();
            template.rules.decisionPoints = this.decisionPointsCreationService.
                createDecisionPoints(templateContentAsJSON.Rules.DecisionPoint);
        }
        template.templatePartial = this.returnEndpoints(templateContent);
        template.endPointsString = this.endPointXMLString;
        template.xmlContent = templateContent;
        return template;
    }
    /**
     * @param {?} templatePartialJSON
     * @return {?}
     */
    getTemplatePartial(templatePartialJSON) {
        const /** @type {?} */ templatePartial = new TemplatePartial;
        templatePartial.id = templatePartialJSON.Attr.Id;
        templatePartial.sectionIfNotValue = templatePartialJSON.SectionIfValueNot;
        templatePartial.sectionIfValues = templatePartialJSON.SectionIfValue;
        return templatePartial;
    }
    /**
     * @param {?} content
     * @param {?} startToken
     * @param {?} endToken
     * @return {?}
     */
    returnEndPointContents(content, startToken, endToken) {
        const /** @type {?} */ contents = new Array();
        let /** @type {?} */ templateSearchIndexPosition = 0;
        while (true) {
            const /** @type {?} */ contentStartPosition = content.indexOf(startToken, templateSearchIndexPosition);
            const /** @type {?} */ contentEndPosition = content.indexOf(endToken, templateSearchIndexPosition);
            if (contentStartPosition >= 0 && contentEndPosition >= 0) {
                const /** @type {?} */ endPosition = contentEndPosition + endToken.length;
                const /** @type {?} */ contentData = content.substring(contentStartPosition, endPosition);
                contents.push(contentData);
                templateSearchIndexPosition = endPosition + 1;
            }
            else {
                break;
            }
        }
        return contents;
    }
    /**
     * @param {?} templatePartialArray
     * @return {?}
     */
    returnTemplatePartials(templatePartialArray) {
        const /** @type {?} */ templatePartials = new Array();
        for (const /** @type {?} */ arrayItem of templatePartialArray) {
            const /** @type {?} */ templatePartial = new TemplatePartial();
            const /** @type {?} */ templatePartialAsJSON = this.parseToJson(arrayItem);
            templatePartial.id = templatePartialAsJSON.Attr.Id;
        }
        return templatePartials;
    }
    /**
     * @param {?} xmlData
     * @return {?}
     */
    returnEndpoints(xmlData) {
        const /** @type {?} */ endPointStartToken = '<EndPoints>';
        const /** @type {?} */ endPointEndToken = '</EndPoints>';
        const /** @type {?} */ endPointStartTokenPosition = xmlData.indexOf(endPointStartToken);
        const /** @type {?} */ endPointEndTokenPosition = xmlData.indexOf(endPointEndToken);
        if (endPointStartTokenPosition >= 0 && endPointEndTokenPosition >= 0) {
            const /** @type {?} */ contentStartPosition = (endPointStartTokenPosition + endPointStartToken.length);
            const /** @type {?} */ endPointContent = xmlData.substring(contentStartPosition, endPointEndTokenPosition);
            if (endPointContent.length > 0) {
                const /** @type {?} */ templatePartials = this.returnEndPointContents(endPointContent, '<TemplatePartial', '</TemplatePartial>');
                this.endPointXMLString = this.returnEndPointContents(endPointContent, '<EndPoint', '</EndPoint>');
                return templatePartials;
            }
        }
    }
    /**
     * @param {?} xmlData
     * @return {?}
     */
    parseToJson(xmlData) {
        let /** @type {?} */ jsonResult;
        const /** @type {?} */ parseString = require('xml2js').parseString;
        parseString(xmlData, { explicitRoot: false, explicitArray: false, attrkey: 'Attr' }, function (err, result) {
            jsonResult = result;
        });
        return jsonResult;
    }
    /**
     * @param {?} metadataJSON
     * @return {?}
     */
    getMetaData(metadataJSON) {
        const /** @type {?} */ metadata = new Metadata();
        metadata.label = metadataJSON.Label;
        metadata.id = metadataJSON.ID;
        metadata.schemaVersion = metadataJSON.SchemaVersion;
        metadata.ruleVersion = metadataJSON.RuleVersion;
        const /** @type {?} */ diagramsAsJSON = metadataJSON.Info.Diagrams.Diagram;
        metadata.diagrams = this.diagramService.returnDiagrams(diagramsAsJSON);
        return metadata;
    }
    /**
     * @param {?} elementType
     * @param {?} dataElementsJSON
     * @return {?}
     */
    returnDataElement(elementType, dataElementsJSON) {
        const /** @type {?} */ dataElements = new Array();
        let /** @type {?} */ dataElementCreationServiceInstance;
        for (const /** @type {?} */ dataElementCreationService of this.elememtcreationService) {
            if (dataElementCreationService.elementType === elementType) {
                dataElementCreationServiceInstance = dataElementCreationService;
                break;
            }
        }
        if (dataElementCreationServiceInstance !== undefined && dataElementsJSON !== undefined) {
            if (this.arrayCheckerService.isArray(dataElementsJSON)) {
                for (const /** @type {?} */ dataElementJSON of dataElementsJSON) {
                    const /** @type {?} */ dataElement = dataElementCreationServiceInstance.createElement(dataElementJSON);
                    dataElements.push(dataElement);
                }
            }
            else {
                const /** @type {?} */ dataElement = dataElementCreationServiceInstance.createElement(dataElementsJSON);
                dataElements.push(dataElement);
            }
        }
        return dataElements;
    }
    /**
     * @param {?} dataElementsJSON
     * @return {?}
     */
    getDataElements(dataElementsJSON) {
        let /** @type {?} */ dataElements = new Array();
        dataElements = dataElements.concat(this.returnDataElement('ChoiceDataElement', dataElementsJSON.ChoiceDataElement));
        dataElements = dataElements.concat(this.returnDataElement('MultiChoiceDataElement', dataElementsJSON.MultiChoiceDataElement));
        dataElements = dataElements.concat(this.returnDataElement('NumericDataElement', dataElementsJSON.NumericDataElement));
        dataElements = dataElements.concat(this.returnDataElement('GlobalValue', dataElementsJSON.GlobalValue));
        dataElements = dataElements.concat(this.returnDataElement('ComputedDataElement', dataElementsJSON.ComputedDataElement));
        dataElements = dataElements.concat(this.returnDataElement('IntegerDataElement', dataElementsJSON.IntegerDataElement));
        return dataElements;
    }
}
TemplateManagerService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
TemplateManagerService.ctorParameters = () => [
    { type: DiagramService, },
    { type: Array, decorators: [{ type: Inject, args: [CreationServiceInjectorToken,] },] },
    { type: ArrayCheckerService, },
    { type: DecisionPointsCreationService, },
];

class AllTextReport {
}
let ReportTextPosition = {};
ReportTextPosition.Down = 0;
ReportTextPosition.Right = 1;
ReportTextPosition[ReportTextPosition.Down] = "Down";
ReportTextPosition[ReportTextPosition.Right] = "Right";

class AcrAssistSimulatorComponent {
    /**
     * @param {?} templateManagerService
     * @param {?} simulatorEngineService
     */
    constructor(templateManagerService, simulatorEngineService) {
        this.templateManagerService = templateManagerService;
        this.simulatorEngineService = simulatorEngineService;
        this.returnExecutionHistory = new EventEmitter();
        this.returnDefaultElements = new EventEmitter();
        this.inputValues = [];
        this.position = ReportTextPosition;
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        this.isReset = true;
        this.isEmptyContent = this.templateContent === undefined || this.templateContent.length === 0 && this.inputValues.length === 0 &&
            this.inputData === undefined;
        if (this.isEmptyContent) {
            return;
        }
        if (this.inputData !== undefined) {
            if (this.inputData.length > 0) {
                this.inputValues = JSON.parse(this.inputData);
            }
        }
        this.template = this.templateManagerService.getTemplate(this.templateContent);
        this.simulatorEngineService.initialize(this.template);
        if (this.inputValues.length !== 0) {
            for (const /** @type {?} */ dataeElement of this.template.dataElements) {
                const /** @type {?} */ inputValue = this.inputValues.filter(x => x.dataElementId === dataeElement.id);
                if (inputValue !== undefined && inputValue.length > 0) {
                    dataeElement.currentValue = inputValue[0].dataElementValue;
                }
            }
        }
        this.dataElements = this.template.dataElements;
        for (let /** @type {?} */ index = 0; index < this.template.metadata.diagrams.length; index++) {
            if (this.template.metadata.diagrams[index].keyDiagram) {
                const /** @type {?} */ element = new Diagram();
                element.label = this.template.metadata.diagrams[index].label;
                element.location = this.imagePath + '/' + this.template.metadata.diagrams[index].location;
                element.keyDiagram = this.template.metadata.diagrams[index].keyDiagram;
                this.keyDiagram = element;
                break;
            }
        }
        this.resultText = undefined;
    }
    /**
     * @return {?}
     */
    resetElements() {
        this.template = this.templateManagerService.getTemplate(this.templateContent);
        this.simulatorEngineService.initialize(this.template);
        this.dataElements = this.template.dataElements;
        this.resultText = undefined;
        this.returnDefaultElements.emit();
    }
    /**
     * @param {?} textReport
     * @return {?}
     */
    recieveReportText(textReport) {
        this.resultText = textReport;
    }
    /**
     * @param {?} finalExecutionHistory
     * @return {?}
     */
    recievedExecutionHistory(finalExecutionHistory) {
        this.returnExecutionHistory.emit(finalExecutionHistory);
    }
}
AcrAssistSimulatorComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-simulator',
                template: `
    <ng-container *ngIf="!isEmptyContent">
  
      <div class="row">
        <div class="text-right border-0">
          <h4>
            <button class="btn btn-md" (click)="resetElements()">
              <strong>Reset Data</strong>
            </button>
          </h4>
        </div>
      </div>
  
      <div class="row content-area" >
        <div [ngClass]="{'col-sm-6' : reportTextPosition == position.Right ? true : false, 'col-sm-12' : reportTextPosition == position.Right ? false : true}" class="text-right border-0">
          <ng-container>
            <acr-assist-data-element [dataElements]="dataElements" [templatePartial]="template.templatePartial" [endPointXMLString]="template.endPointsString"
              [imagePath]="imagePath" [xmlContent]="template.xmlContent" (returnReportText)='recieveReportText($event)' [inputValues]="inputValues"
              [isReset]="isReset" (returnExecutionHistory)='recievedExecutionHistory($event)'></acr-assist-data-element>
          </ng-container>
        </div>

        <div class="col-sm-6 text-right border-0 fixed-report-text-sidebar" *ngIf="reportTextPosition == position.Right">
          <div class="row report-text-top-margin left-margin">
            <ng-container *ngIf="resultText !== undefined">
              <acr-assist-report-text [reportText]="resultText"></acr-assist-report-text>
            </ng-container>
          </div>
          <div *ngIf=" showKeyDiagram === true && keyDiagram !== undefined" class="keydiagram">
              <img class="img-max-width" src="{{keyDiagram.location}}">
          </div>
        </div>

        <div class="col-sm-8 report-text-top-margin" *ngIf="reportTextPosition == position.Down">
          <ng-container *ngIf="resultText !== undefined">
            <acr-assist-report-text [reportText]="resultText"></acr-assist-report-text>
          </ng-container>
        </div>
      </div>
    </ng-container>
  `,
                styles: [`
    input[type=file].inputfile {
      width: 0.1px;
      height: 0.1px;
      opacity: 0;
      overflow: hidden;
      position: absolute;
      z-index: -1;
      margin: 0;
    }

    input[type=file].inputfile+label:active,
    input[type=file].inputfile+label {
      max-width: 100%;
      font-size: 1.5rem;
      font-weight: 700;
      text-overflow: ellipsis;
      white-space: nowrap;
      cursor: pointer;
      display: inline-block;
      overflow: hidden;
      display: inline-block;
      color: #f1e5e6;
      background-color: #d3394c;
      text-indent: 0px;
      width: 130px;
    }

    input[type=file].inputfile+label:hover {
      background-color: #722040;
    }

    input[type=file].inputfile+label {
      cursor: pointer;
      /* "hand" cursor */
    }

    input[type=file].inputfile:hover+label {
      outline: 1px dotted #000;
      outline: -webkit-focus-ring-color auto 5px;
    }

    .right-fixed {
      position: fixed;
      right: 0px;
    }

    .row.report-text-top-margin.right-align{
      width: 80%;
      margin-left: 135px;
    }

    /* Master Styles */

    h1 {
      color: #369;
      font-family: Arial, Helvetica, sans-serif;
      font-size: 250%;
    }

    h2,
    h3 {
      color: #444;
      font-family: Arial, Helvetica, sans-serif;
      font-weight: lighter;
    }

    body {
      margin: 2em;
    }


    /*Apply background color for div having checked radio button*/

    input[type="radio"]:checked+div {
      background-color: #1e89b5 !important;
      border: 1px solid #9b9b9b;
      color: #ffffff;
    }


    /*Apply background color for div having no checked radio button*/

    input[type="radio"]+div {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
    }

    .checkbox>label {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
      height: auto;
      line-height: 25px;
      width: 100%;
      font-weight: bold;
    }

    .checkbox>label>input[type="checkbox"] {
      margin-left: -15px;
      margin-top: 6px;
    }

    .full-width span {
      font-weight: bold;
    }


    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;
        border: 1px solid #9B9B9B;
        }*/

    .DEElement {
      color: #363636;
      letter-spacing: -0.37px;
      word-wrap: break-word;
    }

    .DEValues {
      /*font-size: 12px;*/
      color: #4a4a4a;
      letter-spacing: -0.29px;
      width: 100%;
      min-width: 180px;
      max-width: 280px;
    }


    /* CHECKBOX OVERWRITE STYLES */

    .rad {
      cursor: pointer;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
      -webkit-user-select: none;
      -webkit-touch-callout: none;
    }

    .rad>input {
      /* HIDE ORG RADIO & CHECKBOX */
      visibility: hidden;
      position: absolute;
    }

    [type="radio"]+span::before {
      content: "";
      display: inline-block;
      width: 9px;
      height: 9px;
      border-radius: 1em;
      border: 0.1px solid #fff;
      -webkit-box-shadow: 0 0 0 1px #57aed0;
              box-shadow: 0 0 0 1px #57aed0;
      margin-right: 4px;
      -webkit-transition: 0.5s ease all;
      transition: 0.5s ease all;
      margin-left: -15px;
    }

    [type="radio"]:checked+span::before {
      background: #57aed0;
      -webkit-box-shadow: 0 0 0 2px #57aed0;
              box-shadow: 0 0 0 2px #57aed0;
      margin-top: auto;
      /*margin-left:-15px;*/
    }

    .reportText {
      font-size: 14px;
      color: #363636;
      letter-spacing: -0.49px;
      margin-top: 5px;
    }

    button:hover,
    button:focus,
    button.active,
    .btn-default:hover,
    .btn-default:focus,
    .item.active,
    .btn-default.active {
      background: #1e89b5 !important;
      color: #ffffff !important;
    }

    .hideInput {
      visibility: hidden;
      margin-left: 5px !important;
    }

    .panel {
      background-color: transparent;
    }

    .logo {
      height: 30px;
      width: 250px;
    }

    .navbar-blue {
      background-color: #00205b !important;
      color: #fff;
    }

    .navbar-brand-text {
      font-size: 30px;
      color: #fff;
      font-weight: normal;
      margin-top: 10px;
    }

    .close {
      margin-top: -20px !important;
    }


    /*.full-width {
            width: 320px !important;
        }*/

    #myNav.affix {
      width: 483px;
      top: 100;
    }

    #Can-ImgMap {
      pointer-events: none;
      position: absolute;
      opacity: 0.5;
    }


    /* Styles for Assist bootstrap*/

    .control-label {
      text-align: left !important;
    }

    .box-style {
      text-decoration: none;
      color: #363636 !important;
      border-radius: 3px;
      padding: 5px;
      font-weight: bold !important;
      width: 75%;
    }

    .findings {
      color: #ffffff !important;
      background-color: #5295b1 !important;
      border-color: #5295b1 !important;
      background-image: none !important;
      font-weight: bold;
      text-transform: capitalize;
      height: 45px;
      font-size: 16px;
      text-align: left;
    }

    .table-row {
      display: table-row;
      width: auto;
      clear: both;
    }

    .table-cell {
      display: table-cell;
      width: 475px;
      font-size: 12px;
      background-color: transparent;
      color: black;
      height: 25px;
      line-height: 25px;
      padding: 1px;
    }

    .imgMap-table-cell {
      width: 10% !important;
      vertical-align: middle;
    }

    .panel-default {
      min-width: 100%;
    }

    #footer {
      position: fixed;
      bottom: 0;
    }

    .row-style {
      bottom: 5px;
      position: fixed;
      top: 55px;
      overflow: auto;
      width: 100%;
    }

    .modal-dialog {
      top: 100px;
      margin-left: 50% !important;
    }

    .required-field {
      /* border: 1px solid red; */
      /* border-radius: 5px; */
      padding: 5px;
      font-size: 16px;
      color: red;
      /* width: 120px; */
      display: inline-block;
      font-weight: bold;
    }

    .xml-only-msg {
      border: 1px solid red;
      border-radius: 5px;
      padding: 5px;
      font-size: 12px;
      color: white;
      width: 223px;
      display: inline-block;
      font-weight: bold;
    }

    @media (min-width: 400px) and (max-width: 1024px) {
      .xml-only-msg {
        width: 120px;
      }
    }

    @media (max-width: 475px)  {
      .xml-only-msg {
        color: #000000
      }
    }
    .col-per-10 {
      border: 1px solid blue;
      padding: 15px 10px 15px 10px;
      border-radius: 10px;
      height: auto;
      width: 10%;
      float: left;
      position: fixed;
      min-height: 1px;
    }

    .btn-group>.btn:first-child {
      margin-left: 0;
      width: 165px;
      margin-top: 10px;
    }

    .col-md-10 {
      left: 200px;
    }

    .module-header {
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
      margin-left: -135px;
      margin-top: -15px;
      font-size: 14px;
      font-weight: bold;
      color: #363636;
    }

    .btn-group-justified {
      padding-left: 15px;
    }

    select {
      height: 35px;
      border-radius: 5px;
      max-width: 280px;
      width: 100%;
    }

    .findings select{
      max-width: 150px;
      margin-top: -3px;
    }
    .fixed-keydiagram {
      position: fixed !important;
      float: right;
      padding-right: 0px !important;
      margin-right: 10px;
      padding-left: 25px !important;
    }

    .center-align {
      text-align: center;
      width: 160px !important;
      padding: 0px !important;
    }

    .center-align div {
      width: 200px;
      margin-left: -10px;
    }

    .findings div {
      color: #363636 !important;
      margin-left: 100px !important;
      margin-top: -23.5px !important;
      height: 30px;
    }

    .findings div select {
      text-transform: capitalize;
    }

    .modal-backdrop {
      top: 10000px !important;
    }

    .tooltip-arrow {
      display: none !important;
    }

    .other-reportSection {
      font-weight: normal;
      margin-top: -10px;
      margin-left: 15px;
    }

    a:hover {
      text-decoration: none !important;
    }

    .no-btm-margin-table {
      margin-bottom: 0px !important;
    }

    .adjust-diagram {
      margin-top: 56px;
      right: 20px !important;
    }

    .adjust-diagram-image {
      top: 0px !important;
      margin-top: 0px !important;
    }

    .reportText-panel {
      width: 90%;
      margin-left: 2%;
    }

    .reportText-body {
      margin-left: 2%;
    }

    .top-Index {
      z-index: 99999 !important;
    }


    /* Master Styles */

    h1 {
      color: #369;
      font-family: Arial, Helvetica, sans-serif;
      font-size: 250%;
    }

    h2,
    h3 {
      color: #444;
      font-family: Arial, Helvetica, sans-serif;
      font-weight: lighter;
    }

    .div-simulator-container {
      margin: 0;
    }


    /*Apply background color for div having checked radio button*/

    .div-simulator-container input[type="radio"]:checked+div {
      background-color: #1e89b5 !important;
      border: 1px solid #9b9b9b;
      color: #ffffff;
    }


    /*Apply background color for div having no checked radio button*/

    .div-simulator-container input[type="radio"]+div {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
    }

    .div-simulator-container .checkbox>label {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
      height: 25px;
      line-height: 25px;
    }

    .div-simulator-container .checkbox>label>input[type="checkbox"] {
      margin-left: -15px;
      margin-top: 6px;
    }

    .div-simulator-container .full-width span {
      font-weight: bold;
    }


    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;
        border: 1px solid #9B9B9B;
        }*/

    .div-simulator-container .DEElement {
      color: #363636;
      letter-spacing: -0.37px;
      word-wrap: break-word;
    }

    .div-simulator-container .DEValues {
      /*font-size: 12px;*/
      color: #4a4a4a;
      letter-spacing: -0.29px;
    }


    /* CHECKBOX OVERWRITE STYLES */

    .div-simulator-container .rad {
      cursor: pointer;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
      -webkit-user-select: none;
      -webkit-touch-callout: none;
    }

    .div-simulator-container .rad>input {
      /* HIDE ORG RADIO & CHECKBOX */
      visibility: hidden;
      position: absolute;
    }

    .div-simulator-container [type="radio"]+span::before {
      content: "";
      display: inline-block;
      width: 9px;
      height: 9px;
      border-radius: 1em;
      border: 0.1px solid #fff;
      -webkit-box-shadow: 0 0 0 1px #57aed0;
              box-shadow: 0 0 0 1px #57aed0;
      margin-right: 4px;
      -webkit-transition: 0.5s ease all;
      transition: 0.5s ease all;
      margin-left: -15px;
    }

    [type="radio"]:checked+span::before {
      background: #57aed0;
      -webkit-box-shadow: 0 0 0 2px #57aed0;
              box-shadow: 0 0 0 2px #57aed0;
      margin-top: auto;
      /*margin-left:-15px;*/
    }

    .div-simulator-container .reportText {
      font-size: 14px;
      color: #363636;
      letter-spacing: -0.49px;
    }

    .div-simulator-container button:hover,
    .div-simulator-container button:focus,
    .div-simulator-container button.active,
    .div-simulator-container .btn-default:hover,
    .btn-default:focus,
    .div-simulator-container .item.active,
    .div-simulator-container .btn-default.active {
      background: #1e89b5 !important;
      color: #ffffff !important;
    }

    .div-simulator-container .hideInput {
      visibility: hidden;
      margin-left: 5px !important;
    }

    .div-simulator-container .panel {
      background-color: transparent;
    }

    .logo {
      height: 30px;
      width: 250px;
    }

    .navbar-blue {
      background-color: #00205b !important;
      color: #fff;
    }

    .navbar-brand-text {
      font-size: 30px;
      color: #fff;
      font-weight: normal;
      margin-top: 10px;
    }

    .div-simulator-container .close {
      margin-top: -20px !important;
    }


    /*.full-width {
            width: 320px !important;
        }*/

    #myNav.affix {
      width: 483px;
      top: 100;
    }

    #Can-ImgMap {
      pointer-events: none;
      position: absolute;
      opacity: 0.5;
    }


    /* Styles for Assist bootstrap*/

    .div-simulator-container .control-label {
      text-align: left !important;
    }

    .div-simulator-container .box-style {
      text-decoration: none;
      color: #363636 !important;
      border-radius: 3px;
      padding: 5px;
      font-weight: bold !important;
      width: 75%;
    }

    .div-simulator-container .findings {
      color: #ffffff !important;
      background-color: #5295b1 !important;
      border-color: #5295b1 !important;
      background-image: none !important;
      font-weight: bold;
      text-transform: capitalize;
      height: 40px;
    }

    .div-simulator-container .table-row {
      display: table-row;
      width: auto;
      clear: both;
    }

    .div-simulator-container .table-cell {
      display: table-cell;
      width: 475px;
      font-size: 12px;
      background-color: transparent;
      color: black;
      height: 25px;
      line-height: 25px;
      padding: 1px;
      border-bottom: none;
    }

    .div-simulator-container .imgMap-table-cell {
      width: 10% !important;
      vertical-align: middle;
    }

    .div-simulator-container .panel-default {
      min-width: 600px;
      margin: 0 !important;
      background-color: white;
    }

    .div-simulator-container .footerBlock {
      position: fixed;
      bottom: 55px;
    }

    .div-simulator-container .row-style {
      bottom: 5px;
      position: fixed;
      top: 55px;
      overflow: auto;
      width: 100%;
    }

    .div-simulator-container .modal-dialog {
      top: 100px;
      /*margin-left: 50% !important;*/
      margin-left: 0 !important;
    }

    .div-simulator-container .required-field {
      border: 1px solid #edd1d1;
      border-radius: 5px;
      padding: 5px;
      font-size: 12px;
      color: #cd5c5c;
      width: 125px;
    }

    .div-simulator-container .col-per-10 {
      border: 1px solid blue;
      padding: 15px 10px 15px 10px;
      border-radius: 10px;
      height: auto;
      width: 10%;
      float: left;
      position: fixed;
      min-height: 1px;
    }

    .div-simulator-container .btn-group>.btn:first-child {
      margin-left: 0;
      width: 165px;
      margin-top: 10px;
    }

    .div-simulator-container .col-md-10 {
      left: 200px;
    }

    .div-simulator-container .module-header {
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
      margin-left: -135px;
      margin-top: -15px;
      font-size: 14px;
      font-weight: bold;
      color: #363636;
    }

    .div-simulator-container .btn-group-justified {
      padding-left: 15px;
    }

    .div-simulator-container select {
      height: 28px;
      border-radius: 5px;
    }

    .div-simulator-container .panel-body {
      padding: 10px !important;
    }

    .div-simulator-container .fixed-keydiagram {
      position: fixed !important;
      float: right;
      padding-right: 0px !important;
      margin-right: 10px;
      padding-left: 25px !important;
    }

    .div-simulator-container .center-align {
      text-align: center;
      width: 160px !important;
      padding: 0px !important;
    }

    .div-simulator-container .center-align div {
      width: 200px;
      margin-left: -10px;
    }

    .div-simulator-container .findings div {
      color: #363636 !important;
      margin-left: 97px !important;
      margin-top: -29.5px !important;
      height: 30px;
    }

    .div-simulator-container .findings div select {
      text-transform: capitalize;
    }

    .div-simulator-container .modal-backdrop {
      top: 10000px !important;
    }

    .div-simulator-container .tooltip-arrow {
      display: none !important;
    }

    .div-simulator-container .other-reportSection {
      font-weight: normal;
      margin-top: -10px;
      margin-left: 15px;
    }

    .div-simulator-container a:hover {
      text-decoration: none !important;
    }

    .div-simulator-container .no-btm-margin-table {
      margin-bottom: 0px !important;
    }

    .div-simulator-container .adjust-diagram {
      margin-top: 56px;
      right: 20px !important;
    }

    .adjust-diagram-image {
      top: 0px !important;
      margin-top: 0px !important;
    }

    @media only screen and (min-width: 1224px) {
      .tab-content {
        padding: 5px;
      }
    }

    @media (min-width: 768px) {
      #page-content-wrapper {
        padding: 0px 20px;
        margin-top: 15px;
      }
    }

    #sidebar-wrapper {
      left: 175px;
      margin-left: -175px;
    }

    #rowContent {
      padding-bottom: 120px;
    }

    @media only screen and (min-width: 1224px) {
      .fixed-reportText {
        width: 1064px;
      }
    }

    @media only screen and (min-width: 1824px) {
      .fixed-reportText {
        width: 1260px;
      }
    }

    @media only screen and (min-width: 1224px) {
      .modal-lg {
        left: 0;
        /* left: -250px; */
      }
    }

    .form-group {
      margin-bottom: 15px;
    }

    .control-label {
      margin-top: 0;
      margin-left: 0;
    }

    .div-simulator-container .checkbox>label {
      height: 30px;
      line-height: 30px;
    }

    .div-simulator-container .checkbox>label>input[type="checkbox"] {
      margin-top: 8px;
    }

    .div-simulator-container select {
      height: 30px;
      border-radius: 5px;
      font-size: 12px;
      width: 280px;
    }

    .div-simulator-container .input-group {
      width: 280px;
    }

    .div-simulator-container .input-group .form-control {
      border-radius: 5px;
      -webkit-box-shadow: none;
              box-shadow: none;
      border: 1px solid #969696;
    }

    .div-simulator-container .imgMap-table-cell {
      padding-left: 10px;
    }

    @media (min-width: 1224px) {
      .modal-lg {
        width: 630px;
      }
    }

    .tableImagemap {
      table-layout: fixed;
    }

    @media (min-width: 1850px) {
      .modal-lg {
        width: 900px;
      }
      .tableImagemap {
        table-layout: inherit;
      }
    }

    .col-centered {
      float: none;
      margin: 0 auto;
    }

    .checkbox {
      max-width: 280px;
    }

    [type="number"] {
      max-width: 280px;
      /*margin-left: -15px;*/
    }

    .input-group {
      width: 100%;
    }

    @media (min-width:1441px) {
      .DEValues {
        /*min-width: 280px;
        max-width: 280px;*/
        height: auto;
      }
    }

    @media (max-width:1024px) {
      .adjust-diagram-image {
        width: 50%;
      }
    }

    @media (min-width:1921px) {
      .adjust-diagram-image {
        width: 50%;
      }
    }

    .row {
      font-weight: bold;
    }

    .carousel-item.item img {
      width: 100% !important;
    }

    .carousel-indicators {
      display: none !important;
    }

    .display-inline {
      display: inline;
    }

    .font-weight-normal {
      font-weight: normal;
    }

    .font-weight-bold {
      font-weight: bold;
    }

    .color-white {
      color: #ffffff;
    }

    .bottom-margin{
      margin-bottom: 25px;
    }

    .reportText-content {
      white-space: pre-line; 
      font-weight: bold;
      margin: -40px 0px;
      height: -webkit-fit-content;
      height: -moz-fit-content;
      height: fit-content;
    }

    .no-bottom-margin {
      margin-bottom: 0px !important;
    }
    .reportText-main-content{
      font-size: 16px;
    }

    .split-length-word {
      word-break: break-all;
      text-align: left;
      margin: 0px 0px;
    }

    .img-max-width {
      width: 70% !important;
    }

    .keydiagram {
      text-align: center;
      margin-top: 10px;
    }

    .report-text-top-margin {
      margin-top: 15px;
    }

    input[type=number]::-webkit-inner-spin-button, 
    input[type=number]::-webkit-outer-spin-button { 
        -webkit-appearance: none;
        -moz-appearance: none;
        margin: 0; 
    }

    input[type="number"]:hover,
    input[type="number"]:focus,
    input[type="number"] {
        -moz-appearance: textfield;
    }

    .numeric-align {
      display: inline;
    }

    input[type="text"] {
    max-width: 280px;
    margin-left: 0px !important;
    border-radius: 5px !important;
    text-transform: capitalize;
    }

    .all-reporttext-heading {
      text-decoration: underline;
      font-weight: bold;
      text-transform: capitalize;
      font-size: 18px;
      margin-top: -50px;
      text-align: left;
    }

    .all-reportText-content {
      margin-top: -10px;
    }

    .split-length-word.all-reportText-content {
      text-align: justify;
      word-break: unset;
    }

    .fixed-report-text-sidebar {
      position: fixed;
      right: 0;
      width: 45%;
    }

    .fixed-report-text-footer {
      position: fixed;
      left: 15 !important;
      bottom: 0;
      background-color: white;
    }

    .left-margin {
      margin-left: 60px;
      width: 90%;
    }

    .overflow {
      /* max-height: 500px; */
      overflow-x: hidden;
    }

    @media (max-width: 650px) {
  

      .left-margin {
        margin-left: 20px;
      }

      .keydiagram {
        width: 100%;
        margin-left: 4%;
      } 
      .row.content-area {
        padding: 0px 5px;
      }

      .text-right.border-0 > h4 {
        padding-right: 20px;
      }

      .keydiagram {
        width: 100%;
        text-align: center;
        margin-left: 0px !important;
      }
    }
    @media (max-width: 1024px) {
      .keydiagram {
        width: 100%;
        margin-left: 9%;
      }
      .img-max-width {
        width: 80% !important;
      }
    }
    @media (max-width: 1023px) {
      .fixed-report-text-sidebar {
        position: relative;
      }
    }

    .upload-button-size {
    	font-size: 100% !important;
    }
  
  `]
            },] },
];
/**
 * @nocollapse
 */
AcrAssistSimulatorComponent.ctorParameters = () => [
    { type: TemplateManagerService, },
    { type: SimulatorEngineService, },
];
AcrAssistSimulatorComponent.propDecorators = {
    'templateContent': [{ type: Input },],
    'imagePath': [{ type: Input },],
    'showKeyDiagram': [{ type: Input },],
    'reportTextPosition': [{ type: Input },],
    'returnExecutionHistory': [{ type: Output },],
    'returnDefaultElements': [{ type: Output },],
    'inputValues': [{ type: Input },],
    'inputData': [{ type: Input },],
};

/**
 * @abstract
 */
class DataElementCreationBaseService {
    /**
     * @param {?} diagramService
     */
    constructor(diagramService) {
        this.diagramService = diagramService;
    }
    /**
     * @abstract
     * @param {?} data
     * @return {?}
     */
    createElement(data) { }
    /**
     * @param {?} diagramJSON
     * @return {?}
     */
    returnDiagram(diagramJSON) {
        const /** @type {?} */ metadataDiagram = new Diagram();
        metadataDiagram.displaySequence = diagramJSON.Attr.DisplaySequence;
        metadataDiagram.keyDiagram = diagramJSON.Attr.IsKeyDiagram ? diagramJSON.Attr.IsKeyDiagram : false;
        metadataDiagram.label = diagramJSON.Label;
        metadataDiagram.location = diagramJSON.Location;
        return metadataDiagram;
    }
    /**
     * @param {?} data
     * @param {?} dataElement
     * @return {?}
     */
    populateBasicData(data, dataElement) {
        dataElement.dataElementType = this.elementType;
        dataElement.displaySequence = data.Attr.DisplaySequence;
        dataElement.id = data.Attr.Id;
        dataElement.isRequired = data.Attr.IsRequired === 'true' ? true : false;
        dataElement.label = data.Label;
        dataElement.hint = data.Hint;
        if (data.Diagrams) {
            dataElement.diagrams = this.diagramService.returnDiagrams(data.Diagrams.Diagram);
        }
        dataElement.currentValue = undefined;
        dataElement.defaultValue = undefined;
    }
}
DataElementCreationBaseService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
DataElementCreationBaseService.ctorParameters = () => [
    { type: DiagramService, },
];

class BaseDataElement {
    constructor() {
        this.isVisible = true;
    }
}

class ChoiceDataElement extends BaseDataElement {
    constructor() {
        super(...arguments);
        this.allowFreetext = false;
    }
}

class Choice {
}

class ImageElements {
}

class ImageMap extends ImageElements {
}

class Area {
}

class AreaMap {
}

class ChoiceDataElementCreationService extends DataElementCreationBaseService {
    /**
     * @param {?} diagramService
     * @param {?} arrayCheckerService
     */
    constructor(diagramService, arrayCheckerService) {
        super(diagramService);
        this.arrayCheckerService = arrayCheckerService;
        this.elementType = 'ChoiceDataElement';
    }
    /**
     * @param {?} choiceItem
     * @return {?}
     */
    returnChoice(choiceItem) {
        const /** @type {?} */ choice = new Choice();
        choice.label = choiceItem.Label;
        choice.value = choiceItem.Value;
        choice.hint = choiceItem.Hint;
        choice.reportText = choiceItem.ReportText;
        choice.default = false;
        if (choiceItem.Attr && choiceItem.Attr.IsDefault) {
            choice.default = choiceItem.Attr.IsDefault;
        }
        return choice;
    }
    /**
     * @param {?} areaJSON
     * @return {?}
     */
    returnArea(areaJSON) {
        const /** @type {?} */ area = new Area();
        area.choiceValue = areaJSON.Attr.ChoiceValue;
        area.coords = areaJSON.Attr.Coords;
        area.shape = areaJSON.Attr.Shape;
        return area;
    }
    /**
     * @param {?} data
     * @return {?}
     */
    createElement(data) {
        const /** @type {?} */ dataElement = new ChoiceDataElement();
        super.populateBasicData(data, dataElement);
        dataElement.allowFreetext = data.Attr.AllowFreetext ? data.Attr.AllowFreetext : false;
        const /** @type {?} */ choiceItems = data.ChoiceInfo.Choice;
        let /** @type {?} */ defaultValue;
        if (choiceItems !== undefined) {
            dataElement.choiceInfo = new Array();
            if (this.arrayCheckerService.isArray(choiceItems)) {
                for (const /** @type {?} */ choiceItem of choiceItems) {
                    const /** @type {?} */ choice = this.returnChoice(choiceItem);
                    if (choice.default) {
                        defaultValue = choice.value;
                    }
                    dataElement.choiceInfo.push(choice);
                }
            }
            else {
                const /** @type {?} */ choice = this.returnChoice(choiceItems);
                if (choice.default) {
                    defaultValue = choice.value;
                }
                dataElement.choiceInfo.push(choice);
            }
        }
        dataElement.defaultValue = defaultValue;
        dataElement.currentValue = defaultValue;
        const /** @type {?} */ imageMap = data.ImageMap;
        if (imageMap !== undefined) {
            dataElement.imageMap = new ImageMap();
            dataElement.imageMap.location = imageMap.Location;
            const /** @type {?} */ areaMaps = imageMap.Map.Area;
            if (areaMaps !== undefined) {
                dataElement.imageMap.map = new AreaMap();
                dataElement.imageMap.map.areas = new Array();
                if (this.arrayCheckerService.isArray(areaMaps)) {
                    for (const /** @type {?} */ areaMap of areaMaps) {
                        dataElement.imageMap.map.areas.push(this.returnArea(areaMap));
                    }
                }
                else {
                    dataElement.imageMap.map.areas.push(this.returnArea(areaMaps));
                }
            }
        }
        return dataElement;
    }
}
ChoiceDataElementCreationService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
ChoiceDataElementCreationService.ctorParameters = () => [
    { type: DiagramService, },
    { type: ArrayCheckerService, },
];

class MultipleChoiceDataElementCreationService extends ChoiceDataElementCreationService {
    /**
     * @param {?} diagramService
     * @param {?} arrayCheckerService
     */
    constructor(diagramService, arrayCheckerService) {
        super(diagramService, arrayCheckerService);
        this.elementType = 'MultiChoiceDataElement';
    }
}
MultipleChoiceDataElementCreationService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
MultipleChoiceDataElementCreationService.ctorParameters = () => [
    { type: DiagramService, },
    { type: ArrayCheckerService, },
];

class NumericDataElement extends BaseDataElement {
}

class NumericDataElementCreationService extends DataElementCreationBaseService {
    /**
     * @param {?} diagramService
     */
    constructor(diagramService) {
        super(diagramService);
        this.elementType = 'NumericDataElement';
    }
    /**
     * @param {?} data
     * @return {?}
     */
    createElement(data) {
        const /** @type {?} */ dataElement = new NumericDataElement();
        super.populateBasicData(data, dataElement);
        dataElement.minimum = data.Minimum;
        dataElement.maximum = data.Maximum;
        return dataElement;
    }
}
NumericDataElementCreationService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
NumericDataElementCreationService.ctorParameters = () => [
    { type: DiagramService, },
];

class IntegerDataElement extends BaseDataElement {
}

class IntegerDataElementCreationService extends DataElementCreationBaseService {
    /**
     * @param {?} diagramService
     */
    constructor(diagramService) {
        super(diagramService);
        this.elementType = 'IntegerDataElement';
    }
    /**
     * @param {?} data
     * @return {?}
     */
    createElement(data) {
        const /** @type {?} */ dataElement = new IntegerDataElement();
        super.populateBasicData(data, dataElement);
        dataElement.minimum = data.Minimum;
        dataElement.maximum = data.Maximum;
        return dataElement;
    }
}
IntegerDataElementCreationService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
IntegerDataElementCreationService.ctorParameters = () => [
    { type: DiagramService, },
];

const $ = require('jquery');
class AssistDataElementComponent {
    /**
     * @param {?} simulatorEngineService
     */
    constructor(simulatorEngineService) {
        this.simulatorEngineService = simulatorEngineService;
        this.Endpoints = [];
        this.returnReportText = new EventEmitter();
        this.returnExecutionHistory = new EventEmitter();
        this.comparisonValues = [];
        this.selectedChoiceValues = [];
        this.executedResultIds = [];
        this.executedResultHistories = [];
        this.inputValues = [];
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.simulatorEngineService.simulatorStateChanged.subscribe((message) => {
            this.simulatorState = (message);
            this.dataElementValues = this.simulatorEngineService.getAllDataElementValues();
            for (const /** @type {?} */ dataElement of this.dataElements) {
                if (this.simulatorState.nonRelevantDataElementIds && this.simulatorState.nonRelevantDataElementIds.length > 0) {
                    if (this.simulatorState.nonRelevantDataElementIds.indexOf(dataElement.id) >= 0) {
                        dataElement.isVisible = false;
                    }
                    else {
                        dataElement.isVisible = true;
                    }
                }
                else {
                    dataElement.isVisible = true;
                }
                dataElement.currentValue = (dataElement.currentValue !== undefined) ? dataElement.currentValue : this.dataElementValues[dataElement.id];
            }
            if (this.simulatorState.endPointId && this.simulatorState.endPointId.length > 0) {
                this.generateReportText(this.simulatorState.endPointId);
            }
            else {
                this.returnReportText.emit(undefined);
            }
        });
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        this.dataElements = this.dataElements.filter(x => x.displaySequence != null).sort(function (DE_1, DE_2) { return DE_1.displaySequence - DE_2.displaySequence; });
        this.executedResultIds = [];
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    choiceSelected($event) {
        if ($event.receivedElement !== undefined && $event.selectedCondition !== undefined) {
            this.selectedChoiceValues[$event.receivedElement.elementId + 'SelectedValue'] = $event.receivedElement.selectedText;
            this.simulatorEngineService.addOrUpdateDataElement($event.receivedElement.elementId, $event.receivedElement.selectedValue, $event.receivedElement.selectedText);
            const /** @type {?} */ executedResults = [];
            executedResults[$event.selectedCondition.selectedCondition] = $event.selectedCondition.selectedValue;
            this.executedResultIds[$event.selectedCondition.selectedConditionId] = executedResults;
            if (this.simulatorState.endPointId && this.simulatorState.endPointId.length > 0) {
                this.generateExecutionHistory();
            }
        }
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    numericSelected($event) {
        if ($event.receivedElement !== undefined && $event.selectedCondition !== undefined) {
            this.simulatorEngineService.addOrUpdateDataElement($event.receivedElement.elementId, $event.receivedElement.selectedValue, $event.receivedElement.selectedValue);
            const /** @type {?} */ executedResults = [];
            executedResults[$event.selectedCondition.selectedCondition] = $event.selectedCondition.selectedValue;
            this.executedResultIds[$event.selectedCondition.selectedConditionId] = executedResults;
            if (this.simulatorState.endPointId && this.simulatorState.endPointId.length > 0) {
                this.generateExecutionHistory();
            }
        }
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    multiSelected($event) {
        if ($event.receivedElement !== undefined && $event.selectedCondition !== undefined) {
            this.comparisonValues[$event.receivedElement.elementId + 'ComparisonValue'] = $event.receivedElement.selectedComparisonValues;
            this.simulatorEngineService.addOrUpdateDataElement($event.receivedElement.elementId, $event.receivedElement.selectedComparisonValues, $event.receivedElement.selectedValues);
            const /** @type {?} */ executedResults = [];
            executedResults[$event.selectedCondition.selectedCondition] = $event.selectedCondition.selectedValue;
            this.executedResultIds[$event.selectedCondition.selectedConditionId] = executedResults;
            if (this.simulatorState.endPointId && this.simulatorState.endPointId.length > 0) {
                this.generateExecutionHistory();
            }
        }
    }
    /**
     * @param {?} inputValues
     * @param {?} isReset
     * @return {?}
     */
    load(inputValues, isReset) {
        if (inputValues !== undefined) {
            if (isReset) {
                $('select').prop('selectedIndex', 0);
            }
            this.returnReportText.emit(undefined);
            for (const /** @type {?} */ inputValue of inputValues) {
                if (inputValue !== undefined) {
                    for (const /** @type {?} */ dataElement of this.dataElements) {
                        if (dataElement.id === inputValue.dataElementId) {
                            switch (dataElement.dataElementType) {
                                case 'ChoiceDataElement':
                                    if (inputValue.dataElementValue !== undefined) {
                                        if (!isReset) {
                                            $('#' + inputValue.dataElementValue + '_' + inputValue.dataElementId).prop('checked', true);
                                            this.simulatorEngineService.addOrUpdateDataElement(inputValue.dataElementId, inputValue.dataElementValue, inputValue.dataElementValue);
                                        }
                                        else {
                                            $('#' + inputValue.dataElementValue + '_' + inputValue.dataElementId).prop('checked', false);
                                            // $('#' + inputValue.dataElementValue + '_' + inputValue.dataElementId).trigger('click');
                                            this.isReset = true;
                                        }
                                    }
                                    break;
                                case 'IntegerDataElement':
                                    if (inputValue.dataElementValue !== undefined) {
                                        if (!isReset) {
                                            $('#' + inputValue.dataElementId).val(inputValue.dataElementValue);
                                            this.simulatorEngineService.addOrUpdateDataElement(inputValue.dataElementId, inputValue.dataElementValue, inputValue.dataElementValue);
                                            $('#' + inputValue.dataElementId).trigger('change');
                                        }
                                        else {
                                            $('#' + inputValue.dataElementId).val('');
                                            $('#' + inputValue.dataElementId).trigger('change');
                                        }
                                        const /** @type {?} */ customEvent = document.createEvent('Event');
                                        customEvent.initEvent('change', true, true);
                                        $('#' + inputValue.dataElementId)[0].dispatchEvent(customEvent);
                                    }
                                    break;
                                case 'NumericDataElement':
                                    if (inputValue.dataElementValue !== undefined) {
                                        if (!isReset) {
                                            $('#' + inputValue.dataElementId).val(inputValue.dataElementValue);
                                            this.simulatorEngineService.addOrUpdateDataElement(inputValue.dataElementId, inputValue.dataElementValue, inputValue.dataElementValue);
                                            $('#' + inputValue.dataElementId).trigger('keyup');
                                        }
                                        else {
                                            $('#' + inputValue.dataElementId).val('');
                                            $('#' + inputValue.dataElementId).trigger('keyup');
                                        }
                                        const /** @type {?} */ customEvent = document.createEvent('Event');
                                        customEvent.initEvent('change', true, true);
                                        $('#' + inputValue.dataElementId)[0].dispatchEvent(customEvent);
                                    }
                                    break;
                                case 'MultiChoiceDataElement':
                                    if (inputValue.dataElementValue !== undefined) {
                                        const /** @type {?} */ customEvent = document.createEvent('Event');
                                        customEvent.initEvent('change', true, true);
                                        if (inputValue.dataElementValue.length !== undefined && inputValue.dataElementValue.length > 0) {
                                            if (!isReset) {
                                                if (Array.isArray(inputValue.dataElementValue)) {
                                                    for (const /** @type {?} */ element in inputValue.dataElementValue) {
                                                        $('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue[element]).prop('checked', true);
                                                        $('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue[element])[0].dispatchEvent(customEvent);
                                                    }
                                                }
                                                else {
                                                    $('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue).prop('checked', true);
                                                    $('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue)[0].dispatchEvent(customEvent);
                                                }
                                            }
                                            else {
                                                if (Array.isArray(inputValue.dataElementValue)) {
                                                    for (const /** @type {?} */ element in inputValue.dataElementValue) {
                                                        $('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue[element]).prop('checked', false);
                                                        customEvent.initEvent('change', true, true);
                                                        $('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue[element])[0].dispatchEvent(customEvent);
                                                    }
                                                }
                                                else {
                                                    $('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue).prop('checked', false);
                                                    $('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue)[0].dispatchEvent(customEvent);
                                                }
                                            }
                                            // if (isReset) {
                                            //   for (const value in inputValue.dataElementValue) {
                                            //     customEvent.initEvent('change', true, true);
                                            //     $('#' + inputValue.dataElementId + '_' + inputValue.dataElementValue[value])[0].dispatchEvent(customEvent);
                                            //   }
                                            // }
                                        }
                                    }
                                    break;
                            }
                        }
                    }
                }
            }
        }
        else {
            throw console.error('Invalid values');
        }
    }
    /**
     * @param {?} endpointId
     * @return {?}
     */
    generateReportText(endpointId) {
        const /** @type {?} */ endpointContent = this.returnEndPointContents(this.xmlContent, '<EndPoint Id="' + endpointId + '">', '</EndPoint>');
        this.parseXml(endpointId, endpointContent);
    }
    /**
     * @return {?}
     */
    generateExecutionHistory() {
        this.executedResultHistories = [];
        let /** @type {?} */ isNonRelevant;
        isNonRelevant = false;
        for (const /** @type {?} */ resultId in this.executedResultIds) {
            for (const /** @type {?} */ nonRelevantDataElement of this.simulatorState.nonRelevantDataElementIds) {
                if (nonRelevantDataElement === resultId) {
                    isNonRelevant = true;
                    break;
                }
                else {
                    isNonRelevant = false;
                }
            }
            if (!isNonRelevant) {
                for (const /** @type {?} */ label in this.executedResultIds[resultId]) {
                    const /** @type {?} */ executedResultHistory = new ExecutedResultHistory();
                    executedResultHistory.resultCondition = label;
                    executedResultHistory.resultValue = this.executedResultIds[resultId][label];
                    this.executedResultHistories.push(executedResultHistory);
                }
            }
        }
        const /** @type {?} */ finalExecution = new FinalExecutedHistory();
        if (this.executedResultHistories.length > 0) {
            finalExecution.executionHistories = this.executedResultHistories;
            finalExecution.resultText = this.mainReportTextObj;
        }
        this.returnExecutionHistory.emit(finalExecution);
    }
    /**
     * @param {?} content
     * @param {?} startToken
     * @param {?} endToken
     * @return {?}
     */
    returnEndPointContents(content, startToken, endToken) {
        let /** @type {?} */ contents;
        let /** @type {?} */ templateSearchIndexPosition = 0;
        while (true) {
            const /** @type {?} */ contentStartPosition = content.indexOf(startToken, templateSearchIndexPosition);
            const /** @type {?} */ contentEndPosition = content.indexOf(endToken, templateSearchIndexPosition);
            if (contentStartPosition >= 0 && contentEndPosition >= 0) {
                const /** @type {?} */ endPosition = contentEndPosition + endToken.length;
                const /** @type {?} */ contentData = content.substring(contentStartPosition, endPosition);
                contents = contentData;
                templateSearchIndexPosition = endPosition + 1;
            }
            else {
                break;
            }
        }
        return contents;
    }
    /**
     * @param {?} endPointId
     * @param {?} endpointContent
     * @return {?}
     */
    parseXml(endPointId, endpointContent) {
        let /** @type {?} */ canInsertText;
        let /** @type {?} */ isSectionIf;
        let /** @type {?} */ selectedElements;
        let /** @type {?} */ executeSectionIfNot;
        let /** @type {?} */ hasSectionNot;
        let /** @type {?} */ executeTemplate;
        let /** @type {?} */ isImpression;
        let /** @type {?} */ isNewTemplate;
        let /** @type {?} */ hasInsertPartial;
        let /** @type {?} */ isMainText;
        const /** @type {?} */ allReportText = [];
        const /** @type {?} */ endpoints = this.Endpoints;
        let /** @type {?} */ templatePartialsText;
        let /** @type {?} */ selectedComparisonValues;
        let /** @type {?} */ findingsText;
        let /** @type {?} */ impressionText;
        let /** @type {?} */ selectedSection;
        let /** @type {?} */ selectedChoiceTexts;
        let /** @type {?} */ textExpressionValue;
        selectedElements = this.simulatorEngineService.getAllDataElementValues();
        templatePartialsText = this.templatePartial;
        selectedComparisonValues = this.comparisonValues;
        selectedChoiceTexts = this.simulatorEngineService.getAllDataElementTexts();
        executeSectionIfNot = false;
        hasInsertPartial = false;
        findingsText = '';
        impressionText = '';
        let /** @type {?} */ isReportText;
        let /** @type {?} */ reportTextContent = '';
        const /** @type {?} */ endpointSax = require('sax'), /** @type {?} */ strict = true, /** @type {?} */ normalize = true, /** @type {?} */ // set to false for html-mode
        trim = true, /** @type {?} */ reportTextParser = endpointSax.parser(strict, trim);
        reportTextParser.onerror = function (e) {
            // an error happened.
            reportTextParser.resume();
        };
        reportTextParser.ontext = function (t) {
            if (t.length > 1) {
                t = t.trim();
            }
            let /** @type {?} */ isTextInserted;
            isTextInserted = false;
            if (executeTemplate) {
                if (!isImpression) {
                    if (canInsertText && hasSectionNot && hasSectionNot !== undefined && executeSectionIfNot) {
                        findingsText = findingsText + t;
                    }
                    else if (canInsertText && isNewTemplate && hasInsertPartial && !isSectionIf) {
                        findingsText = findingsText + t;
                    }
                    else if (canInsertText && !isImpression) {
                        findingsText = findingsText + t;
                    }
                }
                else {
                    if (canInsertText && hasSectionNot && hasSectionNot !== undefined && executeSectionIfNot) {
                        impressionText = impressionText + t;
                    }
                    else if (canInsertText && !hasSectionNot && isImpression) {
                        impressionText = impressionText + t;
                    }
                    else if (canInsertText && isNewTemplate) {
                        impressionText = impressionText + t;
                    }
                }
                if (isReportText && !isTextInserted && isMainText && canInsertText) {
                    reportTextContent = reportTextContent + t;
                }
            }
        };
        reportTextParser.onopentag = function (node) {
            switch (node.name) {
                case 'Label':
                    canInsertText = false;
                    isReportText = false;
                    isMainText = false;
                    break;
                case 'ReportText':
                    if (executeTemplate) {
                        isReportText = true;
                        canInsertText = true;
                        selectedSection = node.attributes.SectionId;
                        impressionText = '';
                        if (node.attributes.SectionId === 'findings' && executeTemplate) {
                            isImpression = false;
                        }
                        else if (node.attributes.SectionId === 'impression' && executeTemplate) {
                            isImpression = true;
                        }
                    }
                    isSectionIf = false;
                    // isMainText = true;
                    break;
                case 'InsertPartial':
                    if (executeTemplate) {
                        generatePartialView(node.attributes.PartialId, isImpression);
                        executeTemplate = true;
                        canInsertText = true;
                        if (isReportText) {
                            hasInsertPartial = true;
                        }
                        else {
                            hasInsertPartial = false;
                        }
                    }
                    else {
                        canInsertText = false;
                    }
                    isReportText = false;
                    isMainText = false;
                    break;
                case 'SectionIfValueNot':
                    if (executeTemplate) {
                        if (Array.isArray(selectedElements[node.attributes.DataElementId])) {
                            for (const /** @type {?} */ comaprisonValue of selectedElements[node.attributes.DataElementId]) {
                                if (comaprisonValue !== node.attributes.ComparisonValue &&
                                    comaprisonValue !== undefined && !isSectionIf) {
                                    canInsertText = true;
                                    executeSectionIfNot = true;
                                    break;
                                }
                                else {
                                    canInsertText = false;
                                    executeSectionIfNot = false;
                                }
                            }
                        }
                        else if (selectedElements[node.attributes.DataElementId] !== node.attributes.ComparisonValue &&
                            selectedElements[node.attributes.DataElementId] !== '--Select--' &&
                            selectedElements[node.attributes.DataElementId] !== undefined &&
                            selectedElements[node.attributes.DataElementId] !== null) {
                            canInsertText = true;
                            executeSectionIfNot = true;
                        }
                        else {
                            canInsertText = false;
                            executeSectionIfNot = false;
                        }
                    }
                    hasSectionNot = true;
                    isMainText = false;
                    break;
                case 'SectionIf':
                    if (selectedElements[node.attributes.DataElementId] !== undefined && selectedElements[node.attributes.DataElementId].length > 0 && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                        isSectionIf = true;
                        canInsertText = true;
                    }
                    else {
                        isSectionIf = false;
                        canInsertText = false;
                    }
                    break;
                case 'SectionIfValue':
                    if (executeTemplate) {
                        if (executeTemplate) {
                            if (Array.isArray(selectedElements[node.attributes.DataElementId])) {
                                for (const /** @type {?} */ comaprisonValue of selectedElements[node.attributes.DataElementId]) {
                                    if (comaprisonValue === node.attributes.ComparisonValue &&
                                        comaprisonValue !== undefined) {
                                        isSectionIf = true;
                                        if (selectedElements[node.attributes.DataElementId] !== undefined && !isSectionIf && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                            findingsText = findingsText + selectedChoiceTexts[node.attributes.DataElementId];
                                        }
                                        canInsertText = true;
                                        break;
                                    }
                                    else {
                                        isSectionIf = false;
                                        canInsertText = false;
                                    }
                                }
                            }
                            else if (selectedElements[node.attributes.DataElementId] === node.attributes.ComparisonValue &&
                                selectedElements[node.attributes.DataElementId] !== undefined) {
                                isSectionIf = true;
                                if (selectedElements[node.attributes.DataElementId] !== undefined && !isSectionIf && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                    findingsText = findingsText + selectedChoiceTexts[node.attributes.DataElementId];
                                }
                                canInsertText = true;
                            }
                            else {
                                canInsertText = false;
                            }
                        }
                        break;
                    }
                    isMainText = false;
                    break;
                case 'InsertValue':
                    if (executeTemplate) {
                        isReportText = false;
                        const /** @type {?} */ choiceText = selectedChoiceTexts[node.attributes.DataElementId];
                        if (node.attributes.Id === 'findings' || canInsertText) {
                            if (selectedElements[node.attributes.DataElementId] !== undefined && hasSectionNot && executeSectionIfNot) {
                                if (isImpression) {
                                    if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                    }
                                    else {
                                        getTextExpressionValue(selectedElements[node.attributes.DataElementId]);
                                        impressionText = impressionText + (Array.isArray(selectedElements[node.attributes.DataElementId]) ? selectedElements[node.attributes.DataElementId].join(', ') : textExpressionValue);
                                    }
                                }
                                else {
                                    if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        findingsText = findingsText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                    }
                                    else {
                                        getTextExpressionValue(selectedElements[node.attributes.DataElementId]);
                                        findingsText = findingsText + (Array.isArray(selectedElements[node.attributes.DataElementId]) ? selectedElements[node.attributes.DataElementId].join(', ') : textExpressionValue);
                                    }
                                }
                            }
                            else if (selectedElements[node.attributes.DataElementId] !== undefined && !hasSectionNot) {
                                if (isImpression) {
                                    if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                    }
                                    else {
                                        getTextExpressionValue(selectedElements[node.attributes.DataElementId]);
                                        impressionText = impressionText + (Array.isArray(selectedElements[node.attributes.DataElementId]) ? selectedElements[node.attributes.DataElementId].join(', ') : textExpressionValue);
                                    }
                                }
                                else {
                                    if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        findingsText = findingsText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                    }
                                    else {
                                        getTextExpressionValue(selectedElements[node.attributes.DataElementId]);
                                        findingsText = findingsText + (Array.isArray(selectedElements[node.attributes.DataElementId]) ? selectedElements[node.attributes.DataElementId].join(', ') : textExpressionValue);
                                    }
                                }
                            }
                            if (isImpression) {
                                canInsertText = true;
                            }
                        }
                        isMainText = false;
                        break;
                    }
            }
            executeTemplate = true;
            isNewTemplate = true;
        };
        reportTextParser.onclosetag = function (node) {
            switch (node) {
                case 'SectionIfValueNot':
                    executeSectionIfNot = false;
                    hasSectionNot = false;
                    if (isSectionIf) {
                        canInsertText = true;
                    }
                    break;
                case 'TemplatePartial':
                    isNewTemplate = false;
                    canInsertText = false;
                    executeTemplate = false;
                    break;
                case 'ReportText':
                    // isImpression = false;
                    if (!hasInsertPartial && !isImpression) {
                        const /** @type {?} */ reportTextObj = new AllReportText();
                        reportTextObj.sectionId = 'findings';
                        reportTextObj.reportText = findingsText;
                        allReportText[reportTextObj.sectionId] = reportTextObj;
                    }
                    if (impressionText !== '' && impressionText !== undefined) {
                        const /** @type {?} */ reportTextObj = new AllReportText();
                        reportTextObj.sectionId = selectedSection;
                        reportTextObj.reportText = impressionText;
                        allReportText[reportTextObj.sectionId] = reportTextObj;
                    }
                    hasInsertPartial = false;
                    break;
                case 'SectionIf':
                    isSectionIf = false;
                    canInsertText = true;
                    break;
                case 'InsertPartial':
                    canInsertText = true;
                    break;
                case 'InsertValue':
                    if ((hasSectionNot && executeSectionIfNot || !hasSectionNot)) {
                        canInsertText = true;
                    }
                    break;
                case 'SectionIfValue':
                    canInsertText = true;
                    break;
            }
        };
        reportTextParser.onend = function () {
            // parser stream is done, and ready to have more stuff written to it.
            // if (impressionText !== '' && impressionText !== undefined) {
            // const reportTextObj: AllReportText = new AllReportText();
            // reportTextObj.sectionId = selectedSection;
            // reportTextObj.reportText = impressionText;
            // allReportText[reportTextObj.sectionId] = reportTextObj;
            // }
        };
        reportTextParser.write(endpointContent).onend();
        /**
         * @param {?} textExpression
         * @return {?}
         */
        function getTextExpressionValue(textExpression) {
            if (textExpression.indexOf('{') === 0 && (textExpression.indexOf('}') > 1)) {
                const /** @type {?} */ subString = textExpression.substr(textExpression.indexOf('{') + 1, textExpression.indexOf('}') - 1);
                getTextExpressionValue(selectedElements[subString]);
            }
            else {
                textExpressionValue = textExpression;
            }
        }
        /**
         * @param {?} partialViewId
         * @param {?} isImpressionTemplate
         * @return {?}
         */
        function generatePartialView(partialViewId, isImpressionTemplate) {
            // this.templateIds = [];
            const /** @type {?} */ sax = require('sax'), /** @type {?} */ parser = sax.parser(strict, trim);
            parser.onerror = function (e) {
                // an error happened.
                // parser.resume();
            };
            parser.ontext = function (t) {
                if (executeTemplate) {
                    if (!isImpressionTemplate) {
                        if (canInsertText && hasSectionNot && hasSectionNot !== undefined && executeSectionIfNot) {
                            findingsText = findingsText + t;
                        }
                        else if (canInsertText && !hasSectionNot && isImpression) {
                            findingsText = findingsText + t;
                        }
                        else if (canInsertText && isNewTemplate) {
                            findingsText = findingsText + t;
                        }
                    }
                    else {
                        if (canInsertText && hasSectionNot && hasSectionNot !== undefined && executeSectionIfNot) {
                            impressionText = impressionText + t;
                        }
                        else if (canInsertText && !hasSectionNot && isImpression) {
                            impressionText = impressionText + t;
                        }
                        else if (canInsertText && isNewTemplate) {
                            impressionText = impressionText + t;
                        }
                    }
                }
            };
            parser.onopentag = function (node) {
                switch (node.name) {
                    case 'Label':
                        canInsertText = false;
                        break;
                    case 'EndPoint':
                        if (node.attributes.Id !== '') {
                            canInsertText = true;
                            isImpression = true;
                        }
                        else {
                            canInsertText = false;
                            isImpression = false;
                        }
                        break;
                    case 'InsertPartial':
                        canInsertText = false;
                        break;
                    case 'ReportText':
                        canInsertText = true;
                        break;
                    case 'TemplatePartial':
                        hasSectionNot = false;
                        executeSectionIfNot = false;
                        if (node.attributes.Id === partialViewId) {
                            executeTemplate = true;
                            canInsertText = true;
                            isNewTemplate = true;
                            break;
                        }
                        else {
                            isNewTemplate = false;
                            executeTemplate = false;
                        }
                        break;
                    case 'SectionIfValueNot':
                        if (executeTemplate) {
                            if (Array.isArray(selectedElements[node.attributes.DataElementId])) {
                                for (const /** @type {?} */ comaprisonValue of selectedComparisonValues[node.attributes.DataElementId + 'ComparisonValue']) {
                                    if (comaprisonValue !== node.attributes.ComparisonValue &&
                                        comaprisonValue !== undefined && !isSectionIf) {
                                        canInsertText = true;
                                        executeSectionIfNot = true;
                                        break;
                                    }
                                    else {
                                        canInsertText = false;
                                        executeSectionIfNot = false;
                                    }
                                }
                            }
                            else if (selectedElements[node.attributes.DataElementId] !== node.attributes.ComparisonValue &&
                                selectedElements[node.attributes.DataElementId] !== '--Select--' &&
                                selectedElements[node.attributes.DataElementId] !== undefined &&
                                selectedElements[node.attributes.DataElementId] !== null) {
                                canInsertText = true;
                                executeSectionIfNot = true;
                            }
                            else {
                                canInsertText = false;
                                executeSectionIfNot = false;
                            }
                        }
                        hasSectionNot = true;
                        break;
                    case 'SectionIf':
                        if (selectedElements[node.attributes.DataElementId] !== undefined && selectedElements[node.attributes.DataElementId].length > 0 && (!hasSectionNot || (hasSectionNot && executeSectionIfNot))
                            && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                            isSectionIf = true;
                            canInsertText = true;
                        }
                        else {
                            isSectionIf = false;
                            canInsertText = false;
                        }
                        break;
                    case 'SectionIfValue':
                        if (executeTemplate) {
                            if (Array.isArray(selectedElements[node.attributes.DataElementId])) {
                                for (const /** @type {?} */ comaprisonValue of selectedComparisonValues[node.attributes.DataElementId + 'ComparisonValue']) {
                                    if (comaprisonValue === node.attributes.ComparisonValue &&
                                        comaprisonValue !== undefined) {
                                        isSectionIf = true;
                                        if (selectedElements[node.attributes.DataElementId] !== undefined && !isSectionIf && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                            findingsText = findingsText + selectedChoiceTexts[node.attributes.DataElementId];
                                        }
                                        canInsertText = true;
                                        break;
                                    }
                                    else {
                                        isSectionIf = false;
                                        canInsertText = false;
                                    }
                                }
                            }
                            else if (selectedElements[node.attributes.DataElementId] === node.attributes.ComparisonValue &&
                                selectedElements[node.attributes.DataElementId] !== undefined) {
                                isSectionIf = true;
                                if (selectedElements[node.attributes.DataElementId] !== undefined && !isSectionIf && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                    findingsText = findingsText + selectedChoiceTexts[node.attributes.DataElementId];
                                }
                                canInsertText = true;
                            }
                            else {
                                canInsertText = false;
                            }
                        }
                        break;
                    case 'InsertValue':
                        if (executeTemplate) {
                            const /** @type {?} */ choiceText = selectedChoiceTexts[node.attributes.DataElementId];
                            if (node.attributes.Id === 'findings' || canInsertText) {
                                if (isImpression) {
                                    canInsertText = true;
                                    if (selectedElements[node.attributes.DataElementId] !== undefined && hasSectionNot && executeSectionIfNot && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined) {
                                            impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                        else {
                                            impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                    }
                                    else if (selectedElements[node.attributes.DataElementId] !== undefined && !hasSectionNot && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined) {
                                            impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                        else {
                                            if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                                impressionText = impressionText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                            }
                                        }
                                    }
                                }
                                else {
                                    if (selectedElements[node.attributes.DataElementId] !== undefined && hasSectionNot && executeSectionIfNot && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined) {
                                            findingsText = findingsText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                    }
                                    else if (selectedElements[node.attributes.DataElementId] !== undefined && !hasSectionNot && selectedChoiceTexts[node.attributes.DataElementId] !== 'Other, please specify…') {
                                        if (selectedChoiceTexts[node.attributes.DataElementId] !== undefined) {
                                            findingsText = findingsText + (Array.isArray(choiceText) ? choiceText.join(', ') : choiceText);
                                        }
                                    }
                                }
                            }
                            break;
                        }
                }
            };
            parser.onclosetag = function (node) {
                switch (node) {
                    case 'SectionIfValueNot':
                        executeSectionIfNot = false;
                        hasSectionNot = false;
                        if (isSectionIf) {
                            canInsertText = true;
                        }
                        break;
                    case 'TemplatePartial':
                        isNewTemplate = true;
                        canInsertText = false;
                        executeTemplate = true;
                        break;
                    case 'InsertPartial':
                        canInsertText = true;
                        break;
                    case 'SectionIf' || 'SectionIfValue':
                        isSectionIf = false;
                        break;
                }
            };
            parser.onend = function () {
                // parser stream is done, and ready to have more stuff written to it.
                const /** @type {?} */ reportTextObj = new AllReportText();
                reportTextObj.sectionId = 'findings';
                reportTextObj.reportText = findingsText;
                allReportText[reportTextObj.sectionId] = reportTextObj;
            };
            parser.write(templatePartialsText).onend();
        }
        this.mainReportTextObj = new MainReportText();
        this.mainReportTextObj.reportTextMainContent = reportTextContent;
        this.mainReportTextObj.allReportText = allReportText;
        this.returnReportText.emit(this.mainReportTextObj);
    }
}
AssistDataElementComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-data-element',
                template: `
    <ng-container *ngFor="let DataElement of dataElements">
        <ng-container *ngIf="(DataElement.dataElementType == 'ChoiceDataElement' || DataElement.dataElementType == 'NumericDataElement' || DataElement.dataElementType == 'IntegerDataElement' || DataElement.dataElementType == 'MultiChoiceDataElement') ">
            <ng-container *ngIf="DataElement.isVisible">
                <div id="div_{{DataElement.id}}" class="row bottom-margin"> 
                    <ng-container *ngIf="DataElement.dataElementType == 'ChoiceDataElement'">
                        <acr-assist-choice-element [choiceDataElement]='DataElement' [imagePath]='imagePath' (returnChoiceElement)='choiceSelected($event)'></acr-assist-choice-element>
                    </ng-container>          
    
                    <ng-container *ngIf="DataElement.dataElementType == 'MultiChoiceDataElement'">
                        <acr-assist-multi-choice-element [multiChoiceElement]='DataElement' [imagePath]='imagePath'  (returnMultiChoice)='multiSelected($event)'></acr-assist-multi-choice-element>
                    </ng-container>
    
                    <ng-container *ngIf="DataElement.dataElementType == 'NumericDataElement' || DataElement.dataElementType == 'IntegerDataElement'">
                        <acr-assist-numeric-element [numericDataElement]='DataElement' [imagePath]='imagePath' (returnNumericElement)='numericSelected($event)'></acr-assist-numeric-element>
                    </ng-container>
                </div>  
            </ng-container>        
        </ng-container>
    </ng-container>
  `,
                styles: [`
    input[type=file].inputfile {
      width: 0.1px;
      height: 0.1px;
      opacity: 0;
      overflow: hidden;
      position: absolute;
      z-index: -1;
      margin: 0;
    }

    input[type=file].inputfile+label:active,
    input[type=file].inputfile+label {
      max-width: 100%;
      font-size: 1.5rem;
      font-weight: 700;
      text-overflow: ellipsis;
      white-space: nowrap;
      cursor: pointer;
      display: inline-block;
      overflow: hidden;
      display: inline-block;
      color: #f1e5e6;
      background-color: #d3394c;
      text-indent: 0px;
      width: 130px;
    }

    input[type=file].inputfile+label:hover {
      background-color: #722040;
    }

    input[type=file].inputfile+label {
      cursor: pointer;
      /* "hand" cursor */
    }

    input[type=file].inputfile:hover+label {
      outline: 1px dotted #000;
      outline: -webkit-focus-ring-color auto 5px;
    }

    .right-fixed {
      position: fixed;
      right: 0px;
    }

    .row.report-text-top-margin.right-align{
      width: 80%;
      margin-left: 135px;
    }

    /* Master Styles */

    h1 {
      color: #369;
      font-family: Arial, Helvetica, sans-serif;
      font-size: 250%;
    }

    h2,
    h3 {
      color: #444;
      font-family: Arial, Helvetica, sans-serif;
      font-weight: lighter;
    }

    body {
      margin: 2em;
    }


    /*Apply background color for div having checked radio button*/

    input[type="radio"]:checked+div {
      background-color: #1e89b5 !important;
      border: 1px solid #9b9b9b;
      color: #ffffff;
    }


    /*Apply background color for div having no checked radio button*/

    input[type="radio"]+div {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
    }

    .checkbox>label {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
      height: auto;
      line-height: 25px;
      width: 100%;
      font-weight: bold;
    }

    .checkbox>label>input[type="checkbox"] {
      margin-left: -15px;
      margin-top: 6px;
    }

    .full-width span {
      font-weight: bold;
    }


    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;
        border: 1px solid #9B9B9B;
        }*/

    .DEElement {
      color: #363636;
      letter-spacing: -0.37px;
      word-wrap: break-word;
    }

    .DEValues {
      /*font-size: 12px;*/
      color: #4a4a4a;
      letter-spacing: -0.29px;
      width: 100%;
      min-width: 180px;
      max-width: 280px;
    }


    /* CHECKBOX OVERWRITE STYLES */

    .rad {
      cursor: pointer;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
      -webkit-user-select: none;
      -webkit-touch-callout: none;
    }

    .rad>input {
      /* HIDE ORG RADIO & CHECKBOX */
      visibility: hidden;
      position: absolute;
    }

    [type="radio"]+span::before {
      content: "";
      display: inline-block;
      width: 9px;
      height: 9px;
      border-radius: 1em;
      border: 0.1px solid #fff;
      -webkit-box-shadow: 0 0 0 1px #57aed0;
              box-shadow: 0 0 0 1px #57aed0;
      margin-right: 4px;
      -webkit-transition: 0.5s ease all;
      transition: 0.5s ease all;
      margin-left: -15px;
    }

    [type="radio"]:checked+span::before {
      background: #57aed0;
      -webkit-box-shadow: 0 0 0 2px #57aed0;
              box-shadow: 0 0 0 2px #57aed0;
      margin-top: auto;
      /*margin-left:-15px;*/
    }

    .reportText {
      font-size: 14px;
      color: #363636;
      letter-spacing: -0.49px;
      margin-top: 5px;
    }

    button:hover,
    button:focus,
    button.active,
    .btn-default:hover,
    .btn-default:focus,
    .item.active,
    .btn-default.active {
      background: #1e89b5 !important;
      color: #ffffff !important;
    }

    .hideInput {
      visibility: hidden;
      margin-left: 5px !important;
    }

    .panel {
      background-color: transparent;
    }

    .logo {
      height: 30px;
      width: 250px;
    }

    .navbar-blue {
      background-color: #00205b !important;
      color: #fff;
    }

    .navbar-brand-text {
      font-size: 30px;
      color: #fff;
      font-weight: normal;
      margin-top: 10px;
    }

    .close {
      margin-top: -20px !important;
    }


    /*.full-width {
            width: 320px !important;
        }*/

    #myNav.affix {
      width: 483px;
      top: 100;
    }

    #Can-ImgMap {
      pointer-events: none;
      position: absolute;
      opacity: 0.5;
    }


    /* Styles for Assist bootstrap*/

    .control-label {
      text-align: left !important;
    }

    .box-style {
      text-decoration: none;
      color: #363636 !important;
      border-radius: 3px;
      padding: 5px;
      font-weight: bold !important;
      width: 75%;
    }

    .findings {
      color: #ffffff !important;
      background-color: #5295b1 !important;
      border-color: #5295b1 !important;
      background-image: none !important;
      font-weight: bold;
      text-transform: capitalize;
      height: 45px;
      font-size: 16px;
      text-align: left;
    }

    .table-row {
      display: table-row;
      width: auto;
      clear: both;
    }

    .table-cell {
      display: table-cell;
      width: 475px;
      font-size: 12px;
      background-color: transparent;
      color: black;
      height: 25px;
      line-height: 25px;
      padding: 1px;
    }

    .imgMap-table-cell {
      width: 10% !important;
      vertical-align: middle;
    }

    .panel-default {
      min-width: 100%;
    }

    #footer {
      position: fixed;
      bottom: 0;
    }

    .row-style {
      bottom: 5px;
      position: fixed;
      top: 55px;
      overflow: auto;
      width: 100%;
    }

    .modal-dialog {
      top: 100px;
      margin-left: 50% !important;
    }

    .required-field {
      /* border: 1px solid red; */
      /* border-radius: 5px; */
      padding: 5px;
      font-size: 16px;
      color: red;
      /* width: 120px; */
      display: inline-block;
      font-weight: bold;
    }

    .xml-only-msg {
      border: 1px solid red;
      border-radius: 5px;
      padding: 5px;
      font-size: 12px;
      color: white;
      width: 223px;
      display: inline-block;
      font-weight: bold;
    }

    @media (min-width: 400px) and (max-width: 1024px) {
      .xml-only-msg {
        width: 120px;
      }
    }

    @media (max-width: 475px)  {
      .xml-only-msg {
        color: #000000
      }
    }
    .col-per-10 {
      border: 1px solid blue;
      padding: 15px 10px 15px 10px;
      border-radius: 10px;
      height: auto;
      width: 10%;
      float: left;
      position: fixed;
      min-height: 1px;
    }

    .btn-group>.btn:first-child {
      margin-left: 0;
      width: 165px;
      margin-top: 10px;
    }

    .col-md-10 {
      left: 200px;
    }

    .module-header {
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
      margin-left: -135px;
      margin-top: -15px;
      font-size: 14px;
      font-weight: bold;
      color: #363636;
    }

    .btn-group-justified {
      padding-left: 15px;
    }

    select {
      height: 35px;
      border-radius: 5px;
      max-width: 280px;
      width: 100%;
    }

    .findings select{
      max-width: 150px;
      margin-top: -3px;
    }
    .fixed-keydiagram {
      position: fixed !important;
      float: right;
      padding-right: 0px !important;
      margin-right: 10px;
      padding-left: 25px !important;
    }

    .center-align {
      text-align: center;
      width: 160px !important;
      padding: 0px !important;
    }

    .center-align div {
      width: 200px;
      margin-left: -10px;
    }

    .findings div {
      color: #363636 !important;
      margin-left: 100px !important;
      margin-top: -23.5px !important;
      height: 30px;
    }

    .findings div select {
      text-transform: capitalize;
    }

    .modal-backdrop {
      top: 10000px !important;
    }

    .tooltip-arrow {
      display: none !important;
    }

    .other-reportSection {
      font-weight: normal;
      margin-top: -10px;
      margin-left: 15px;
    }

    a:hover {
      text-decoration: none !important;
    }

    .no-btm-margin-table {
      margin-bottom: 0px !important;
    }

    .adjust-diagram {
      margin-top: 56px;
      right: 20px !important;
    }

    .adjust-diagram-image {
      top: 0px !important;
      margin-top: 0px !important;
    }

    .reportText-panel {
      width: 90%;
      margin-left: 2%;
    }

    .reportText-body {
      margin-left: 2%;
    }

    .top-Index {
      z-index: 99999 !important;
    }


    /* Master Styles */

    h1 {
      color: #369;
      font-family: Arial, Helvetica, sans-serif;
      font-size: 250%;
    }

    h2,
    h3 {
      color: #444;
      font-family: Arial, Helvetica, sans-serif;
      font-weight: lighter;
    }

    .div-simulator-container {
      margin: 0;
    }


    /*Apply background color for div having checked radio button*/

    .div-simulator-container input[type="radio"]:checked+div {
      background-color: #1e89b5 !important;
      border: 1px solid #9b9b9b;
      color: #ffffff;
    }


    /*Apply background color for div having no checked radio button*/

    .div-simulator-container input[type="radio"]+div {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
    }

    .div-simulator-container .checkbox>label {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
      height: 25px;
      line-height: 25px;
    }

    .div-simulator-container .checkbox>label>input[type="checkbox"] {
      margin-left: -15px;
      margin-top: 6px;
    }

    .div-simulator-container .full-width span {
      font-weight: bold;
    }


    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;
        border: 1px solid #9B9B9B;
        }*/

    .div-simulator-container .DEElement {
      color: #363636;
      letter-spacing: -0.37px;
      word-wrap: break-word;
    }

    .div-simulator-container .DEValues {
      /*font-size: 12px;*/
      color: #4a4a4a;
      letter-spacing: -0.29px;
    }


    /* CHECKBOX OVERWRITE STYLES */

    .div-simulator-container .rad {
      cursor: pointer;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
      -webkit-user-select: none;
      -webkit-touch-callout: none;
    }

    .div-simulator-container .rad>input {
      /* HIDE ORG RADIO & CHECKBOX */
      visibility: hidden;
      position: absolute;
    }

    .div-simulator-container [type="radio"]+span::before {
      content: "";
      display: inline-block;
      width: 9px;
      height: 9px;
      border-radius: 1em;
      border: 0.1px solid #fff;
      -webkit-box-shadow: 0 0 0 1px #57aed0;
              box-shadow: 0 0 0 1px #57aed0;
      margin-right: 4px;
      -webkit-transition: 0.5s ease all;
      transition: 0.5s ease all;
      margin-left: -15px;
    }

    [type="radio"]:checked+span::before {
      background: #57aed0;
      -webkit-box-shadow: 0 0 0 2px #57aed0;
              box-shadow: 0 0 0 2px #57aed0;
      margin-top: auto;
      /*margin-left:-15px;*/
    }

    .div-simulator-container .reportText {
      font-size: 14px;
      color: #363636;
      letter-spacing: -0.49px;
    }

    .div-simulator-container button:hover,
    .div-simulator-container button:focus,
    .div-simulator-container button.active,
    .div-simulator-container .btn-default:hover,
    .btn-default:focus,
    .div-simulator-container .item.active,
    .div-simulator-container .btn-default.active {
      background: #1e89b5 !important;
      color: #ffffff !important;
    }

    .div-simulator-container .hideInput {
      visibility: hidden;
      margin-left: 5px !important;
    }

    .div-simulator-container .panel {
      background-color: transparent;
    }

    .logo {
      height: 30px;
      width: 250px;
    }

    .navbar-blue {
      background-color: #00205b !important;
      color: #fff;
    }

    .navbar-brand-text {
      font-size: 30px;
      color: #fff;
      font-weight: normal;
      margin-top: 10px;
    }

    .div-simulator-container .close {
      margin-top: -20px !important;
    }


    /*.full-width {
            width: 320px !important;
        }*/

    #myNav.affix {
      width: 483px;
      top: 100;
    }

    #Can-ImgMap {
      pointer-events: none;
      position: absolute;
      opacity: 0.5;
    }


    /* Styles for Assist bootstrap*/

    .div-simulator-container .control-label {
      text-align: left !important;
    }

    .div-simulator-container .box-style {
      text-decoration: none;
      color: #363636 !important;
      border-radius: 3px;
      padding: 5px;
      font-weight: bold !important;
      width: 75%;
    }

    .div-simulator-container .findings {
      color: #ffffff !important;
      background-color: #5295b1 !important;
      border-color: #5295b1 !important;
      background-image: none !important;
      font-weight: bold;
      text-transform: capitalize;
      height: 40px;
    }

    .div-simulator-container .table-row {
      display: table-row;
      width: auto;
      clear: both;
    }

    .div-simulator-container .table-cell {
      display: table-cell;
      width: 475px;
      font-size: 12px;
      background-color: transparent;
      color: black;
      height: 25px;
      line-height: 25px;
      padding: 1px;
      border-bottom: none;
    }

    .div-simulator-container .imgMap-table-cell {
      width: 10% !important;
      vertical-align: middle;
    }

    .div-simulator-container .panel-default {
      min-width: 600px;
      margin: 0 !important;
      background-color: white;
    }

    .div-simulator-container .footerBlock {
      position: fixed;
      bottom: 55px;
    }

    .div-simulator-container .row-style {
      bottom: 5px;
      position: fixed;
      top: 55px;
      overflow: auto;
      width: 100%;
    }

    .div-simulator-container .modal-dialog {
      top: 100px;
      /*margin-left: 50% !important;*/
      margin-left: 0 !important;
    }

    .div-simulator-container .required-field {
      border: 1px solid #edd1d1;
      border-radius: 5px;
      padding: 5px;
      font-size: 12px;
      color: #cd5c5c;
      width: 125px;
    }

    .div-simulator-container .col-per-10 {
      border: 1px solid blue;
      padding: 15px 10px 15px 10px;
      border-radius: 10px;
      height: auto;
      width: 10%;
      float: left;
      position: fixed;
      min-height: 1px;
    }

    .div-simulator-container .btn-group>.btn:first-child {
      margin-left: 0;
      width: 165px;
      margin-top: 10px;
    }

    .div-simulator-container .col-md-10 {
      left: 200px;
    }

    .div-simulator-container .module-header {
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
      margin-left: -135px;
      margin-top: -15px;
      font-size: 14px;
      font-weight: bold;
      color: #363636;
    }

    .div-simulator-container .btn-group-justified {
      padding-left: 15px;
    }

    .div-simulator-container select {
      height: 28px;
      border-radius: 5px;
    }

    .div-simulator-container .panel-body {
      padding: 10px !important;
    }

    .div-simulator-container .fixed-keydiagram {
      position: fixed !important;
      float: right;
      padding-right: 0px !important;
      margin-right: 10px;
      padding-left: 25px !important;
    }

    .div-simulator-container .center-align {
      text-align: center;
      width: 160px !important;
      padding: 0px !important;
    }

    .div-simulator-container .center-align div {
      width: 200px;
      margin-left: -10px;
    }

    .div-simulator-container .findings div {
      color: #363636 !important;
      margin-left: 97px !important;
      margin-top: -29.5px !important;
      height: 30px;
    }

    .div-simulator-container .findings div select {
      text-transform: capitalize;
    }

    .div-simulator-container .modal-backdrop {
      top: 10000px !important;
    }

    .div-simulator-container .tooltip-arrow {
      display: none !important;
    }

    .div-simulator-container .other-reportSection {
      font-weight: normal;
      margin-top: -10px;
      margin-left: 15px;
    }

    .div-simulator-container a:hover {
      text-decoration: none !important;
    }

    .div-simulator-container .no-btm-margin-table {
      margin-bottom: 0px !important;
    }

    .div-simulator-container .adjust-diagram {
      margin-top: 56px;
      right: 20px !important;
    }

    .adjust-diagram-image {
      top: 0px !important;
      margin-top: 0px !important;
    }

    @media only screen and (min-width: 1224px) {
      .tab-content {
        padding: 5px;
      }
    }

    @media (min-width: 768px) {
      #page-content-wrapper {
        padding: 0px 20px;
        margin-top: 15px;
      }
    }

    #sidebar-wrapper {
      left: 175px;
      margin-left: -175px;
    }

    #rowContent {
      padding-bottom: 120px;
    }

    @media only screen and (min-width: 1224px) {
      .fixed-reportText {
        width: 1064px;
      }
    }

    @media only screen and (min-width: 1824px) {
      .fixed-reportText {
        width: 1260px;
      }
    }

    @media only screen and (min-width: 1224px) {
      .modal-lg {
        left: 0;
        /* left: -250px; */
      }
    }

    .form-group {
      margin-bottom: 15px;
    }

    .control-label {
      margin-top: 0;
      margin-left: 0;
    }

    .div-simulator-container .checkbox>label {
      height: 30px;
      line-height: 30px;
    }

    .div-simulator-container .checkbox>label>input[type="checkbox"] {
      margin-top: 8px;
    }

    .div-simulator-container select {
      height: 30px;
      border-radius: 5px;
      font-size: 12px;
      width: 280px;
    }

    .div-simulator-container .input-group {
      width: 280px;
    }

    .div-simulator-container .input-group .form-control {
      border-radius: 5px;
      -webkit-box-shadow: none;
              box-shadow: none;
      border: 1px solid #969696;
    }

    .div-simulator-container .imgMap-table-cell {
      padding-left: 10px;
    }

    @media (min-width: 1224px) {
      .modal-lg {
        width: 630px;
      }
    }

    .tableImagemap {
      table-layout: fixed;
    }

    @media (min-width: 1850px) {
      .modal-lg {
        width: 900px;
      }
      .tableImagemap {
        table-layout: inherit;
      }
    }

    .col-centered {
      float: none;
      margin: 0 auto;
    }

    .checkbox {
      max-width: 280px;
    }

    [type="number"] {
      max-width: 280px;
      /*margin-left: -15px;*/
    }

    .input-group {
      width: 100%;
    }

    @media (min-width:1441px) {
      .DEValues {
        /*min-width: 280px;
        max-width: 280px;*/
        height: auto;
      }
    }

    @media (max-width:1024px) {
      .adjust-diagram-image {
        width: 50%;
      }
    }

    @media (min-width:1921px) {
      .adjust-diagram-image {
        width: 50%;
      }
    }

    .row {
      font-weight: bold;
    }

    .carousel-item.item img {
      width: 100% !important;
    }

    .carousel-indicators {
      display: none !important;
    }

    .display-inline {
      display: inline;
    }

    .font-weight-normal {
      font-weight: normal;
    }

    .font-weight-bold {
      font-weight: bold;
    }

    .color-white {
      color: #ffffff;
    }

    .bottom-margin{
      margin-bottom: 25px;
    }

    .reportText-content {
      white-space: pre-line; 
      font-weight: bold;
      margin: -40px 0px;
      height: -webkit-fit-content;
      height: -moz-fit-content;
      height: fit-content;
    }

    .no-bottom-margin {
      margin-bottom: 0px !important;
    }
    .reportText-main-content{
      font-size: 16px;
    }

    .split-length-word {
      word-break: break-all;
      text-align: left;
      margin: 0px 0px;
    }

    .img-max-width {
      width: 70% !important;
    }

    .keydiagram {
      text-align: center;
      margin-top: 10px;
    }

    .report-text-top-margin {
      margin-top: 15px;
    }

    input[type=number]::-webkit-inner-spin-button, 
    input[type=number]::-webkit-outer-spin-button { 
        -webkit-appearance: none;
        -moz-appearance: none;
        margin: 0; 
    }

    input[type="number"]:hover,
    input[type="number"]:focus,
    input[type="number"] {
        -moz-appearance: textfield;
    }

    .numeric-align {
      display: inline;
    }

    input[type="text"] {
    max-width: 280px;
    margin-left: 0px !important;
    border-radius: 5px !important;
    text-transform: capitalize;
    }

    .all-reporttext-heading {
      text-decoration: underline;
      font-weight: bold;
      text-transform: capitalize;
      font-size: 18px;
      margin-top: -50px;
      text-align: left;
    }

    .all-reportText-content {
      margin-top: -10px;
    }

    .split-length-word.all-reportText-content {
      text-align: justify;
      word-break: unset;
    }

    .fixed-report-text-sidebar {
      position: fixed;
      right: 0;
      width: 45%;
    }

    .fixed-report-text-footer {
      position: fixed;
      left: 15 !important;
      bottom: 0;
      background-color: white;
    }

    .left-margin {
      margin-left: 60px;
      width: 90%;
    }

    .overflow {
      /* max-height: 500px; */
      overflow-x: hidden;
    }

    @media (max-width: 650px) {
  

      .left-margin {
        margin-left: 20px;
      }

      .keydiagram {
        width: 100%;
        margin-left: 4%;
      } 
      .row.content-area {
        padding: 0px 5px;
      }

      .text-right.border-0 > h4 {
        padding-right: 20px;
      }

      .keydiagram {
        width: 100%;
        text-align: center;
        margin-left: 0px !important;
      }
    }
    @media (max-width: 1024px) {
      .keydiagram {
        width: 100%;
        margin-left: 9%;
      }
      .img-max-width {
        width: 80% !important;
      }
    }
    @media (max-width: 1023px) {
      .fixed-report-text-sidebar {
        position: relative;
      }
    }

    .upload-button-size {
    	font-size: 100% !important;
    }
  
  `]
            },] },
];
/**
 * @nocollapse
 */
AssistDataElementComponent.ctorParameters = () => [
    { type: SimulatorEngineService, },
];
AssistDataElementComponent.propDecorators = {
    'dataElements': [{ type: Input },],
    'imagePath': [{ type: Input },],
    'Endpoints': [{ type: Input },],
    'templatePartial': [{ type: Input },],
    'endPointXMLString': [{ type: Input },],
    'xmlContent': [{ type: Input },],
    'returnReportText': [{ type: Output },],
    'returnExecutionHistory': [{ type: Output },],
    'isReset': [{ type: Input },],
    'inputValues': [{ type: Input },],
};
class ChoiceElement {
}
class NumericElement {
}
class MultiChoiceElement {
}

class MainReportText {
}
class AllReportText {
}
class ExecutedResultHistory {
}
class FinalExecutedHistory {
}

class HintDiagramComponent {
    constructor() {
        this.activeSlideIndex = 0;
    }
    /**
     * @return {?}
     */
    resetCarouselIndex() {
        this.activeSlideIndex = 0;
    }
}
HintDiagramComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-hint-diagram',
                template: `
    <ng-container *ngIf="DataElement !== undefined">



    <button type="button" class="btn btn-default btn-xs" data-toggle="modal" attr.data-target="#{{'diag_'+DataElement.id}}" (click)="resetCarouselIndex()">
      <span class=" glyphicon glyphicon-cd" aria-hidden="true" data-toggle="tooltip"  data-placement="right" title="Hint Diagrams"></span>

    </button>
    <div class="modal fade adjust-diagram " tabindex="-1" role="dialog" attr.id="{{'diag_'+DataElement.id}}" aria-labelledby="mySmallModalLabel">
        <div class="modal-dialog modal-lg adjust-diagram-image " role="document">
            <div class="modal-content">
                <div class="modal-header">
                    <h4 class="modal-title">
                        {{DataElement.label}}
                    </h4>
                    <button type="button" class="close" data-dismiss="modal" aria-label="Close"><span aria-hidden="true">×</span></button>
                </div>
                <ng-container>
                    <carousel [(activeSlide)]="activeSlideIndex" interval="false">
                        <ng-container *ngFor="let diag of DataElement.diagrams ">
                            <slide>
                                <img  src="{{imagePath}}/{{diag.location}}" alt="Image Not Available!!!">
                            </slide>
                        </ng-container>  
                    </carousel>
                </ng-container>
            </div>
        </div>
    </div>
    </ng-container>
  `,
                styles: [`
    input[type=file].inputfile {
      width: 0.1px;
      height: 0.1px;
      opacity: 0;
      overflow: hidden;
      position: absolute;
      z-index: -1;
      margin: 0;
    }

    input[type=file].inputfile+label:active,
    input[type=file].inputfile+label {
      max-width: 100%;
      font-size: 1.5rem;
      font-weight: 700;
      text-overflow: ellipsis;
      white-space: nowrap;
      cursor: pointer;
      display: inline-block;
      overflow: hidden;
      display: inline-block;
      color: #f1e5e6;
      background-color: #d3394c;
      text-indent: 0px;
      width: 130px;
    }

    input[type=file].inputfile+label:hover {
      background-color: #722040;
    }

    input[type=file].inputfile+label {
      cursor: pointer;
      /* "hand" cursor */
    }

    input[type=file].inputfile:hover+label {
      outline: 1px dotted #000;
      outline: -webkit-focus-ring-color auto 5px;
    }

    .right-fixed {
      position: fixed;
      right: 0px;
    }

    .row.report-text-top-margin.right-align{
      width: 80%;
      margin-left: 135px;
    }

    /* Master Styles */

    h1 {
      color: #369;
      font-family: Arial, Helvetica, sans-serif;
      font-size: 250%;
    }

    h2,
    h3 {
      color: #444;
      font-family: Arial, Helvetica, sans-serif;
      font-weight: lighter;
    }

    body {
      margin: 2em;
    }


    /*Apply background color for div having checked radio button*/

    input[type="radio"]:checked+div {
      background-color: #1e89b5 !important;
      border: 1px solid #9b9b9b;
      color: #ffffff;
    }


    /*Apply background color for div having no checked radio button*/

    input[type="radio"]+div {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
    }

    .checkbox>label {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
      height: auto;
      line-height: 25px;
      width: 100%;
      font-weight: bold;
    }

    .checkbox>label>input[type="checkbox"] {
      margin-left: -15px;
      margin-top: 6px;
    }

    .full-width span {
      font-weight: bold;
    }


    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;
        border: 1px solid #9B9B9B;
        }*/

    .DEElement {
      color: #363636;
      letter-spacing: -0.37px;
      word-wrap: break-word;
    }

    .DEValues {
      /*font-size: 12px;*/
      color: #4a4a4a;
      letter-spacing: -0.29px;
      width: 100%;
      min-width: 180px;
      max-width: 280px;
    }


    /* CHECKBOX OVERWRITE STYLES */

    .rad {
      cursor: pointer;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
      -webkit-user-select: none;
      -webkit-touch-callout: none;
    }

    .rad>input {
      /* HIDE ORG RADIO & CHECKBOX */
      visibility: hidden;
      position: absolute;
    }

    [type="radio"]+span::before {
      content: "";
      display: inline-block;
      width: 9px;
      height: 9px;
      border-radius: 1em;
      border: 0.1px solid #fff;
      -webkit-box-shadow: 0 0 0 1px #57aed0;
              box-shadow: 0 0 0 1px #57aed0;
      margin-right: 4px;
      -webkit-transition: 0.5s ease all;
      transition: 0.5s ease all;
      margin-left: -15px;
    }

    [type="radio"]:checked+span::before {
      background: #57aed0;
      -webkit-box-shadow: 0 0 0 2px #57aed0;
              box-shadow: 0 0 0 2px #57aed0;
      margin-top: auto;
      /*margin-left:-15px;*/
    }

    .reportText {
      font-size: 14px;
      color: #363636;
      letter-spacing: -0.49px;
      margin-top: 5px;
    }

    button:hover,
    button:focus,
    button.active,
    .btn-default:hover,
    .btn-default:focus,
    .item.active,
    .btn-default.active {
      background: #1e89b5 !important;
      color: #ffffff !important;
    }

    .hideInput {
      visibility: hidden;
      margin-left: 5px !important;
    }

    .panel {
      background-color: transparent;
    }

    .logo {
      height: 30px;
      width: 250px;
    }

    .navbar-blue {
      background-color: #00205b !important;
      color: #fff;
    }

    .navbar-brand-text {
      font-size: 30px;
      color: #fff;
      font-weight: normal;
      margin-top: 10px;
    }

    .close {
      margin-top: -20px !important;
    }


    /*.full-width {
            width: 320px !important;
        }*/

    #myNav.affix {
      width: 483px;
      top: 100;
    }

    #Can-ImgMap {
      pointer-events: none;
      position: absolute;
      opacity: 0.5;
    }


    /* Styles for Assist bootstrap*/

    .control-label {
      text-align: left !important;
    }

    .box-style {
      text-decoration: none;
      color: #363636 !important;
      border-radius: 3px;
      padding: 5px;
      font-weight: bold !important;
      width: 75%;
    }

    .findings {
      color: #ffffff !important;
      background-color: #5295b1 !important;
      border-color: #5295b1 !important;
      background-image: none !important;
      font-weight: bold;
      text-transform: capitalize;
      height: 45px;
      font-size: 16px;
      text-align: left;
    }

    .table-row {
      display: table-row;
      width: auto;
      clear: both;
    }

    .table-cell {
      display: table-cell;
      width: 475px;
      font-size: 12px;
      background-color: transparent;
      color: black;
      height: 25px;
      line-height: 25px;
      padding: 1px;
    }

    .imgMap-table-cell {
      width: 10% !important;
      vertical-align: middle;
    }

    .panel-default {
      min-width: 100%;
    }

    #footer {
      position: fixed;
      bottom: 0;
    }

    .row-style {
      bottom: 5px;
      position: fixed;
      top: 55px;
      overflow: auto;
      width: 100%;
    }

    .modal-dialog {
      top: 100px;
      margin-left: 50% !important;
    }

    .required-field {
      /* border: 1px solid red; */
      /* border-radius: 5px; */
      padding: 5px;
      font-size: 16px;
      color: red;
      /* width: 120px; */
      display: inline-block;
      font-weight: bold;
    }

    .xml-only-msg {
      border: 1px solid red;
      border-radius: 5px;
      padding: 5px;
      font-size: 12px;
      color: white;
      width: 223px;
      display: inline-block;
      font-weight: bold;
    }

    @media (min-width: 400px) and (max-width: 1024px) {
      .xml-only-msg {
        width: 120px;
      }
    }

    @media (max-width: 475px)  {
      .xml-only-msg {
        color: #000000
      }
    }
    .col-per-10 {
      border: 1px solid blue;
      padding: 15px 10px 15px 10px;
      border-radius: 10px;
      height: auto;
      width: 10%;
      float: left;
      position: fixed;
      min-height: 1px;
    }

    .btn-group>.btn:first-child {
      margin-left: 0;
      width: 165px;
      margin-top: 10px;
    }

    .col-md-10 {
      left: 200px;
    }

    .module-header {
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
      margin-left: -135px;
      margin-top: -15px;
      font-size: 14px;
      font-weight: bold;
      color: #363636;
    }

    .btn-group-justified {
      padding-left: 15px;
    }

    select {
      height: 35px;
      border-radius: 5px;
      max-width: 280px;
      width: 100%;
    }

    .findings select{
      max-width: 150px;
      margin-top: -3px;
    }
    .fixed-keydiagram {
      position: fixed !important;
      float: right;
      padding-right: 0px !important;
      margin-right: 10px;
      padding-left: 25px !important;
    }

    .center-align {
      text-align: center;
      width: 160px !important;
      padding: 0px !important;
    }

    .center-align div {
      width: 200px;
      margin-left: -10px;
    }

    .findings div {
      color: #363636 !important;
      margin-left: 100px !important;
      margin-top: -23.5px !important;
      height: 30px;
    }

    .findings div select {
      text-transform: capitalize;
    }

    .modal-backdrop {
      top: 10000px !important;
    }

    .tooltip-arrow {
      display: none !important;
    }

    .other-reportSection {
      font-weight: normal;
      margin-top: -10px;
      margin-left: 15px;
    }

    a:hover {
      text-decoration: none !important;
    }

    .no-btm-margin-table {
      margin-bottom: 0px !important;
    }

    .adjust-diagram {
      margin-top: 56px;
      right: 20px !important;
    }

    .adjust-diagram-image {
      top: 0px !important;
      margin-top: 0px !important;
    }

    .reportText-panel {
      width: 90%;
      margin-left: 2%;
    }

    .reportText-body {
      margin-left: 2%;
    }

    .top-Index {
      z-index: 99999 !important;
    }


    /* Master Styles */

    h1 {
      color: #369;
      font-family: Arial, Helvetica, sans-serif;
      font-size: 250%;
    }

    h2,
    h3 {
      color: #444;
      font-family: Arial, Helvetica, sans-serif;
      font-weight: lighter;
    }

    .div-simulator-container {
      margin: 0;
    }


    /*Apply background color for div having checked radio button*/

    .div-simulator-container input[type="radio"]:checked+div {
      background-color: #1e89b5 !important;
      border: 1px solid #9b9b9b;
      color: #ffffff;
    }


    /*Apply background color for div having no checked radio button*/

    .div-simulator-container input[type="radio"]+div {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
    }

    .div-simulator-container .checkbox>label {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
      height: 25px;
      line-height: 25px;
    }

    .div-simulator-container .checkbox>label>input[type="checkbox"] {
      margin-left: -15px;
      margin-top: 6px;
    }

    .div-simulator-container .full-width span {
      font-weight: bold;
    }


    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;
        border: 1px solid #9B9B9B;
        }*/

    .div-simulator-container .DEElement {
      color: #363636;
      letter-spacing: -0.37px;
      word-wrap: break-word;
    }

    .div-simulator-container .DEValues {
      /*font-size: 12px;*/
      color: #4a4a4a;
      letter-spacing: -0.29px;
    }


    /* CHECKBOX OVERWRITE STYLES */

    .div-simulator-container .rad {
      cursor: pointer;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
      -webkit-user-select: none;
      -webkit-touch-callout: none;
    }

    .div-simulator-container .rad>input {
      /* HIDE ORG RADIO & CHECKBOX */
      visibility: hidden;
      position: absolute;
    }

    .div-simulator-container [type="radio"]+span::before {
      content: "";
      display: inline-block;
      width: 9px;
      height: 9px;
      border-radius: 1em;
      border: 0.1px solid #fff;
      -webkit-box-shadow: 0 0 0 1px #57aed0;
              box-shadow: 0 0 0 1px #57aed0;
      margin-right: 4px;
      -webkit-transition: 0.5s ease all;
      transition: 0.5s ease all;
      margin-left: -15px;
    }

    [type="radio"]:checked+span::before {
      background: #57aed0;
      -webkit-box-shadow: 0 0 0 2px #57aed0;
              box-shadow: 0 0 0 2px #57aed0;
      margin-top: auto;
      /*margin-left:-15px;*/
    }

    .div-simulator-container .reportText {
      font-size: 14px;
      color: #363636;
      letter-spacing: -0.49px;
    }

    .div-simulator-container button:hover,
    .div-simulator-container button:focus,
    .div-simulator-container button.active,
    .div-simulator-container .btn-default:hover,
    .btn-default:focus,
    .div-simulator-container .item.active,
    .div-simulator-container .btn-default.active {
      background: #1e89b5 !important;
      color: #ffffff !important;
    }

    .div-simulator-container .hideInput {
      visibility: hidden;
      margin-left: 5px !important;
    }

    .div-simulator-container .panel {
      background-color: transparent;
    }

    .logo {
      height: 30px;
      width: 250px;
    }

    .navbar-blue {
      background-color: #00205b !important;
      color: #fff;
    }

    .navbar-brand-text {
      font-size: 30px;
      color: #fff;
      font-weight: normal;
      margin-top: 10px;
    }

    .div-simulator-container .close {
      margin-top: -20px !important;
    }


    /*.full-width {
            width: 320px !important;
        }*/

    #myNav.affix {
      width: 483px;
      top: 100;
    }

    #Can-ImgMap {
      pointer-events: none;
      position: absolute;
      opacity: 0.5;
    }


    /* Styles for Assist bootstrap*/

    .div-simulator-container .control-label {
      text-align: left !important;
    }

    .div-simulator-container .box-style {
      text-decoration: none;
      color: #363636 !important;
      border-radius: 3px;
      padding: 5px;
      font-weight: bold !important;
      width: 75%;
    }

    .div-simulator-container .findings {
      color: #ffffff !important;
      background-color: #5295b1 !important;
      border-color: #5295b1 !important;
      background-image: none !important;
      font-weight: bold;
      text-transform: capitalize;
      height: 40px;
    }

    .div-simulator-container .table-row {
      display: table-row;
      width: auto;
      clear: both;
    }

    .div-simulator-container .table-cell {
      display: table-cell;
      width: 475px;
      font-size: 12px;
      background-color: transparent;
      color: black;
      height: 25px;
      line-height: 25px;
      padding: 1px;
      border-bottom: none;
    }

    .div-simulator-container .imgMap-table-cell {
      width: 10% !important;
      vertical-align: middle;
    }

    .div-simulator-container .panel-default {
      min-width: 600px;
      margin: 0 !important;
      background-color: white;
    }

    .div-simulator-container .footerBlock {
      position: fixed;
      bottom: 55px;
    }

    .div-simulator-container .row-style {
      bottom: 5px;
      position: fixed;
      top: 55px;
      overflow: auto;
      width: 100%;
    }

    .div-simulator-container .modal-dialog {
      top: 100px;
      /*margin-left: 50% !important;*/
      margin-left: 0 !important;
    }

    .div-simulator-container .required-field {
      border: 1px solid #edd1d1;
      border-radius: 5px;
      padding: 5px;
      font-size: 12px;
      color: #cd5c5c;
      width: 125px;
    }

    .div-simulator-container .col-per-10 {
      border: 1px solid blue;
      padding: 15px 10px 15px 10px;
      border-radius: 10px;
      height: auto;
      width: 10%;
      float: left;
      position: fixed;
      min-height: 1px;
    }

    .div-simulator-container .btn-group>.btn:first-child {
      margin-left: 0;
      width: 165px;
      margin-top: 10px;
    }

    .div-simulator-container .col-md-10 {
      left: 200px;
    }

    .div-simulator-container .module-header {
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
      margin-left: -135px;
      margin-top: -15px;
      font-size: 14px;
      font-weight: bold;
      color: #363636;
    }

    .div-simulator-container .btn-group-justified {
      padding-left: 15px;
    }

    .div-simulator-container select {
      height: 28px;
      border-radius: 5px;
    }

    .div-simulator-container .panel-body {
      padding: 10px !important;
    }

    .div-simulator-container .fixed-keydiagram {
      position: fixed !important;
      float: right;
      padding-right: 0px !important;
      margin-right: 10px;
      padding-left: 25px !important;
    }

    .div-simulator-container .center-align {
      text-align: center;
      width: 160px !important;
      padding: 0px !important;
    }

    .div-simulator-container .center-align div {
      width: 200px;
      margin-left: -10px;
    }

    .div-simulator-container .findings div {
      color: #363636 !important;
      margin-left: 97px !important;
      margin-top: -29.5px !important;
      height: 30px;
    }

    .div-simulator-container .findings div select {
      text-transform: capitalize;
    }

    .div-simulator-container .modal-backdrop {
      top: 10000px !important;
    }

    .div-simulator-container .tooltip-arrow {
      display: none !important;
    }

    .div-simulator-container .other-reportSection {
      font-weight: normal;
      margin-top: -10px;
      margin-left: 15px;
    }

    .div-simulator-container a:hover {
      text-decoration: none !important;
    }

    .div-simulator-container .no-btm-margin-table {
      margin-bottom: 0px !important;
    }

    .div-simulator-container .adjust-diagram {
      margin-top: 56px;
      right: 20px !important;
    }

    .adjust-diagram-image {
      top: 0px !important;
      margin-top: 0px !important;
    }

    @media only screen and (min-width: 1224px) {
      .tab-content {
        padding: 5px;
      }
    }

    @media (min-width: 768px) {
      #page-content-wrapper {
        padding: 0px 20px;
        margin-top: 15px;
      }
    }

    #sidebar-wrapper {
      left: 175px;
      margin-left: -175px;
    }

    #rowContent {
      padding-bottom: 120px;
    }

    @media only screen and (min-width: 1224px) {
      .fixed-reportText {
        width: 1064px;
      }
    }

    @media only screen and (min-width: 1824px) {
      .fixed-reportText {
        width: 1260px;
      }
    }

    @media only screen and (min-width: 1224px) {
      .modal-lg {
        left: 0;
        /* left: -250px; */
      }
    }

    .form-group {
      margin-bottom: 15px;
    }

    .control-label {
      margin-top: 0;
      margin-left: 0;
    }

    .div-simulator-container .checkbox>label {
      height: 30px;
      line-height: 30px;
    }

    .div-simulator-container .checkbox>label>input[type="checkbox"] {
      margin-top: 8px;
    }

    .div-simulator-container select {
      height: 30px;
      border-radius: 5px;
      font-size: 12px;
      width: 280px;
    }

    .div-simulator-container .input-group {
      width: 280px;
    }

    .div-simulator-container .input-group .form-control {
      border-radius: 5px;
      -webkit-box-shadow: none;
              box-shadow: none;
      border: 1px solid #969696;
    }

    .div-simulator-container .imgMap-table-cell {
      padding-left: 10px;
    }

    @media (min-width: 1224px) {
      .modal-lg {
        width: 630px;
      }
    }

    .tableImagemap {
      table-layout: fixed;
    }

    @media (min-width: 1850px) {
      .modal-lg {
        width: 900px;
      }
      .tableImagemap {
        table-layout: inherit;
      }
    }

    .col-centered {
      float: none;
      margin: 0 auto;
    }

    .checkbox {
      max-width: 280px;
    }

    [type="number"] {
      max-width: 280px;
      /*margin-left: -15px;*/
    }

    .input-group {
      width: 100%;
    }

    @media (min-width:1441px) {
      .DEValues {
        /*min-width: 280px;
        max-width: 280px;*/
        height: auto;
      }
    }

    @media (max-width:1024px) {
      .adjust-diagram-image {
        width: 50%;
      }
    }

    @media (min-width:1921px) {
      .adjust-diagram-image {
        width: 50%;
      }
    }

    .row {
      font-weight: bold;
    }

    .carousel-item.item img {
      width: 100% !important;
    }

    .carousel-indicators {
      display: none !important;
    }

    .display-inline {
      display: inline;
    }

    .font-weight-normal {
      font-weight: normal;
    }

    .font-weight-bold {
      font-weight: bold;
    }

    .color-white {
      color: #ffffff;
    }

    .bottom-margin{
      margin-bottom: 25px;
    }

    .reportText-content {
      white-space: pre-line; 
      font-weight: bold;
      margin: -40px 0px;
      height: -webkit-fit-content;
      height: -moz-fit-content;
      height: fit-content;
    }

    .no-bottom-margin {
      margin-bottom: 0px !important;
    }
    .reportText-main-content{
      font-size: 16px;
    }

    .split-length-word {
      word-break: break-all;
      text-align: left;
      margin: 0px 0px;
    }

    .img-max-width {
      width: 70% !important;
    }

    .keydiagram {
      text-align: center;
      margin-top: 10px;
    }

    .report-text-top-margin {
      margin-top: 15px;
    }

    input[type=number]::-webkit-inner-spin-button, 
    input[type=number]::-webkit-outer-spin-button { 
        -webkit-appearance: none;
        -moz-appearance: none;
        margin: 0; 
    }

    input[type="number"]:hover,
    input[type="number"]:focus,
    input[type="number"] {
        -moz-appearance: textfield;
    }

    .numeric-align {
      display: inline;
    }

    input[type="text"] {
    max-width: 280px;
    margin-left: 0px !important;
    border-radius: 5px !important;
    text-transform: capitalize;
    }

    .all-reporttext-heading {
      text-decoration: underline;
      font-weight: bold;
      text-transform: capitalize;
      font-size: 18px;
      margin-top: -50px;
      text-align: left;
    }

    .all-reportText-content {
      margin-top: -10px;
    }

    .split-length-word.all-reportText-content {
      text-align: justify;
      word-break: unset;
    }

    .fixed-report-text-sidebar {
      position: fixed;
      right: 0;
      width: 45%;
    }

    .fixed-report-text-footer {
      position: fixed;
      left: 15 !important;
      bottom: 0;
      background-color: white;
    }

    .left-margin {
      margin-left: 60px;
      width: 90%;
    }

    .overflow {
      /* max-height: 500px; */
      overflow-x: hidden;
    }

    @media (max-width: 650px) {
  

      .left-margin {
        margin-left: 20px;
      }

      .keydiagram {
        width: 100%;
        margin-left: 4%;
      } 
      .row.content-area {
        padding: 0px 5px;
      }

      .text-right.border-0 > h4 {
        padding-right: 20px;
      }

      .keydiagram {
        width: 100%;
        text-align: center;
        margin-left: 0px !important;
      }
    }
    @media (max-width: 1024px) {
      .keydiagram {
        width: 100%;
        margin-left: 9%;
      }
      .img-max-width {
        width: 80% !important;
      }
    }
    @media (max-width: 1023px) {
      .fixed-report-text-sidebar {
        position: relative;
      }
    }

    .upload-button-size {
    	font-size: 100% !important;
    }
  
  `]
            },] },
];
/**
 * @nocollapse
 */
HintDiagramComponent.ctorParameters = () => [];
HintDiagramComponent.propDecorators = {
    'DataElement': [{ type: Input },],
    'imagePath': [{ type: Input },],
};

/*tslint:disable:no-invalid-this */

var LinkedList = (function () {
    function LinkedList() {
        this.length = 0;
        this.asArray = [];
    }
    LinkedList.prototype.getNode = function (position) {
        if (this.length === 0 || position < 0 || position >= this.length) {
            throw new Error('Position is out of the list');
        }
        var current = this.head;
        for (var index = 0; index < position; index++) {
            current = current.next;
        }
        return current;
    };
    LinkedList.prototype.createInternalArrayRepresentation = function () {
        var outArray = [];
        var current = this.head;
        while (current) {
            outArray.push(current.value);
            current = current.next;
        }
        this.asArray = outArray;
    };
    LinkedList.prototype.get = function (position) {
        if (this.length === 0 || position < 0 || position >= this.length) {
            return void 0;
        }
        var current = this.head;
        for (var index = 0; index < position; index++) {
            current = current.next;
        }
        return current.value;
    };
    LinkedList.prototype.add = function (value, position) {
        if (position === void 0) { position = this.length; }
        if (position < 0 || position > this.length) {
            throw new Error('Position is out of the list');
        }
        var node = {
            value: value,
            next: undefined,
            previous: undefined
        };
        if (this.length === 0) {
            this.head = node;
            this.tail = node;
            this.current = node;
        }
        else {
            if (position === 0) {
                // first node
                node.next = this.head;
                this.head.previous = node;
                this.head = node;
            }
            else if (position === this.length) {
                // last node
                this.tail.next = node;
                node.previous = this.tail;
                this.tail = node;
            }
            else {
                // node in middle
                var currentPreviousNode = this.getNode(position - 1);
                var currentNextNode = currentPreviousNode.next;
                currentPreviousNode.next = node;
                currentNextNode.previous = node;
                node.previous = currentPreviousNode;
                node.next = currentNextNode;
            }
        }
        this.length++;
        this.createInternalArrayRepresentation();
    };
    LinkedList.prototype.remove = function (position) {
        if (position === void 0) { position = 0; }
        if (this.length === 0 || position < 0 || position >= this.length) {
            throw new Error('Position is out of the list');
        }
        if (position === 0) {
            // first node
            this.head = this.head.next;
            if (this.head) {
                // there is no second node
                this.head.previous = undefined;
            }
            else {
                // there is no second node
                this.tail = undefined;
            }
        }
        else if (position === this.length - 1) {
            // last node
            this.tail = this.tail.previous;
            this.tail.next = undefined;
        }
        else {
            // middle node
            var removedNode = this.getNode(position);
            removedNode.next.previous = removedNode.previous;
            removedNode.previous.next = removedNode.next;
        }
        this.length--;
        this.createInternalArrayRepresentation();
    };
    LinkedList.prototype.set = function (position, value) {
        if (this.length === 0 || position < 0 || position >= this.length) {
            throw new Error('Position is out of the list');
        }
        var node = this.getNode(position);
        node.value = value;
        this.createInternalArrayRepresentation();
    };
    LinkedList.prototype.toArray = function () {
        return this.asArray;
    };
    LinkedList.prototype.findAll = function (fn) {
        var current = this.head;
        var result = [];
        for (var index = 0; index < this.length; index++) {
            if (fn(current.value, index)) {
                result.push({ index: index, value: current.value });
            }
            current = current.next;
        }
        return result;
    };
    // Array methods overriding start
    LinkedList.prototype.push = function () {
        var _this = this;
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i - 0] = arguments[_i];
        }
        args.forEach(function (arg) {
            _this.add(arg);
        });
        return this.length;
    };
    LinkedList.prototype.pop = function () {
        if (this.length === 0) {
            return undefined;
        }
        var last = this.tail;
        this.remove(this.length - 1);
        return last.value;
    };
    LinkedList.prototype.unshift = function () {
        var _this = this;
        var args = [];
        for (var _i = 0; _i < arguments.length; _i++) {
            args[_i - 0] = arguments[_i];
        }
        args.reverse();
        args.forEach(function (arg) {
            _this.add(arg, 0);
        });
        return this.length;
    };
    LinkedList.prototype.shift = function () {
        if (this.length === 0) {
            return undefined;
        }
        var lastItem = this.head.value;
        this.remove();
        return lastItem;
    };
    LinkedList.prototype.forEach = function (fn) {
        var current = this.head;
        for (var index = 0; index < this.length; index++) {
            fn(current.value, index);
            current = current.next;
        }
    };
    LinkedList.prototype.indexOf = function (value) {
        var current = this.head;
        var position = 0;
        for (var index = 0; index < this.length; index++) {
            if (current.value === value) {
                position = index;
                break;
            }
            current = current.next;
        }
        return position;
    };
    LinkedList.prototype.some = function (fn) {
        var current = this.head;
        var result = false;
        while (current && !result) {
            if (fn(current.value)) {
                result = true;
                break;
            }
            current = current.next;
        }
        return result;
    };
    LinkedList.prototype.every = function (fn) {
        var current = this.head;
        var result = true;
        while (current && result) {
            if (!fn(current.value)) {
                result = false;
            }
            current = current.next;
        }
        return result;
    };
    LinkedList.prototype.toString = function () {
        return '[Linked List]';
    };
    LinkedList.prototype.find = function (fn) {
        var current = this.head;
        var result;
        for (var index = 0; index < this.length; index++) {
            if (fn(current.value, index)) {
                result = current.value;
                break;
            }
            current = current.next;
        }
        return result;
    };
    LinkedList.prototype.findIndex = function (fn) {
        var current = this.head;
        var result;
        for (var index = 0; index < this.length; index++) {
            if (fn(current.value, index)) {
                result = index;
                break;
            }
            current = current.next;
        }
        return result;
    };
    return LinkedList;
}());

/*tslint:disable */
/**
 * @license
 * Copyright Google Inc. All Rights Reserved.
 *
 * Use of this source code is governed by an MIT-style license that can be
 * found in the LICENSE file at https://angular.io/license
 */
/**
 * JS version of browser APIs. This library can only run in the browser.
 */
var win = typeof window !== 'undefined' && window || {};
var document$1 = win.document;
var location = win.location;
var gc = win['gc'] ? function () { return win['gc'](); } : function () { return null; };
var performance = win['performance'] ? win['performance'] : null;
var Event = win['Event'];
var MouseEvent = win['MouseEvent'];
var KeyboardEvent = win['KeyboardEvent'];
var EventTarget = win['EventTarget'];
var History = win['History'];
var Location = win['Location'];
var EventListener = win['EventListener'];

function isBs3() {
    return win.__theme !== 'bs4';
}

/**
 * @copyright Valor Software
 * @copyright Angular ng-bootstrap team
 */

var CarouselConfig = (function () {
    function CarouselConfig() {
        /** Default interval of auto changing of slides */
        this.interval = 5000;
        /** Is loop of auto changing of slides can be paused */
        this.noPause = false;
        /** Is slides can wrap from the last to the first slide */
        this.noWrap = false;
    }
    CarouselConfig.decorators = [
        { type: Injectable },
    ];
    /** @nocollapse */
    CarouselConfig.ctorParameters = function () { return []; };
    return CarouselConfig;
}());

// todo: add animation
var Direction;
(function (Direction) {
    Direction[Direction["UNKNOWN"] = 0] = "UNKNOWN";
    Direction[Direction["NEXT"] = 1] = "NEXT";
    Direction[Direction["PREV"] = 2] = "PREV";
})(Direction || (Direction = {}));
/**
 * Base element to create carousel
 */
var CarouselComponent = (function () {
    function CarouselComponent(config) {
        /** Will be emitted when active slide has been changed. Part of two-way-bindable [(activeSlide)] property */
        this.activeSlideChange = new EventEmitter(false);
        this._slides = new LinkedList();
        this.destroyed = false;
        Object.assign(this, config);
    }
    Object.defineProperty(CarouselComponent.prototype, "activeSlide", {
        get: function () {
            return this._currentActiveSlide;
        },
        /** Index of currently displayed slide(started for 0) */
        set: function (index) {
            if (this._slides.length && index !== this._currentActiveSlide) {
                this._select(index);
            }
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CarouselComponent.prototype, "interval", {
        /**
         * Delay of item cycling in milliseconds. If false, carousel won't cycle automatically.
         */
        get: function () {
            return this._interval;
        },
        set: function (value) {
            this._interval = value;
            this.restartTimer();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CarouselComponent.prototype, "slides", {
        get: function () {
            return this._slides.toArray();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(CarouselComponent.prototype, "isBs4", {
        get: function () {
            return !isBs3();
        },
        enumerable: true,
        configurable: true
    });
    CarouselComponent.prototype.ngOnDestroy = function () {
        this.destroyed = true;
    };
    /**
     * Adds new slide. If this slide is first in collection - set it as active and starts auto changing
     * @param slide
     */
    CarouselComponent.prototype.addSlide = function (slide) {
        this._slides.add(slide);
        if (this._slides.length === 1) {
            this._currentActiveSlide = void 0;
            this.activeSlide = 0;
            this.play();
        }
    };
    /**
     * Removes specified slide. If this slide is active - will roll to another slide
     * @param slide
     */
    CarouselComponent.prototype.removeSlide = function (slide) {
        var _this = this;
        var remIndex = this._slides.indexOf(slide);
        if (this._currentActiveSlide === remIndex) {
            // removing of active slide
            var nextSlideIndex_1 = void 0;
            if (this._slides.length > 1) {
                // if this slide last - will roll to first slide, if noWrap flag is FALSE or to previous, if noWrap is TRUE
                // in case, if this slide in middle of collection, index of next slide is same to removed
                nextSlideIndex_1 = !this.isLast(remIndex) ? remIndex :
                    this.noWrap ? remIndex - 1 : 0;
            }
            this._slides.remove(remIndex);
            // prevents exception with changing some value after checking
            setTimeout(function () {
                _this._select(nextSlideIndex_1);
            }, 0);
        }
        else {
            this._slides.remove(remIndex);
            var currentSlideIndex_1 = this.getCurrentSlideIndex();
            setTimeout(function () {
                // after removing, need to actualize index of current active slide
                _this._currentActiveSlide = currentSlideIndex_1;
                _this.activeSlideChange.emit(_this._currentActiveSlide);
            }, 0);
        }
    };
    /**
     * Rolling to next slide
     * @param force: {boolean} if true - will ignore noWrap flag
     */
    CarouselComponent.prototype.nextSlide = function (force) {
        if (force === void 0) { force = false; }
        this.activeSlide = this.findNextSlideIndex(Direction.NEXT, force);
    };
    /**
     * Rolling to previous slide
     * @param force: {boolean} if true - will ignore noWrap flag
     */
    CarouselComponent.prototype.previousSlide = function (force) {
        if (force === void 0) { force = false; }
        this.activeSlide = this.findNextSlideIndex(Direction.PREV, force);
    };
    /**
     * Rolling to specified slide
     * @param index: {number} index of slide, which must be shown
     */
    CarouselComponent.prototype.selectSlide = function (index) {
        this.activeSlide = index;
    };
    /**
     * Starts a auto changing of slides
     */
    CarouselComponent.prototype.play = function () {
        if (!this.isPlaying) {
            this.isPlaying = true;
            this.restartTimer();
        }
    };
    /**
     * Stops a auto changing of slides
     */
    CarouselComponent.prototype.pause = function () {
        if (!this.noPause) {
            this.isPlaying = false;
            this.resetTimer();
        }
    };
    /**
     * Finds and returns index of currently displayed slide
     * @returns {number}
     */
    CarouselComponent.prototype.getCurrentSlideIndex = function () {
        return this._slides.findIndex(function (slide) { return slide.active; });
    };
    /**
     * Defines, whether the specified index is last in collection
     * @param index
     * @returns {boolean}
     */
    CarouselComponent.prototype.isLast = function (index) {
        return index + 1 >= this._slides.length;
    };
    /**
     * Defines next slide index, depending of direction
     * @param direction: Direction(UNKNOWN|PREV|NEXT)
     * @param force: {boolean} if TRUE - will ignore noWrap flag, else will return undefined if next slide require wrapping
     * @returns {any}
     */
    CarouselComponent.prototype.findNextSlideIndex = function (direction, force) {
        var nextSlideIndex = 0;
        if (!force && (this.isLast(this.activeSlide) && direction !== Direction.PREV && this.noWrap)) {
            return void 0;
        }
        switch (direction) {
            case Direction.NEXT:
                // if this is last slide, not force, looping is disabled and need to going forward - select current slide, as a next
                nextSlideIndex = (!this.isLast(this._currentActiveSlide)) ? this._currentActiveSlide + 1 :
                    (!force && this.noWrap) ? this._currentActiveSlide : 0;
                break;
            case Direction.PREV:
                // if this is first slide, not force, looping is disabled and need to going backward - select current slide, as a next
                nextSlideIndex = (this._currentActiveSlide > 0) ? this._currentActiveSlide - 1 :
                    (!force && this.noWrap) ? this._currentActiveSlide : this._slides.length - 1;
                break;
            default:
                throw new Error('Unknown direction');
        }
        return nextSlideIndex;
    };
    /**
     * Sets a slide, which specified through index, as active
     * @param index
     * @private
     */
    CarouselComponent.prototype._select = function (index) {
        if (isNaN(index)) {
            this.pause();
            return;
        }
        var currentSlide = this._slides.get(this._currentActiveSlide);
        if (currentSlide) {
            currentSlide.active = false;
        }
        var nextSlide = this._slides.get(index);
        if (nextSlide) {
            this._currentActiveSlide = index;
            nextSlide.active = true;
            this.activeSlide = index;
            this.activeSlideChange.emit(index);
        }
    };
    /**
     * Starts loop of auto changing of slides
     */
    CarouselComponent.prototype.restartTimer = function () {
        var _this = this;
        this.resetTimer();
        var interval = +this.interval;
        if (!isNaN(interval) && interval > 0) {
            this.currentInterval = setInterval(function () {
                var nInterval = +_this.interval;
                if (_this.isPlaying && !isNaN(_this.interval) && nInterval > 0 && _this.slides.length) {
                    _this.nextSlide();
                }
                else {
                    _this.pause();
                }
            }, interval);
        }
    };
    /**
     * Stops loop of auto changing of slides
     */
    CarouselComponent.prototype.resetTimer = function () {
        if (this.currentInterval) {
            clearInterval(this.currentInterval);
            this.currentInterval = void 0;
        }
    };
    CarouselComponent.decorators = [
        { type: Component, args: [{
                    selector: 'carousel',
                    template: "\n    <div (mouseenter)=\"pause()\" (mouseleave)=\"play()\" (mouseup)=\"play()\" class=\"carousel slide\">\n      <ol class=\"carousel-indicators\" *ngIf=\"slides.length > 1\">\n         <li *ngFor=\"let slidez of slides; let i = index;\" [class.active]=\"slidez.active === true\" (click)=\"selectSlide(i)\"></li>\n      </ol>\n      <div class=\"carousel-inner\"><ng-content></ng-content></div>\n      <a class=\"left carousel-control carousel-control-prev\" [class.disabled]=\"activeSlide === 0 && noWrap\" (click)=\"previousSlide()\" *ngIf=\"slides.length > 1\">\n        <span class=\"icon-prev carousel-control-prev-icon\" aria-hidden=\"true\"></span>\n        <span *ngIf=\"isBs4\" class=\"sr-only\">Previous</span>\n      </a>\n      <a class=\"right carousel-control carousel-control-next\" (click)=\"nextSlide()\"  [class.disabled]=\"isLast(activeSlide) && noWrap\" *ngIf=\"slides.length > 1\">\n        <span class=\"icon-next carousel-control-next-icon\" aria-hidden=\"true\"></span>\n        <span class=\"sr-only\">Next</span>\n      </a>\n    </div>\n  "
                },] },
    ];
    /** @nocollapse */
    CarouselComponent.ctorParameters = function () { return [
        { type: CarouselConfig, },
    ]; };
    CarouselComponent.propDecorators = {
        'noWrap': [{ type: Input },],
        'noPause': [{ type: Input },],
        'activeSlideChange': [{ type: Output },],
        'activeSlide': [{ type: Input },],
        'interval': [{ type: Input },],
    };
    return CarouselComponent;
}());

var SlideComponent = (function () {
    function SlideComponent(carousel) {
        /** Wraps element by appropriate CSS classes */
        this.addClass = true;
        this.carousel = carousel;
    }
    /** Fires changes in container collection after adding a new slide instance */
    SlideComponent.prototype.ngOnInit = function () {
        this.carousel.addSlide(this);
    };
    /** Fires changes in container collection after removing of this slide instance */
    SlideComponent.prototype.ngOnDestroy = function () {
        this.carousel.removeSlide(this);
    };
    SlideComponent.decorators = [
        { type: Component, args: [{
                    selector: 'slide',
                    template: "\n    <div [class.active]=\"active\" class=\"item\">\n      <ng-content></ng-content>\n    </div>\n  "
                },] },
    ];
    /** @nocollapse */
    SlideComponent.ctorParameters = function () { return [
        { type: CarouselComponent, },
    ]; };
    SlideComponent.propDecorators = {
        'active': [{ type: HostBinding, args: ['class.active',] }, { type: Input },],
        'addClass': [{ type: HostBinding, args: ['class.item',] }, { type: HostBinding, args: ['class.carousel-item',] },],
    };
    return SlideComponent;
}());

class GlobalValue extends BaseDataElement {
}

class GlobalValueCreationService extends DataElementCreationBaseService {
    /**
     * @param {?} diagramService
     */
    constructor(diagramService) {
        super(diagramService);
        this.elementType = 'GlobalValue';
    }
    /**
     * @param {?} data
     * @return {?}
     */
    createElement(data) {
        const /** @type {?} */ dataElement = new GlobalValue();
        dataElement.id = data.Attr.Id;
        dataElement.currentValue = data._;
        dataElement.dataElementType = 'GlobalValue';
        return dataElement;
    }
}
GlobalValueCreationService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
GlobalValueCreationService.ctorParameters = () => [
    { type: DiagramService, },
];

class SelectedCondition {
}

const $$1 = require('jquery');
class AssistNumericElementComponent {
    /**
     * @param {?} formBuilder
     * @param {?} simulatorEngineService
     */
    constructor(formBuilder, simulatorEngineService) {
        this.formBuilder = formBuilder;
        this.simulatorEngineService = simulatorEngineService;
        this.returnNumericElement = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.createNumericElementForm();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        if (this.numericDataElement.currentValue !== undefined && this.numericDataElement.currentValue !== 0) {
            this.simulatorEngineService.addOrUpdateDataElement(this.numericDataElement.id, this.numericDataElement.currentValue, this.numericDataElement.currentValue);
            const /** @type {?} */ customEvent = document.createEvent('Event');
            // customEvent.initEvent('change', true, true);
            // $('#' + this.numericDataElement.id)[0].dispatchEvent(customEvent);
            this.numberValue = this.numericDataElement.currentValue;
            this.simulatorEngineService.addOrUpdateDataElement(this.numericDataElement.id, this.numericDataElement.currentValue, this.numericDataElement.currentValue);
            this.loadedNumericValue(this.numericDataElement.id, this.numericDataElement.currentValue, this.numericDataElement.label);
        }
    }
    /**
     * @param {?} id
     * @param {?} value
     * @param {?} selectedCondition
     * @return {?}
     */
    loadedNumericValue(id, value, selectedCondition) {
        const /** @type {?} */ choiceElement = new NumericElement();
        choiceElement.elementId = id;
        choiceElement.selectedValue = value;
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = id;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = value;
        this.returnNumericElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    }
    /**
     * @param {?} element
     * @param {?} selectedCondition
     * @return {?}
     */
    choiceSelected(element, selectedCondition) {
        const /** @type {?} */ choiceElement = new NumericElement();
        choiceElement.elementId = element.id;
        choiceElement.selectedValue = element.value;
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = element.id;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = element.value;
        this.returnNumericElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    }
    /**
     * @return {?}
     */
    createNumericElementForm() {
        this.numericElementForm = this.formBuilder.group({
            numericElement: ['', Validators.compose([Validators.required, Validators.min(+this.numericDataElement.minimum)])],
        });
    }
    /**
     * @param {?} numericKey
     * @return {?}
     */
    specificValueInsideRange(numericKey) {
        return (group) => {
            const /** @type {?} */ numericControl = group.controls[numericKey];
            if ((numericControl.value === 'undefined' || numericControl.value === '') && this.numericDataElement.isRequired) {
                return numericControl.setErrors({ notEquivalent: true });
            }
            else {
                return numericControl.setErrors(null);
            }
        };
    }
    /**
     * @param {?} event
     * @return {?}
     */
    onlyNumberKey(event) {
        return (event.charCode === 8 || event.charCode === 0) ? null : event.charCode >= 48 && event.charCode <= 57;
    }
}
AssistNumericElementComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-numeric-element',
                template: `
    <form [formGroup]="numericElementForm" novalidate>
      <div class="col-xs-4 col-sm-6 text-left content-padding">
        <label class="control-label DEElement">
          {{numericDataElement.label}}
        </label>
        <ng-container *ngIf="numericDataElement.hint !== '' && numericDataElement.hint !== undefined">
          <a>
            <span class="glyphicon glyphicon-info-sign" data-toggle="tooltip" data-placement="right" title="{{numericDataElement.hint}}"></span>
          </a>
        </ng-container>
        <ng-container *ngIf="numericDataElement.diagrams != undefined ">
          <acr-hint-diagram [DataElement]="numericDataElement" [imagePath]="imagePath"></acr-hint-diagram>
        </ng-container>

        <ng-container *ngIf="this.numericDataElement.isRequired">
          <div *ngIf="numericElementForm.controls['numericElement'].invalid" class="numeric-align">
            <div *ngIf="numericElementForm.controls['numericElement'].errors.required" class="required-field" title="Required Field">
              *
            </div>
          </div>
        </ng-container>
        <div *ngIf="numericElementForm.controls['numericElement'].invalid && numericElementForm.controls['numericElement'].errors.min" class="required-field numeric-validator"
        title=" Minimum value is {{numericDataElement.minimum}}">
            *
          </div>
      </div>
      <ng-container *ngIf="numericDataElement.dataElementType === 'NumericDataElement'">
        <div class="col-xs-8 col-sm-6 text-left content-padding">
            <div class="row">
                <div class="col-sm-12">
                  <input [(ngModel)]="numberValue" id="{{numericDataElement.id}}" type="number" class="form-control" formControlName="numericElement" (keypress)="onlyNumberKey($event)"
                  onpaste="return false;" (input)="choiceSelected($event.target, numericDataElement.label)" min="{{numericDataElement.minimum}}" required>
                </div>
              </div>
        </div>
      </ng-container>

      <ng-container *ngIf="numericDataElement.dataElementType === 'IntegerDataElement'">
        <div class="col-xs-8 col-sm-6 text-left content-padding">
          <div class="row">
              <div class="col-sm-12">
                <input [(ngModel)]="numberValue" id="{{numericDataElement.id}}" type="number" class="form-control" formControlName="numericElement" (keypress)="onlyNumberKey($event)"
                onpaste="return false;" (input)="choiceSelected($event.target, numericDataElement.label)" min="{{numericDataElement.minimum}}"  required>
              </div>
            </div>
        </div>
      </ng-container>
    </form>
  `,
                styles: [`
    input[type=file].inputfile {
      width: 0.1px;
      height: 0.1px;
      opacity: 0;
      overflow: hidden;
      position: absolute;
      z-index: -1;
      margin: 0;
    }

    input[type=file].inputfile+label:active,
    input[type=file].inputfile+label {
      max-width: 100%;
      font-size: 1.5rem;
      font-weight: 700;
      text-overflow: ellipsis;
      white-space: nowrap;
      cursor: pointer;
      display: inline-block;
      overflow: hidden;
      display: inline-block;
      color: #f1e5e6;
      background-color: #d3394c;
      text-indent: 0px;
      width: 130px;
    }

    input[type=file].inputfile+label:hover {
      background-color: #722040;
    }

    input[type=file].inputfile+label {
      cursor: pointer;
      /* "hand" cursor */
    }

    input[type=file].inputfile:hover+label {
      outline: 1px dotted #000;
      outline: -webkit-focus-ring-color auto 5px;
    }

    .right-fixed {
      position: fixed;
      right: 0px;
    }

    .row.report-text-top-margin.right-align{
      width: 80%;
      margin-left: 135px;
    }

    /* Master Styles */

    h1 {
      color: #369;
      font-family: Arial, Helvetica, sans-serif;
      font-size: 250%;
    }

    h2,
    h3 {
      color: #444;
      font-family: Arial, Helvetica, sans-serif;
      font-weight: lighter;
    }

    body {
      margin: 2em;
    }


    /*Apply background color for div having checked radio button*/

    input[type="radio"]:checked+div {
      background-color: #1e89b5 !important;
      border: 1px solid #9b9b9b;
      color: #ffffff;
    }


    /*Apply background color for div having no checked radio button*/

    input[type="radio"]+div {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
    }

    .checkbox>label {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
      height: auto;
      line-height: 25px;
      width: 100%;
      font-weight: bold;
    }

    .checkbox>label>input[type="checkbox"] {
      margin-left: -15px;
      margin-top: 6px;
    }

    .full-width span {
      font-weight: bold;
    }


    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;
        border: 1px solid #9B9B9B;
        }*/

    .DEElement {
      color: #363636;
      letter-spacing: -0.37px;
      word-wrap: break-word;
    }

    .DEValues {
      /*font-size: 12px;*/
      color: #4a4a4a;
      letter-spacing: -0.29px;
      width: 100%;
      min-width: 180px;
      max-width: 280px;
    }


    /* CHECKBOX OVERWRITE STYLES */

    .rad {
      cursor: pointer;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
      -webkit-user-select: none;
      -webkit-touch-callout: none;
    }

    .rad>input {
      /* HIDE ORG RADIO & CHECKBOX */
      visibility: hidden;
      position: absolute;
    }

    [type="radio"]+span::before {
      content: "";
      display: inline-block;
      width: 9px;
      height: 9px;
      border-radius: 1em;
      border: 0.1px solid #fff;
      -webkit-box-shadow: 0 0 0 1px #57aed0;
              box-shadow: 0 0 0 1px #57aed0;
      margin-right: 4px;
      -webkit-transition: 0.5s ease all;
      transition: 0.5s ease all;
      margin-left: -15px;
    }

    [type="radio"]:checked+span::before {
      background: #57aed0;
      -webkit-box-shadow: 0 0 0 2px #57aed0;
              box-shadow: 0 0 0 2px #57aed0;
      margin-top: auto;
      /*margin-left:-15px;*/
    }

    .reportText {
      font-size: 14px;
      color: #363636;
      letter-spacing: -0.49px;
      margin-top: 5px;
    }

    button:hover,
    button:focus,
    button.active,
    .btn-default:hover,
    .btn-default:focus,
    .item.active,
    .btn-default.active {
      background: #1e89b5 !important;
      color: #ffffff !important;
    }

    .hideInput {
      visibility: hidden;
      margin-left: 5px !important;
    }

    .panel {
      background-color: transparent;
    }

    .logo {
      height: 30px;
      width: 250px;
    }

    .navbar-blue {
      background-color: #00205b !important;
      color: #fff;
    }

    .navbar-brand-text {
      font-size: 30px;
      color: #fff;
      font-weight: normal;
      margin-top: 10px;
    }

    .close {
      margin-top: -20px !important;
    }


    /*.full-width {
            width: 320px !important;
        }*/

    #myNav.affix {
      width: 483px;
      top: 100;
    }

    #Can-ImgMap {
      pointer-events: none;
      position: absolute;
      opacity: 0.5;
    }


    /* Styles for Assist bootstrap*/

    .control-label {
      text-align: left !important;
    }

    .box-style {
      text-decoration: none;
      color: #363636 !important;
      border-radius: 3px;
      padding: 5px;
      font-weight: bold !important;
      width: 75%;
    }

    .findings {
      color: #ffffff !important;
      background-color: #5295b1 !important;
      border-color: #5295b1 !important;
      background-image: none !important;
      font-weight: bold;
      text-transform: capitalize;
      height: 45px;
      font-size: 16px;
      text-align: left;
    }

    .table-row {
      display: table-row;
      width: auto;
      clear: both;
    }

    .table-cell {
      display: table-cell;
      width: 475px;
      font-size: 12px;
      background-color: transparent;
      color: black;
      height: 25px;
      line-height: 25px;
      padding: 1px;
    }

    .imgMap-table-cell {
      width: 10% !important;
      vertical-align: middle;
    }

    .panel-default {
      min-width: 100%;
    }

    #footer {
      position: fixed;
      bottom: 0;
    }

    .row-style {
      bottom: 5px;
      position: fixed;
      top: 55px;
      overflow: auto;
      width: 100%;
    }

    .modal-dialog {
      top: 100px;
      margin-left: 50% !important;
    }

    .required-field {
      /* border: 1px solid red; */
      /* border-radius: 5px; */
      padding: 5px;
      font-size: 16px;
      color: red;
      /* width: 120px; */
      display: inline-block;
      font-weight: bold;
    }

    .xml-only-msg {
      border: 1px solid red;
      border-radius: 5px;
      padding: 5px;
      font-size: 12px;
      color: white;
      width: 223px;
      display: inline-block;
      font-weight: bold;
    }

    @media (min-width: 400px) and (max-width: 1024px) {
      .xml-only-msg {
        width: 120px;
      }
    }

    @media (max-width: 475px)  {
      .xml-only-msg {
        color: #000000
      }
    }
    .col-per-10 {
      border: 1px solid blue;
      padding: 15px 10px 15px 10px;
      border-radius: 10px;
      height: auto;
      width: 10%;
      float: left;
      position: fixed;
      min-height: 1px;
    }

    .btn-group>.btn:first-child {
      margin-left: 0;
      width: 165px;
      margin-top: 10px;
    }

    .col-md-10 {
      left: 200px;
    }

    .module-header {
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
      margin-left: -135px;
      margin-top: -15px;
      font-size: 14px;
      font-weight: bold;
      color: #363636;
    }

    .btn-group-justified {
      padding-left: 15px;
    }

    select {
      height: 35px;
      border-radius: 5px;
      max-width: 280px;
      width: 100%;
    }

    .findings select{
      max-width: 150px;
      margin-top: -3px;
    }
    .fixed-keydiagram {
      position: fixed !important;
      float: right;
      padding-right: 0px !important;
      margin-right: 10px;
      padding-left: 25px !important;
    }

    .center-align {
      text-align: center;
      width: 160px !important;
      padding: 0px !important;
    }

    .center-align div {
      width: 200px;
      margin-left: -10px;
    }

    .findings div {
      color: #363636 !important;
      margin-left: 100px !important;
      margin-top: -23.5px !important;
      height: 30px;
    }

    .findings div select {
      text-transform: capitalize;
    }

    .modal-backdrop {
      top: 10000px !important;
    }

    .tooltip-arrow {
      display: none !important;
    }

    .other-reportSection {
      font-weight: normal;
      margin-top: -10px;
      margin-left: 15px;
    }

    a:hover {
      text-decoration: none !important;
    }

    .no-btm-margin-table {
      margin-bottom: 0px !important;
    }

    .adjust-diagram {
      margin-top: 56px;
      right: 20px !important;
    }

    .adjust-diagram-image {
      top: 0px !important;
      margin-top: 0px !important;
    }

    .reportText-panel {
      width: 90%;
      margin-left: 2%;
    }

    .reportText-body {
      margin-left: 2%;
    }

    .top-Index {
      z-index: 99999 !important;
    }


    /* Master Styles */

    h1 {
      color: #369;
      font-family: Arial, Helvetica, sans-serif;
      font-size: 250%;
    }

    h2,
    h3 {
      color: #444;
      font-family: Arial, Helvetica, sans-serif;
      font-weight: lighter;
    }

    .div-simulator-container {
      margin: 0;
    }


    /*Apply background color for div having checked radio button*/

    .div-simulator-container input[type="radio"]:checked+div {
      background-color: #1e89b5 !important;
      border: 1px solid #9b9b9b;
      color: #ffffff;
    }


    /*Apply background color for div having no checked radio button*/

    .div-simulator-container input[type="radio"]+div {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
    }

    .div-simulator-container .checkbox>label {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
      height: 25px;
      line-height: 25px;
    }

    .div-simulator-container .checkbox>label>input[type="checkbox"] {
      margin-left: -15px;
      margin-top: 6px;
    }

    .div-simulator-container .full-width span {
      font-weight: bold;
    }


    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;
        border: 1px solid #9B9B9B;
        }*/

    .div-simulator-container .DEElement {
      color: #363636;
      letter-spacing: -0.37px;
      word-wrap: break-word;
    }

    .div-simulator-container .DEValues {
      /*font-size: 12px;*/
      color: #4a4a4a;
      letter-spacing: -0.29px;
    }


    /* CHECKBOX OVERWRITE STYLES */

    .div-simulator-container .rad {
      cursor: pointer;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
      -webkit-user-select: none;
      -webkit-touch-callout: none;
    }

    .div-simulator-container .rad>input {
      /* HIDE ORG RADIO & CHECKBOX */
      visibility: hidden;
      position: absolute;
    }

    .div-simulator-container [type="radio"]+span::before {
      content: "";
      display: inline-block;
      width: 9px;
      height: 9px;
      border-radius: 1em;
      border: 0.1px solid #fff;
      -webkit-box-shadow: 0 0 0 1px #57aed0;
              box-shadow: 0 0 0 1px #57aed0;
      margin-right: 4px;
      -webkit-transition: 0.5s ease all;
      transition: 0.5s ease all;
      margin-left: -15px;
    }

    [type="radio"]:checked+span::before {
      background: #57aed0;
      -webkit-box-shadow: 0 0 0 2px #57aed0;
              box-shadow: 0 0 0 2px #57aed0;
      margin-top: auto;
      /*margin-left:-15px;*/
    }

    .div-simulator-container .reportText {
      font-size: 14px;
      color: #363636;
      letter-spacing: -0.49px;
    }

    .div-simulator-container button:hover,
    .div-simulator-container button:focus,
    .div-simulator-container button.active,
    .div-simulator-container .btn-default:hover,
    .btn-default:focus,
    .div-simulator-container .item.active,
    .div-simulator-container .btn-default.active {
      background: #1e89b5 !important;
      color: #ffffff !important;
    }

    .div-simulator-container .hideInput {
      visibility: hidden;
      margin-left: 5px !important;
    }

    .div-simulator-container .panel {
      background-color: transparent;
    }

    .logo {
      height: 30px;
      width: 250px;
    }

    .navbar-blue {
      background-color: #00205b !important;
      color: #fff;
    }

    .navbar-brand-text {
      font-size: 30px;
      color: #fff;
      font-weight: normal;
      margin-top: 10px;
    }

    .div-simulator-container .close {
      margin-top: -20px !important;
    }


    /*.full-width {
            width: 320px !important;
        }*/

    #myNav.affix {
      width: 483px;
      top: 100;
    }

    #Can-ImgMap {
      pointer-events: none;
      position: absolute;
      opacity: 0.5;
    }


    /* Styles for Assist bootstrap*/

    .div-simulator-container .control-label {
      text-align: left !important;
    }

    .div-simulator-container .box-style {
      text-decoration: none;
      color: #363636 !important;
      border-radius: 3px;
      padding: 5px;
      font-weight: bold !important;
      width: 75%;
    }

    .div-simulator-container .findings {
      color: #ffffff !important;
      background-color: #5295b1 !important;
      border-color: #5295b1 !important;
      background-image: none !important;
      font-weight: bold;
      text-transform: capitalize;
      height: 40px;
    }

    .div-simulator-container .table-row {
      display: table-row;
      width: auto;
      clear: both;
    }

    .div-simulator-container .table-cell {
      display: table-cell;
      width: 475px;
      font-size: 12px;
      background-color: transparent;
      color: black;
      height: 25px;
      line-height: 25px;
      padding: 1px;
      border-bottom: none;
    }

    .div-simulator-container .imgMap-table-cell {
      width: 10% !important;
      vertical-align: middle;
    }

    .div-simulator-container .panel-default {
      min-width: 600px;
      margin: 0 !important;
      background-color: white;
    }

    .div-simulator-container .footerBlock {
      position: fixed;
      bottom: 55px;
    }

    .div-simulator-container .row-style {
      bottom: 5px;
      position: fixed;
      top: 55px;
      overflow: auto;
      width: 100%;
    }

    .div-simulator-container .modal-dialog {
      top: 100px;
      /*margin-left: 50% !important;*/
      margin-left: 0 !important;
    }

    .div-simulator-container .required-field {
      border: 1px solid #edd1d1;
      border-radius: 5px;
      padding: 5px;
      font-size: 12px;
      color: #cd5c5c;
      width: 125px;
    }

    .div-simulator-container .col-per-10 {
      border: 1px solid blue;
      padding: 15px 10px 15px 10px;
      border-radius: 10px;
      height: auto;
      width: 10%;
      float: left;
      position: fixed;
      min-height: 1px;
    }

    .div-simulator-container .btn-group>.btn:first-child {
      margin-left: 0;
      width: 165px;
      margin-top: 10px;
    }

    .div-simulator-container .col-md-10 {
      left: 200px;
    }

    .div-simulator-container .module-header {
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
      margin-left: -135px;
      margin-top: -15px;
      font-size: 14px;
      font-weight: bold;
      color: #363636;
    }

    .div-simulator-container .btn-group-justified {
      padding-left: 15px;
    }

    .div-simulator-container select {
      height: 28px;
      border-radius: 5px;
    }

    .div-simulator-container .panel-body {
      padding: 10px !important;
    }

    .div-simulator-container .fixed-keydiagram {
      position: fixed !important;
      float: right;
      padding-right: 0px !important;
      margin-right: 10px;
      padding-left: 25px !important;
    }

    .div-simulator-container .center-align {
      text-align: center;
      width: 160px !important;
      padding: 0px !important;
    }

    .div-simulator-container .center-align div {
      width: 200px;
      margin-left: -10px;
    }

    .div-simulator-container .findings div {
      color: #363636 !important;
      margin-left: 97px !important;
      margin-top: -29.5px !important;
      height: 30px;
    }

    .div-simulator-container .findings div select {
      text-transform: capitalize;
    }

    .div-simulator-container .modal-backdrop {
      top: 10000px !important;
    }

    .div-simulator-container .tooltip-arrow {
      display: none !important;
    }

    .div-simulator-container .other-reportSection {
      font-weight: normal;
      margin-top: -10px;
      margin-left: 15px;
    }

    .div-simulator-container a:hover {
      text-decoration: none !important;
    }

    .div-simulator-container .no-btm-margin-table {
      margin-bottom: 0px !important;
    }

    .div-simulator-container .adjust-diagram {
      margin-top: 56px;
      right: 20px !important;
    }

    .adjust-diagram-image {
      top: 0px !important;
      margin-top: 0px !important;
    }

    @media only screen and (min-width: 1224px) {
      .tab-content {
        padding: 5px;
      }
    }

    @media (min-width: 768px) {
      #page-content-wrapper {
        padding: 0px 20px;
        margin-top: 15px;
      }
    }

    #sidebar-wrapper {
      left: 175px;
      margin-left: -175px;
    }

    #rowContent {
      padding-bottom: 120px;
    }

    @media only screen and (min-width: 1224px) {
      .fixed-reportText {
        width: 1064px;
      }
    }

    @media only screen and (min-width: 1824px) {
      .fixed-reportText {
        width: 1260px;
      }
    }

    @media only screen and (min-width: 1224px) {
      .modal-lg {
        left: 0;
        /* left: -250px; */
      }
    }

    .form-group {
      margin-bottom: 15px;
    }

    .control-label {
      margin-top: 0;
      margin-left: 0;
    }

    .div-simulator-container .checkbox>label {
      height: 30px;
      line-height: 30px;
    }

    .div-simulator-container .checkbox>label>input[type="checkbox"] {
      margin-top: 8px;
    }

    .div-simulator-container select {
      height: 30px;
      border-radius: 5px;
      font-size: 12px;
      width: 280px;
    }

    .div-simulator-container .input-group {
      width: 280px;
    }

    .div-simulator-container .input-group .form-control {
      border-radius: 5px;
      -webkit-box-shadow: none;
              box-shadow: none;
      border: 1px solid #969696;
    }

    .div-simulator-container .imgMap-table-cell {
      padding-left: 10px;
    }

    @media (min-width: 1224px) {
      .modal-lg {
        width: 630px;
      }
    }

    .tableImagemap {
      table-layout: fixed;
    }

    @media (min-width: 1850px) {
      .modal-lg {
        width: 900px;
      }
      .tableImagemap {
        table-layout: inherit;
      }
    }

    .col-centered {
      float: none;
      margin: 0 auto;
    }

    .checkbox {
      max-width: 280px;
    }

    [type="number"] {
      max-width: 280px;
      /*margin-left: -15px;*/
    }

    .input-group {
      width: 100%;
    }

    @media (min-width:1441px) {
      .DEValues {
        /*min-width: 280px;
        max-width: 280px;*/
        height: auto;
      }
    }

    @media (max-width:1024px) {
      .adjust-diagram-image {
        width: 50%;
      }
    }

    @media (min-width:1921px) {
      .adjust-diagram-image {
        width: 50%;
      }
    }

    .row {
      font-weight: bold;
    }

    .carousel-item.item img {
      width: 100% !important;
    }

    .carousel-indicators {
      display: none !important;
    }

    .display-inline {
      display: inline;
    }

    .font-weight-normal {
      font-weight: normal;
    }

    .font-weight-bold {
      font-weight: bold;
    }

    .color-white {
      color: #ffffff;
    }

    .bottom-margin{
      margin-bottom: 25px;
    }

    .reportText-content {
      white-space: pre-line; 
      font-weight: bold;
      margin: -40px 0px;
      height: -webkit-fit-content;
      height: -moz-fit-content;
      height: fit-content;
    }

    .no-bottom-margin {
      margin-bottom: 0px !important;
    }
    .reportText-main-content{
      font-size: 16px;
    }

    .split-length-word {
      word-break: break-all;
      text-align: left;
      margin: 0px 0px;
    }

    .img-max-width {
      width: 70% !important;
    }

    .keydiagram {
      text-align: center;
      margin-top: 10px;
    }

    .report-text-top-margin {
      margin-top: 15px;
    }

    input[type=number]::-webkit-inner-spin-button, 
    input[type=number]::-webkit-outer-spin-button { 
        -webkit-appearance: none;
        -moz-appearance: none;
        margin: 0; 
    }

    input[type="number"]:hover,
    input[type="number"]:focus,
    input[type="number"] {
        -moz-appearance: textfield;
    }

    .numeric-align {
      display: inline;
    }

    input[type="text"] {
    max-width: 280px;
    margin-left: 0px !important;
    border-radius: 5px !important;
    text-transform: capitalize;
    }

    .all-reporttext-heading {
      text-decoration: underline;
      font-weight: bold;
      text-transform: capitalize;
      font-size: 18px;
      margin-top: -50px;
      text-align: left;
    }

    .all-reportText-content {
      margin-top: -10px;
    }

    .split-length-word.all-reportText-content {
      text-align: justify;
      word-break: unset;
    }

    .fixed-report-text-sidebar {
      position: fixed;
      right: 0;
      width: 45%;
    }

    .fixed-report-text-footer {
      position: fixed;
      left: 15 !important;
      bottom: 0;
      background-color: white;
    }

    .left-margin {
      margin-left: 60px;
      width: 90%;
    }

    .overflow {
      /* max-height: 500px; */
      overflow-x: hidden;
    }

    @media (max-width: 650px) {
  

      .left-margin {
        margin-left: 20px;
      }

      .keydiagram {
        width: 100%;
        margin-left: 4%;
      } 
      .row.content-area {
        padding: 0px 5px;
      }

      .text-right.border-0 > h4 {
        padding-right: 20px;
      }

      .keydiagram {
        width: 100%;
        text-align: center;
        margin-left: 0px !important;
      }
    }
    @media (max-width: 1024px) {
      .keydiagram {
        width: 100%;
        margin-left: 9%;
      }
      .img-max-width {
        width: 80% !important;
      }
    }
    @media (max-width: 1023px) {
      .fixed-report-text-sidebar {
        position: relative;
      }
    }

    .upload-button-size {
    	font-size: 100% !important;
    }
  
  `]
            },] },
];
/**
 * @nocollapse
 */
AssistNumericElementComponent.ctorParameters = () => [
    { type: FormBuilder, },
    { type: SimulatorEngineService, },
];
AssistNumericElementComponent.propDecorators = {
    'numericDataElement': [{ type: Input },],
    'imagePath': [{ type: Input },],
    'returnNumericElement': [{ type: Output },],
};

const $$2 = require('jquery');
class AssistChoiceElementComponent {
    /**
     * @param {?} formBuilder
     * @param {?} simulatorEngineService
     */
    constructor(formBuilder, simulatorEngineService) {
        this.formBuilder = formBuilder;
        this.simulatorEngineService = simulatorEngineService;
        this.returnChoiceElement = new EventEmitter();
        this.choiceChange = new EventEmitter();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.createChoiceElementForm();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        if (this.choiceDataElement.currentValue !== undefined) {
            $$2('#' + this.choiceDataElement.currentValue + '_' + this.choiceDataElement.id).prop('checked', true);
            this.choiceValue = this.choiceDataElement.currentValue;
            for (const /** @type {?} */ choice in this.choiceDataElement.choiceInfo) {
                if (this.choiceDataElement.choiceInfo[choice].value === this.choiceDataElement.currentValue) {
                    this.simulatorEngineService.addOrUpdateDataElement(this.choiceDataElement.id, this.choiceDataElement.currentValue, this.choiceDataElement.choiceInfo[choice].label);
                }
            }
            const /** @type {?} */ customEvent = document.createEvent('Event');
            customEvent.initEvent('change', true, true);
            if (this.choiceDataElement.choiceInfo.length <= 5) {
                $$2('#' + this.choiceDataElement.currentValue + '_' + this.choiceDataElement.id)[0].dispatchEvent(customEvent);
            }
            else {
                $$2('#' + this.choiceDataElement.id).val(this.choiceDataElement.currentValue);
                $$2('#' + this.choiceDataElement.id)[0].dispatchEvent(customEvent);
            }
        }
        $$2('#div_' + this.choiceDataElement.id + '_other').hide();
    }
    /**
     * @param {?} elementId
     * @param {?} selectedElement
     * @param {?} selectedText
     * @param {?} selectedValue
     * @return {?}
     */
    choiceSelected(elementId, selectedElement, selectedText, selectedValue) {
        const /** @type {?} */ choiceElement = new ChoiceElement();
        choiceElement.elementId = elementId;
        choiceElement.selectedValue = selectedValue;
        choiceElement.selectedText = selectedText;
        this.showOrHideFreeText(elementId, choiceElement.selectedValue);
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = elementId;
        this.selectedCondition.selectedCondition = selectedElement;
        this.selectedCondition.selectedValue = selectedText;
        this.returnChoiceElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    }
    /**
     * @param {?} element
     * @param {?} selectedCondition
     * @return {?}
     */
    dropdownChoiceSelected(element, selectedCondition) {
        const /** @type {?} */ choiceElement = new ChoiceElement();
        choiceElement.elementId = element.id;
        choiceElement.selectedValue = (element.selectedOptions[0].label === 'Other, please specify…') ? 'other' : element.value;
        choiceElement.selectedText = element.selectedOptions[0].label;
        this.showOrHideFreeText(element.id, choiceElement.selectedValue);
        if (this.choiceValue === 'undefined' || this.choiceValue === undefined || this.choiceValue === '') {
            choiceElement.selectedText = '';
            choiceElement.selectedValue = '';
        }
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = element.id;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = element.selectedOptions[0].label;
        this.returnChoiceElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    }
    /**
     * @return {?}
     */
    createChoiceElementForm() {
        this.choiceElementForm = this.formBuilder.group({
            checkBox: ['', Validators.required],
        }, {
            validator: this.specificValueInsideRange('checkBox')
        });
    }
    /**
     * @param {?} elementId
     * @param {?} selectedValue
     * @return {?}
     */
    showOrHideFreeText(elementId, selectedValue) {
        if (selectedValue === 'other') {
            $$2('#div_' + elementId + '_other').show();
        }
        else {
            $$2('#div_' + elementId + '_other').hide();
            $$2('#txt_other_' + elementId).val('');
        }
    }
    /**
     * @param {?} element
     * @param {?} elementId
     * @param {?} selectedCondition
     * @return {?}
     */
    updateFreeText(element, elementId, selectedCondition) {
        const /** @type {?} */ choiceElement = new ChoiceElement();
        choiceElement.elementId = elementId;
        choiceElement.selectedValue = (element.value === 'Other') ? 'other' : element.value;
        choiceElement.selectedText = element.value;
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = elementId;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = element.value;
        this.returnChoiceElement.emit({ receivedElement: choiceElement, selectedCondition: this.selectedCondition });
    }
    /**
     * @param {?} checkBoxKey
     * @return {?}
     */
    specificValueInsideRange(checkBoxKey) {
        return (group) => {
            const /** @type {?} */ choiceControl = group.controls[checkBoxKey];
            if ((choiceControl.value === 'undefined' || choiceControl.value === '' || this.choiceValue === undefined || this.choiceValue === '')) {
                return choiceControl.setErrors({ notEquivalent: true });
            }
            else {
                return choiceControl.setErrors(null);
            }
        };
    }
}
AssistChoiceElementComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-choice-element',
                template: `
    <canvas id='Can-ImgMap'>

    </canvas>
    <form [formGroup]="choiceElementForm" novalidate>
    <div class="col-xs-4 col-sm-6 text-left content-padding">
      <label class="control-label DEElement" >
        {{choiceDataElement.label}}
      </label>
      <ng-container *ngIf="choiceDataElement.hint !== '' && choiceDataElement.hint !== undefined">
          <a>
            <span class="glyphicon glyphicon-info-sign" data-toggle="tooltip" data-placement="right" title="{{choiceDataElement.hint}}"></span>
          </a>
        </ng-container>
        <ng-container *ngIf="choiceDataElement.diagrams != undefined ">
          <acr-hint-diagram [DataElement]="choiceDataElement" [imagePath]="imagePath"></acr-hint-diagram>
        </ng-container>
        <div *ngIf="choiceElementForm.controls['checkBox'].invalid  && this.choiceDataElement.isRequired " class="required-field" title="Required Field">
         *
        </div>
    </div>

    <div class="col-xs-8 col-sm-6 text-left content-padding">
      <div class="input-group">
        <div class="row">
          <div class="col-sm-12">
            <ng-container *ngIf="choiceDataElement.choiceInfo.length == 2">
              <ng-container *ngIf="imagePath != undefined">
                <div id="radio-inline">
                  <ng-container *ngFor="let choice of choiceDataElement.choiceInfo">
                    <div class="row">
                      <div class="col-sm-12">
                          <input [(ngModel)]="choiceValue" id="{{choice.value}}_{{choiceDataElement.id}}" type="radio" formControlName="checkBox" value="{{choice.value}}"
                          (change)="choiceSelected(choiceDataElement.id, choiceDataElement.label, (choice.reportText !== undefined) ? choice.reportText : choice.label, choice.value)">
                          <label for="{{choice.value}}_{{choiceDataElement.id}}" class="rad DEValues" >{{choice.label}}</label>
                      </div>
                    </div>
                  </ng-container>
                  <ng-container *ngIf="choiceDataElement.allowFreetext">
                    <div class="row">
                      <div class="col-sm-12">
                          <input id="other_{{choiceDataElement.id}}" type="radio" formControlName="checkBox" value="other"  
                          (change)="choiceSelected(choiceDataElement.id, choiceDataElement.label, 'Other', 'other')">
                          <label for="other_{{choiceDataElement.id}}" class="rad DEValues" >Other, please specify…</label>
                      </div>
                    </div>
                  </ng-container> 
                  <ng-container *ngIf="choiceDataElement.allowFreetext">
                    <div id='div_{{choiceDataElement.id}}_other' class="row">
                      <div class="col-sm-12">
                          <input id="txt_other_{{choiceDataElement.id}}" class="form-control" type="text" formControlName="checkBox" value="other"
                           (keyup)='updateFreeText($event.target, choiceDataElement.id, choiceDataElement.label)' placeholder="Please specify '{{choiceDataElement.label}}'"> 
                      </div>
                    </div>
                  </ng-container>        
                </div>
              </ng-container>
            </ng-container>
            <ng-container *ngIf="choiceDataElement.choiceInfo.length != 2">
              <ng-container *ngIf="choiceDataElement.choiceInfo.length > 5 || (choiceDataElement.choiceInfo.length === 5 && choiceDataElement.allowFreetext) ">
                  <select [(ngModel)]="choiceValue" id="{{choiceDataElement.id}}" (change)="dropdownChoiceSelected($event.target, choiceDataElement.label)" formControlName="checkBox">
                    <option [value]="Select" [selected]="true">--Select--</option>
                    <option *ngFor="let choice of choiceDataElement.choiceInfo" [value]="choice.value" [selected] = "choice.value === choiceDataElement.currentValue" >{{choice.label}}</option>
                    <option *ngIf="choiceDataElement.allowFreetext" [value]="other" [selected]='other' >Other, please specify…</option>
                  </select>
                  <div id='div_{{choiceDataElement.id}}_other' class="row">
                      <div class="col-sm-12">
                          <input id="txt_other_{{choiceDataElement.id}}" class="form-control" type="text" formControlName="checkBox" value="other" 
                          placeholder="Please specify '{{choiceDataElement.label}}'" (keyup)='updateFreeText($event.target, choiceDataElement.id, choiceDataElement.label)'>
                      </div>
                    </div>
              </ng-container>
              <ng-container *ngIf="choiceDataElement.choiceInfo.length === 5 && !choiceDataElement.allowFreetext">
                <ng-container *ngFor="let choice of choiceDataElement.choiceInfo">
                  <div id="radio-inline">
                    <div class="row">
                      <div class="col-sm-12">
                          <input [(ngModel)]="choiceValue" id="{{choice.value}}_{{choiceDataElement.id}}" type="radio" formControlName="checkBox" value="{{choice.value}}" 
                          (change)="choiceSelected(choiceDataElement.id, choiceDataElement.label, (choice.reportText !== undefined) ? choice.reportText : choice.label, choice.value)">
                          <label for="{{choice.value}}_{{choiceDataElement.id}}" class="rad DEValues" >{{choice.label}}</label>
                      </div>
                    </div>
                  </div>
                </ng-container>
              </ng-container>

              <ng-container *ngIf="(choiceDataElement.choiceInfo.length < 5 && choiceDataElement.allowFreetext) || (choiceDataElement.choiceInfo.length < 5 && !choiceDataElement.allowFreetext)">
                  <ng-container *ngFor="let choice of choiceDataElement.choiceInfo">
                    <div id="radio-inline">
                      <div class="row">
                        <div class="col-sm-12">
                            <input  [(ngModel)]="choiceValue" id="{{choice.value}}_{{choiceDataElement.id}}" type="radio" formControlName="checkBox" value="{{choice.value}}" 
                            (change)="choiceSelected(choiceDataElement.id, choiceDataElement.label, (choice.reportText !== undefined) ? choice.reportText : choice.label, choice.value)">
                            <label for="{{choice.value}}_{{choiceDataElement.id}}" class="rad DEValues" >{{choice.label}}</label>
                        </div>
                      </div>
                    </div>
                  </ng-container>
                  <ng-container *ngIf="choiceDataElement.allowFreetext">
                    <div id="radio-inline">
                        <div class="row">
                          <div class="col-sm-12">
                              <input id="other_{{choiceDataElement.id}}" type="radio" formControlName="checkBox" value="other" 
                              (change)="choiceSelected(choiceDataElement.id, choiceDataElement.label, 'Other', 'other')">
                              <label for="other_{{choiceDataElement.id}}" class="rad DEValues" >Other, please specify…</label>
                          </div>
                        </div>
                      </div>
                      <div id='div_{{choiceDataElement.id}}_other' class="row">
                          <div class="col-sm-12">
                              <input id="txt_other_{{choiceDataElement.id}}" class="form-control" type="text" formControlName="checkBox" value="other" 
                              placeholder="Please specify '{{choiceDataElement.label}}'" (keyup)="updateFreeText($event.target, choiceDataElement.id, choiceDataElement.label)">
                          </div>
                        </div>
                    </ng-container>
                </ng-container>
            </ng-container>
          </div>
        </div>
        <!-- imagemap will be displyed here -->
        <ng-container *ngIf="choiceDataElement.imageMap != undefined && imagePath != undefined">
          <div class="row">
            <div class="col-sm-12">
              <acr-image-map [DataElement]="choiceDataElement" [imagePath]="imagePath"></acr-image-map>
            </div>
          </div>
        </ng-container>
      </div>
    </div>
    </form>
  `,
                styles: [`
    .DEValues {
      background: #f5f5f5;
      padding: 2px 10px 2px 1.5em;
      border: 1px solid #9b9b9b; /* keeps layout from jumping */
      border-radius: 5px;
    }
    input {
      position: absolute;
      margin-left: 5px;
      margin-top: 5px;
    }

    div{
        margin-top: 1px; 
    }
    input[type="radio"]:checked + label {
      background: #1e89b5;
      border-color: #9b9b9b;
      color: white;
    }input[type=file].inputfile {
      width: 0.1px;
      height: 0.1px;
      opacity: 0;
      overflow: hidden;
      position: absolute;
      z-index: -1;
      margin: 0;
    }

    input[type=file].inputfile+label:active,
    input[type=file].inputfile+label {
      max-width: 100%;
      font-size: 1.5rem;
      font-weight: 700;
      text-overflow: ellipsis;
      white-space: nowrap;
      cursor: pointer;
      display: inline-block;
      overflow: hidden;
      display: inline-block;
      color: #f1e5e6;
      background-color: #d3394c;
      text-indent: 0px;
      width: 130px;
    }

    input[type=file].inputfile+label:hover {
      background-color: #722040;
    }

    input[type=file].inputfile+label {
      cursor: pointer;
      /* "hand" cursor */
    }

    input[type=file].inputfile:hover+label {
      outline: 1px dotted #000;
      outline: -webkit-focus-ring-color auto 5px;
    }

    .right-fixed {
      position: fixed;
      right: 0px;
    }

    .row.report-text-top-margin.right-align{
      width: 80%;
      margin-left: 135px;
    }

    /* Master Styles */

    h1 {
      color: #369;
      font-family: Arial, Helvetica, sans-serif;
      font-size: 250%;
    }

    h2,
    h3 {
      color: #444;
      font-family: Arial, Helvetica, sans-serif;
      font-weight: lighter;
    }

    body {
      margin: 2em;
    }


    /*Apply background color for div having checked radio button*/

    input[type="radio"]:checked+div {
      background-color: #1e89b5 !important;
      border: 1px solid #9b9b9b;
      color: #ffffff;
    }


    /*Apply background color for div having no checked radio button*/

    input[type="radio"]+div {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
    }

    .checkbox>label {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
      height: auto;
      line-height: 25px;
      width: 100%;
      font-weight: bold;
    }

    .checkbox>label>input[type="checkbox"] {
      margin-left: -15px;
      margin-top: 6px;
    }

    .full-width span {
      font-weight: bold;
    }


    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;
        border: 1px solid #9B9B9B;
        }*/

    .DEElement {
      color: #363636;
      letter-spacing: -0.37px;
      word-wrap: break-word;
    }

    .DEValues {
      /*font-size: 12px;*/
      color: #4a4a4a;
      letter-spacing: -0.29px;
      width: 100%;
      min-width: 180px;
      max-width: 280px;
    }


    /* CHECKBOX OVERWRITE STYLES */

    .rad {
      cursor: pointer;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
      -webkit-user-select: none;
      -webkit-touch-callout: none;
    }

    .rad>input {
      /* HIDE ORG RADIO & CHECKBOX */
      visibility: hidden;
      position: absolute;
    }

    [type="radio"]+span::before {
      content: "";
      display: inline-block;
      width: 9px;
      height: 9px;
      border-radius: 1em;
      border: 0.1px solid #fff;
      -webkit-box-shadow: 0 0 0 1px #57aed0;
              box-shadow: 0 0 0 1px #57aed0;
      margin-right: 4px;
      -webkit-transition: 0.5s ease all;
      transition: 0.5s ease all;
      margin-left: -15px;
    }

    [type="radio"]:checked+span::before {
      background: #57aed0;
      -webkit-box-shadow: 0 0 0 2px #57aed0;
              box-shadow: 0 0 0 2px #57aed0;
      margin-top: auto;
      /*margin-left:-15px;*/
    }

    .reportText {
      font-size: 14px;
      color: #363636;
      letter-spacing: -0.49px;
      margin-top: 5px;
    }

    button:hover,
    button:focus,
    button.active,
    .btn-default:hover,
    .btn-default:focus,
    .item.active,
    .btn-default.active {
      background: #1e89b5 !important;
      color: #ffffff !important;
    }

    .hideInput {
      visibility: hidden;
      margin-left: 5px !important;
    }

    .panel {
      background-color: transparent;
    }

    .logo {
      height: 30px;
      width: 250px;
    }

    .navbar-blue {
      background-color: #00205b !important;
      color: #fff;
    }

    .navbar-brand-text {
      font-size: 30px;
      color: #fff;
      font-weight: normal;
      margin-top: 10px;
    }

    .close {
      margin-top: -20px !important;
    }


    /*.full-width {
            width: 320px !important;
        }*/

    #myNav.affix {
      width: 483px;
      top: 100;
    }

    #Can-ImgMap {
      pointer-events: none;
      position: absolute;
      opacity: 0.5;
    }


    /* Styles for Assist bootstrap*/

    .control-label {
      text-align: left !important;
    }

    .box-style {
      text-decoration: none;
      color: #363636 !important;
      border-radius: 3px;
      padding: 5px;
      font-weight: bold !important;
      width: 75%;
    }

    .findings {
      color: #ffffff !important;
      background-color: #5295b1 !important;
      border-color: #5295b1 !important;
      background-image: none !important;
      font-weight: bold;
      text-transform: capitalize;
      height: 45px;
      font-size: 16px;
      text-align: left;
    }

    .table-row {
      display: table-row;
      width: auto;
      clear: both;
    }

    .table-cell {
      display: table-cell;
      width: 475px;
      font-size: 12px;
      background-color: transparent;
      color: black;
      height: 25px;
      line-height: 25px;
      padding: 1px;
    }

    .imgMap-table-cell {
      width: 10% !important;
      vertical-align: middle;
    }

    .panel-default {
      min-width: 100%;
    }

    #footer {
      position: fixed;
      bottom: 0;
    }

    .row-style {
      bottom: 5px;
      position: fixed;
      top: 55px;
      overflow: auto;
      width: 100%;
    }

    .modal-dialog {
      top: 100px;
      margin-left: 50% !important;
    }

    .required-field {
      /* border: 1px solid red; */
      /* border-radius: 5px; */
      padding: 5px;
      font-size: 16px;
      color: red;
      /* width: 120px; */
      display: inline-block;
      font-weight: bold;
    }

    .xml-only-msg {
      border: 1px solid red;
      border-radius: 5px;
      padding: 5px;
      font-size: 12px;
      color: white;
      width: 223px;
      display: inline-block;
      font-weight: bold;
    }

    @media (min-width: 400px) and (max-width: 1024px) {
      .xml-only-msg {
        width: 120px;
      }
    }

    @media (max-width: 475px)  {
      .xml-only-msg {
        color: #000000
      }
    }
    .col-per-10 {
      border: 1px solid blue;
      padding: 15px 10px 15px 10px;
      border-radius: 10px;
      height: auto;
      width: 10%;
      float: left;
      position: fixed;
      min-height: 1px;
    }

    .btn-group>.btn:first-child {
      margin-left: 0;
      width: 165px;
      margin-top: 10px;
    }

    .col-md-10 {
      left: 200px;
    }

    .module-header {
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
      margin-left: -135px;
      margin-top: -15px;
      font-size: 14px;
      font-weight: bold;
      color: #363636;
    }

    .btn-group-justified {
      padding-left: 15px;
    }

    select {
      height: 35px;
      border-radius: 5px;
      max-width: 280px;
      width: 100%;
    }

    .findings select{
      max-width: 150px;
      margin-top: -3px;
    }
    .fixed-keydiagram {
      position: fixed !important;
      float: right;
      padding-right: 0px !important;
      margin-right: 10px;
      padding-left: 25px !important;
    }

    .center-align {
      text-align: center;
      width: 160px !important;
      padding: 0px !important;
    }

    .center-align div {
      width: 200px;
      margin-left: -10px;
    }

    .findings div {
      color: #363636 !important;
      margin-left: 100px !important;
      margin-top: -23.5px !important;
      height: 30px;
    }

    .findings div select {
      text-transform: capitalize;
    }

    .modal-backdrop {
      top: 10000px !important;
    }

    .tooltip-arrow {
      display: none !important;
    }

    .other-reportSection {
      font-weight: normal;
      margin-top: -10px;
      margin-left: 15px;
    }

    a:hover {
      text-decoration: none !important;
    }

    .no-btm-margin-table {
      margin-bottom: 0px !important;
    }

    .adjust-diagram {
      margin-top: 56px;
      right: 20px !important;
    }

    .adjust-diagram-image {
      top: 0px !important;
      margin-top: 0px !important;
    }

    .reportText-panel {
      width: 90%;
      margin-left: 2%;
    }

    .reportText-body {
      margin-left: 2%;
    }

    .top-Index {
      z-index: 99999 !important;
    }


    /* Master Styles */

    h1 {
      color: #369;
      font-family: Arial, Helvetica, sans-serif;
      font-size: 250%;
    }

    h2,
    h3 {
      color: #444;
      font-family: Arial, Helvetica, sans-serif;
      font-weight: lighter;
    }

    .div-simulator-container {
      margin: 0;
    }


    /*Apply background color for div having checked radio button*/

    .div-simulator-container input[type="radio"]:checked+div {
      background-color: #1e89b5 !important;
      border: 1px solid #9b9b9b;
      color: #ffffff;
    }


    /*Apply background color for div having no checked radio button*/

    .div-simulator-container input[type="radio"]+div {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
    }

    .div-simulator-container .checkbox>label {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
      height: 25px;
      line-height: 25px;
    }

    .div-simulator-container .checkbox>label>input[type="checkbox"] {
      margin-left: -15px;
      margin-top: 6px;
    }

    .div-simulator-container .full-width span {
      font-weight: bold;
    }


    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;
        border: 1px solid #9B9B9B;
        }*/

    .div-simulator-container .DEElement {
      color: #363636;
      letter-spacing: -0.37px;
      word-wrap: break-word;
    }

    .div-simulator-container .DEValues {
      /*font-size: 12px;*/
      color: #4a4a4a;
      letter-spacing: -0.29px;
    }


    /* CHECKBOX OVERWRITE STYLES */

    .div-simulator-container .rad {
      cursor: pointer;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
      -webkit-user-select: none;
      -webkit-touch-callout: none;
    }

    .div-simulator-container .rad>input {
      /* HIDE ORG RADIO & CHECKBOX */
      visibility: hidden;
      position: absolute;
    }

    .div-simulator-container [type="radio"]+span::before {
      content: "";
      display: inline-block;
      width: 9px;
      height: 9px;
      border-radius: 1em;
      border: 0.1px solid #fff;
      -webkit-box-shadow: 0 0 0 1px #57aed0;
              box-shadow: 0 0 0 1px #57aed0;
      margin-right: 4px;
      -webkit-transition: 0.5s ease all;
      transition: 0.5s ease all;
      margin-left: -15px;
    }

    [type="radio"]:checked+span::before {
      background: #57aed0;
      -webkit-box-shadow: 0 0 0 2px #57aed0;
              box-shadow: 0 0 0 2px #57aed0;
      margin-top: auto;
      /*margin-left:-15px;*/
    }

    .div-simulator-container .reportText {
      font-size: 14px;
      color: #363636;
      letter-spacing: -0.49px;
    }

    .div-simulator-container button:hover,
    .div-simulator-container button:focus,
    .div-simulator-container button.active,
    .div-simulator-container .btn-default:hover,
    .btn-default:focus,
    .div-simulator-container .item.active,
    .div-simulator-container .btn-default.active {
      background: #1e89b5 !important;
      color: #ffffff !important;
    }

    .div-simulator-container .hideInput {
      visibility: hidden;
      margin-left: 5px !important;
    }

    .div-simulator-container .panel {
      background-color: transparent;
    }

    .logo {
      height: 30px;
      width: 250px;
    }

    .navbar-blue {
      background-color: #00205b !important;
      color: #fff;
    }

    .navbar-brand-text {
      font-size: 30px;
      color: #fff;
      font-weight: normal;
      margin-top: 10px;
    }

    .div-simulator-container .close {
      margin-top: -20px !important;
    }


    /*.full-width {
            width: 320px !important;
        }*/

    #myNav.affix {
      width: 483px;
      top: 100;
    }

    #Can-ImgMap {
      pointer-events: none;
      position: absolute;
      opacity: 0.5;
    }


    /* Styles for Assist bootstrap*/

    .div-simulator-container .control-label {
      text-align: left !important;
    }

    .div-simulator-container .box-style {
      text-decoration: none;
      color: #363636 !important;
      border-radius: 3px;
      padding: 5px;
      font-weight: bold !important;
      width: 75%;
    }

    .div-simulator-container .findings {
      color: #ffffff !important;
      background-color: #5295b1 !important;
      border-color: #5295b1 !important;
      background-image: none !important;
      font-weight: bold;
      text-transform: capitalize;
      height: 40px;
    }

    .div-simulator-container .table-row {
      display: table-row;
      width: auto;
      clear: both;
    }

    .div-simulator-container .table-cell {
      display: table-cell;
      width: 475px;
      font-size: 12px;
      background-color: transparent;
      color: black;
      height: 25px;
      line-height: 25px;
      padding: 1px;
      border-bottom: none;
    }

    .div-simulator-container .imgMap-table-cell {
      width: 10% !important;
      vertical-align: middle;
    }

    .div-simulator-container .panel-default {
      min-width: 600px;
      margin: 0 !important;
      background-color: white;
    }

    .div-simulator-container .footerBlock {
      position: fixed;
      bottom: 55px;
    }

    .div-simulator-container .row-style {
      bottom: 5px;
      position: fixed;
      top: 55px;
      overflow: auto;
      width: 100%;
    }

    .div-simulator-container .modal-dialog {
      top: 100px;
      /*margin-left: 50% !important;*/
      margin-left: 0 !important;
    }

    .div-simulator-container .required-field {
      border: 1px solid #edd1d1;
      border-radius: 5px;
      padding: 5px;
      font-size: 12px;
      color: #cd5c5c;
      width: 125px;
    }

    .div-simulator-container .col-per-10 {
      border: 1px solid blue;
      padding: 15px 10px 15px 10px;
      border-radius: 10px;
      height: auto;
      width: 10%;
      float: left;
      position: fixed;
      min-height: 1px;
    }

    .div-simulator-container .btn-group>.btn:first-child {
      margin-left: 0;
      width: 165px;
      margin-top: 10px;
    }

    .div-simulator-container .col-md-10 {
      left: 200px;
    }

    .div-simulator-container .module-header {
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
      margin-left: -135px;
      margin-top: -15px;
      font-size: 14px;
      font-weight: bold;
      color: #363636;
    }

    .div-simulator-container .btn-group-justified {
      padding-left: 15px;
    }

    .div-simulator-container select {
      height: 28px;
      border-radius: 5px;
    }

    .div-simulator-container .panel-body {
      padding: 10px !important;
    }

    .div-simulator-container .fixed-keydiagram {
      position: fixed !important;
      float: right;
      padding-right: 0px !important;
      margin-right: 10px;
      padding-left: 25px !important;
    }

    .div-simulator-container .center-align {
      text-align: center;
      width: 160px !important;
      padding: 0px !important;
    }

    .div-simulator-container .center-align div {
      width: 200px;
      margin-left: -10px;
    }

    .div-simulator-container .findings div {
      color: #363636 !important;
      margin-left: 97px !important;
      margin-top: -29.5px !important;
      height: 30px;
    }

    .div-simulator-container .findings div select {
      text-transform: capitalize;
    }

    .div-simulator-container .modal-backdrop {
      top: 10000px !important;
    }

    .div-simulator-container .tooltip-arrow {
      display: none !important;
    }

    .div-simulator-container .other-reportSection {
      font-weight: normal;
      margin-top: -10px;
      margin-left: 15px;
    }

    .div-simulator-container a:hover {
      text-decoration: none !important;
    }

    .div-simulator-container .no-btm-margin-table {
      margin-bottom: 0px !important;
    }

    .div-simulator-container .adjust-diagram {
      margin-top: 56px;
      right: 20px !important;
    }

    .adjust-diagram-image {
      top: 0px !important;
      margin-top: 0px !important;
    }

    @media only screen and (min-width: 1224px) {
      .tab-content {
        padding: 5px;
      }
    }

    @media (min-width: 768px) {
      #page-content-wrapper {
        padding: 0px 20px;
        margin-top: 15px;
      }
    }

    #sidebar-wrapper {
      left: 175px;
      margin-left: -175px;
    }

    #rowContent {
      padding-bottom: 120px;
    }

    @media only screen and (min-width: 1224px) {
      .fixed-reportText {
        width: 1064px;
      }
    }

    @media only screen and (min-width: 1824px) {
      .fixed-reportText {
        width: 1260px;
      }
    }

    @media only screen and (min-width: 1224px) {
      .modal-lg {
        left: 0;
        /* left: -250px; */
      }
    }

    .form-group {
      margin-bottom: 15px;
    }

    .control-label {
      margin-top: 0;
      margin-left: 0;
    }

    .div-simulator-container .checkbox>label {
      height: 30px;
      line-height: 30px;
    }

    .div-simulator-container .checkbox>label>input[type="checkbox"] {
      margin-top: 8px;
    }

    .div-simulator-container select {
      height: 30px;
      border-radius: 5px;
      font-size: 12px;
      width: 280px;
    }

    .div-simulator-container .input-group {
      width: 280px;
    }

    .div-simulator-container .input-group .form-control {
      border-radius: 5px;
      -webkit-box-shadow: none;
              box-shadow: none;
      border: 1px solid #969696;
    }

    .div-simulator-container .imgMap-table-cell {
      padding-left: 10px;
    }

    @media (min-width: 1224px) {
      .modal-lg {
        width: 630px;
      }
    }

    .tableImagemap {
      table-layout: fixed;
    }

    @media (min-width: 1850px) {
      .modal-lg {
        width: 900px;
      }
      .tableImagemap {
        table-layout: inherit;
      }
    }

    .col-centered {
      float: none;
      margin: 0 auto;
    }

    .checkbox {
      max-width: 280px;
    }

    [type="number"] {
      max-width: 280px;
      /*margin-left: -15px;*/
    }

    .input-group {
      width: 100%;
    }

    @media (min-width:1441px) {
      .DEValues {
        /*min-width: 280px;
        max-width: 280px;*/
        height: auto;
      }
    }

    @media (max-width:1024px) {
      .adjust-diagram-image {
        width: 50%;
      }
    }

    @media (min-width:1921px) {
      .adjust-diagram-image {
        width: 50%;
      }
    }

    .row {
      font-weight: bold;
    }

    .carousel-item.item img {
      width: 100% !important;
    }

    .carousel-indicators {
      display: none !important;
    }

    .display-inline {
      display: inline;
    }

    .font-weight-normal {
      font-weight: normal;
    }

    .font-weight-bold {
      font-weight: bold;
    }

    .color-white {
      color: #ffffff;
    }

    .bottom-margin{
      margin-bottom: 25px;
    }

    .reportText-content {
      white-space: pre-line; 
      font-weight: bold;
      margin: -40px 0px;
      height: -webkit-fit-content;
      height: -moz-fit-content;
      height: fit-content;
    }

    .no-bottom-margin {
      margin-bottom: 0px !important;
    }
    .reportText-main-content{
      font-size: 16px;
    }

    .split-length-word {
      word-break: break-all;
      text-align: left;
      margin: 0px 0px;
    }

    .img-max-width {
      width: 70% !important;
    }

    .keydiagram {
      text-align: center;
      margin-top: 10px;
    }

    .report-text-top-margin {
      margin-top: 15px;
    }

    input[type=number]::-webkit-inner-spin-button, 
    input[type=number]::-webkit-outer-spin-button { 
        -webkit-appearance: none;
        -moz-appearance: none;
        margin: 0; 
    }

    input[type="number"]:hover,
    input[type="number"]:focus,
    input[type="number"] {
        -moz-appearance: textfield;
    }

    .numeric-align {
      display: inline;
    }

    input[type="text"] {
    max-width: 280px;
    margin-left: 0px !important;
    border-radius: 5px !important;
    text-transform: capitalize;
    }

    .all-reporttext-heading {
      text-decoration: underline;
      font-weight: bold;
      text-transform: capitalize;
      font-size: 18px;
      margin-top: -50px;
      text-align: left;
    }

    .all-reportText-content {
      margin-top: -10px;
    }

    .split-length-word.all-reportText-content {
      text-align: justify;
      word-break: unset;
    }

    .fixed-report-text-sidebar {
      position: fixed;
      right: 0;
      width: 45%;
    }

    .fixed-report-text-footer {
      position: fixed;
      left: 15 !important;
      bottom: 0;
      background-color: white;
    }

    .left-margin {
      margin-left: 60px;
      width: 90%;
    }

    .overflow {
      /* max-height: 500px; */
      overflow-x: hidden;
    }

    @media (max-width: 650px) {
  

      .left-margin {
        margin-left: 20px;
      }

      .keydiagram {
        width: 100%;
        margin-left: 4%;
      } 
      .row.content-area {
        padding: 0px 5px;
      }

      .text-right.border-0 > h4 {
        padding-right: 20px;
      }

      .keydiagram {
        width: 100%;
        text-align: center;
        margin-left: 0px !important;
      }
    }
    @media (max-width: 1024px) {
      .keydiagram {
        width: 100%;
        margin-left: 9%;
      }
      .img-max-width {
        width: 80% !important;
      }
    }
    @media (max-width: 1023px) {
      .fixed-report-text-sidebar {
        position: relative;
      }
    }

    .upload-button-size {
    	font-size: 100% !important;
    }
  
  `]
            },] },
];
/**
 * @nocollapse
 */
AssistChoiceElementComponent.ctorParameters = () => [
    { type: FormBuilder, },
    { type: SimulatorEngineService, },
];
AssistChoiceElementComponent.propDecorators = {
    'choiceDataElement': [{ type: Input },],
    'imagePath': [{ type: Input },],
    'returnChoiceElement': [{ type: Output },],
    'choiceChange': [{ type: Output },],
};

const $$3 = require('jquery');
class AssistMultiChoiceElementComponent {
    /**
     * @param {?} formBuilder
     * @param {?} simulatorEngineService
     */
    constructor(formBuilder, simulatorEngineService) {
        this.formBuilder = formBuilder;
        this.simulatorEngineService = simulatorEngineService;
        this.returnMultiChoice = new EventEmitter();
        this.multiElements = [];
        this.multiChoiceValues = [];
        this.multiChoiceComaprisonValues = [];
        this.choiceValue = [];
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.createMultiChoiceElementForm();
    }
    /**
     * @return {?}
     */
    ngAfterViewInit() {
        if (this.multiChoiceElement.currentValue !== undefined) {
            for (const /** @type {?} */ choice in this.multiChoiceElement.choiceInfo) {
                if (Array.isArray(this.multiChoiceElement.currentValue)) {
                    for (const /** @type {?} */ currValue of this.multiChoiceElement.currentValue) {
                        // this.choiceValue = this.multiChoiceElement.currentValue;
                        if (currValue === this.multiChoiceElement.choiceInfo[choice].value && this.multiChoiceElement.choiceInfo[choice].value !== undefined) {
                            this.choiceValue = this.multiChoiceElement.currentValue;
                            this.simulatorEngineService.addOrUpdateDataElement(this.multiChoiceElement.id, this.multiChoiceElement.currentValue, this.multiChoiceElement.choiceInfo[choice].label);
                            const /** @type {?} */ customEvent = document.createEvent('Event');
                            $$3('#' + this.multiChoiceElement.id + '_' + this.multiChoiceElement.currentValue[choice]).prop('checked', true);
                            customEvent.initEvent('change', true, true);
                            this.selctValue = currValue;
                            $$3('#' + this.multiChoiceElement.id + '_' + this.multiChoiceElement.currentValue[choice])[0].dispatchEvent(customEvent);
                            break;
                        }
                    }
                }
                else {
                    if (this.multiChoiceElement.currentValue === this.multiChoiceElement.choiceInfo[choice].value && this.multiChoiceElement.choiceInfo[choice].value !== undefined) {
                        // this.checked = true;
                        this.simulatorEngineService.addOrUpdateDataElement(this.multiChoiceElement.id, this.multiChoiceElement.currentValue, this.multiChoiceElement.choiceInfo[choice].label);
                        this.choiceValue = this.multiChoiceElement.currentValue;
                        const /** @type {?} */ customEvent = document.createEvent('Event');
                        $$3('#' + this.multiChoiceElement.id + '_' + this.multiChoiceElement.currentValue).prop('checked', true);
                        customEvent.initEvent('change', true, true);
                        $$3('#' + this.multiChoiceElement.id + '_' + this.multiChoiceElement.currentValue)[0].dispatchEvent(customEvent);
                    }
                }
                if (this.selctValue === this.multiChoiceElement.choiceInfo[choice].value) {
                    this.checked = this.multiChoiceElement.choiceInfo[choice].value;
                }
                else {
                    this.checked = undefined;
                }
            }
        }
    }
    /**
     * @param {?} elementId
     * @param {?} selectedCondition
     * @param {?} value
     * @param {?} event
     * @return {?}
     */
    updateMultiChoice(elementId, selectedCondition, value, event) {
        const /** @type {?} */ multiElement = new MultiChoiceElement();
        if (event.currentTarget.checked) {
            this.multiChoiceValues.push(value);
            this.multiChoiceComaprisonValues.push(event.currentTarget.value);
            this.checked = event.currentTarget.value;
            if (this.selctValue === event.currentTarget.value) {
                this.checked = event.currentTarget.value;
            }
            else {
                this.checked = undefined;
            }
        }
        else {
            const /** @type {?} */ index = this.multiChoiceValues.indexOf(value);
            this.checked = undefined;
            const /** @type {?} */ comparisonIndex = this.multiChoiceComaprisonValues.indexOf(event.currentTarget.value);
            if (index > -1) {
                this.multiChoiceValues.splice(index, 1);
            }
            if (comparisonIndex > -1) {
                this.multiChoiceComaprisonValues.splice(comparisonIndex, 1);
            }
        }
        multiElement.elementId = elementId;
        multiElement.selectedValues = this.multiChoiceValues;
        multiElement.selectedComparisonValues = this.multiChoiceComaprisonValues;
        this.selectedCondition = new SelectedCondition();
        this.selectedCondition.selectedConditionId = elementId;
        this.selectedCondition.selectedCondition = selectedCondition;
        this.selectedCondition.selectedValue = this.multiChoiceValues;
        this.returnMultiChoice.emit({ receivedElement: multiElement, selectedCondition: this.selectedCondition });
        // this.returnMultiChoice.emit(multiElement);
    }
    /**
     * @return {?}
     */
    createMultiChoiceElementForm() {
        this.multiChoiceElementForm = this.formBuilder.group({
            multiCheckBox: ['', Validators.required],
        }, {
            validator: this.specificValueInsideRange('multiCheckBox')
        });
    }
    /**
     * @param {?} checkBoxKey
     * @return {?}
     */
    specificValueInsideRange(checkBoxKey) {
        return (group) => {
            const /** @type {?} */ choiceControl = group.controls[checkBoxKey];
            if (this.multiChoiceElement.isRequired) {
                return choiceControl.setErrors({ notEquivalent: true });
            }
            else {
                return choiceControl.setErrors(null);
            }
        };
    }
}
AssistMultiChoiceElementComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-multi-choice-element',
                template: `
    <form [formGroup]="multiChoiceElementForm" novalidate>
      <div class="col-xs-4 col-sm-6 text-left content-padding">
        <label class="control-label DEElement" id="{{multiChoiceElement.id}}">
          {{multiChoiceElement.label}}
        </label>
        <ng-container *ngIf="multiChoiceElement.hint !== '' && multiChoiceElement.hint !== undefined">
          <a>
            <span class="glyphicon glyphicon-info-sign" data-toggle="tooltip" data-placement="right" title="{{multiChoiceElement.hint}}"></span>
          </a>
        </ng-container>
        <ng-container *ngIf="multiChoiceElement.diagrams != undefined ">
          <acr-hint-diagram [DataElement]="multiChoiceElement" [imagePath]="imagePath"></acr-hint-diagram>
        </ng-container>
        <div *ngIf="multiChoiceElementForm.controls['multiCheckBox'].invalid && !multiChoiceValues.length" class="required-field" title="Required Field">
          *
        </div>
      </div>
      <div class="col-xs-8 col-sm-6 text-left content-padding">
        <div class="row">
          <div class="col-sm-12">
            <ng-container *ngFor="let choice of multiChoiceElement.choiceInfo">
              <div class="checkbox" title="{{choice.hint}}">
                <label>
                    <input [(ngModel)]="checked" id="{{multiChoiceElement.id}}_{{choice.value}}" type="checkbox" value={{choice.value}} [checked]="false" formControlName="multiCheckBox" 
                    (change)="updateMultiChoice(multiChoiceElement.id, multiChoiceElement.label, (choice.reportText !== undefined) ? choice.reportText : choice.label, $event)">
                    <span> {{choice.label}}</span>
                </label>
              </div>
            </ng-container>
          </div>
        </div>
      </div>
    </form>
  `,
                styles: [`
    input[type=file].inputfile {
      width: 0.1px;
      height: 0.1px;
      opacity: 0;
      overflow: hidden;
      position: absolute;
      z-index: -1;
      margin: 0;
    }

    input[type=file].inputfile+label:active,
    input[type=file].inputfile+label {
      max-width: 100%;
      font-size: 1.5rem;
      font-weight: 700;
      text-overflow: ellipsis;
      white-space: nowrap;
      cursor: pointer;
      display: inline-block;
      overflow: hidden;
      display: inline-block;
      color: #f1e5e6;
      background-color: #d3394c;
      text-indent: 0px;
      width: 130px;
    }

    input[type=file].inputfile+label:hover {
      background-color: #722040;
    }

    input[type=file].inputfile+label {
      cursor: pointer;
      /* "hand" cursor */
    }

    input[type=file].inputfile:hover+label {
      outline: 1px dotted #000;
      outline: -webkit-focus-ring-color auto 5px;
    }

    .right-fixed {
      position: fixed;
      right: 0px;
    }

    .row.report-text-top-margin.right-align{
      width: 80%;
      margin-left: 135px;
    }

    /* Master Styles */

    h1 {
      color: #369;
      font-family: Arial, Helvetica, sans-serif;
      font-size: 250%;
    }

    h2,
    h3 {
      color: #444;
      font-family: Arial, Helvetica, sans-serif;
      font-weight: lighter;
    }

    body {
      margin: 2em;
    }


    /*Apply background color for div having checked radio button*/

    input[type="radio"]:checked+div {
      background-color: #1e89b5 !important;
      border: 1px solid #9b9b9b;
      color: #ffffff;
    }


    /*Apply background color for div having no checked radio button*/

    input[type="radio"]+div {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
    }

    .checkbox>label {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
      height: auto;
      line-height: 25px;
      width: 100%;
      font-weight: bold;
    }

    .checkbox>label>input[type="checkbox"] {
      margin-left: -15px;
      margin-top: 6px;
    }

    .full-width span {
      font-weight: bold;
    }


    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;
        border: 1px solid #9B9B9B;
        }*/

    .DEElement {
      color: #363636;
      letter-spacing: -0.37px;
      word-wrap: break-word;
    }

    .DEValues {
      /*font-size: 12px;*/
      color: #4a4a4a;
      letter-spacing: -0.29px;
      width: 100%;
      min-width: 180px;
      max-width: 280px;
    }


    /* CHECKBOX OVERWRITE STYLES */

    .rad {
      cursor: pointer;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
      -webkit-user-select: none;
      -webkit-touch-callout: none;
    }

    .rad>input {
      /* HIDE ORG RADIO & CHECKBOX */
      visibility: hidden;
      position: absolute;
    }

    [type="radio"]+span::before {
      content: "";
      display: inline-block;
      width: 9px;
      height: 9px;
      border-radius: 1em;
      border: 0.1px solid #fff;
      -webkit-box-shadow: 0 0 0 1px #57aed0;
              box-shadow: 0 0 0 1px #57aed0;
      margin-right: 4px;
      -webkit-transition: 0.5s ease all;
      transition: 0.5s ease all;
      margin-left: -15px;
    }

    [type="radio"]:checked+span::before {
      background: #57aed0;
      -webkit-box-shadow: 0 0 0 2px #57aed0;
              box-shadow: 0 0 0 2px #57aed0;
      margin-top: auto;
      /*margin-left:-15px;*/
    }

    .reportText {
      font-size: 14px;
      color: #363636;
      letter-spacing: -0.49px;
      margin-top: 5px;
    }

    button:hover,
    button:focus,
    button.active,
    .btn-default:hover,
    .btn-default:focus,
    .item.active,
    .btn-default.active {
      background: #1e89b5 !important;
      color: #ffffff !important;
    }

    .hideInput {
      visibility: hidden;
      margin-left: 5px !important;
    }

    .panel {
      background-color: transparent;
    }

    .logo {
      height: 30px;
      width: 250px;
    }

    .navbar-blue {
      background-color: #00205b !important;
      color: #fff;
    }

    .navbar-brand-text {
      font-size: 30px;
      color: #fff;
      font-weight: normal;
      margin-top: 10px;
    }

    .close {
      margin-top: -20px !important;
    }


    /*.full-width {
            width: 320px !important;
        }*/

    #myNav.affix {
      width: 483px;
      top: 100;
    }

    #Can-ImgMap {
      pointer-events: none;
      position: absolute;
      opacity: 0.5;
    }


    /* Styles for Assist bootstrap*/

    .control-label {
      text-align: left !important;
    }

    .box-style {
      text-decoration: none;
      color: #363636 !important;
      border-radius: 3px;
      padding: 5px;
      font-weight: bold !important;
      width: 75%;
    }

    .findings {
      color: #ffffff !important;
      background-color: #5295b1 !important;
      border-color: #5295b1 !important;
      background-image: none !important;
      font-weight: bold;
      text-transform: capitalize;
      height: 45px;
      font-size: 16px;
      text-align: left;
    }

    .table-row {
      display: table-row;
      width: auto;
      clear: both;
    }

    .table-cell {
      display: table-cell;
      width: 475px;
      font-size: 12px;
      background-color: transparent;
      color: black;
      height: 25px;
      line-height: 25px;
      padding: 1px;
    }

    .imgMap-table-cell {
      width: 10% !important;
      vertical-align: middle;
    }

    .panel-default {
      min-width: 100%;
    }

    #footer {
      position: fixed;
      bottom: 0;
    }

    .row-style {
      bottom: 5px;
      position: fixed;
      top: 55px;
      overflow: auto;
      width: 100%;
    }

    .modal-dialog {
      top: 100px;
      margin-left: 50% !important;
    }

    .required-field {
      /* border: 1px solid red; */
      /* border-radius: 5px; */
      padding: 5px;
      font-size: 16px;
      color: red;
      /* width: 120px; */
      display: inline-block;
      font-weight: bold;
    }

    .xml-only-msg {
      border: 1px solid red;
      border-radius: 5px;
      padding: 5px;
      font-size: 12px;
      color: white;
      width: 223px;
      display: inline-block;
      font-weight: bold;
    }

    @media (min-width: 400px) and (max-width: 1024px) {
      .xml-only-msg {
        width: 120px;
      }
    }

    @media (max-width: 475px)  {
      .xml-only-msg {
        color: #000000
      }
    }
    .col-per-10 {
      border: 1px solid blue;
      padding: 15px 10px 15px 10px;
      border-radius: 10px;
      height: auto;
      width: 10%;
      float: left;
      position: fixed;
      min-height: 1px;
    }

    .btn-group>.btn:first-child {
      margin-left: 0;
      width: 165px;
      margin-top: 10px;
    }

    .col-md-10 {
      left: 200px;
    }

    .module-header {
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
      margin-left: -135px;
      margin-top: -15px;
      font-size: 14px;
      font-weight: bold;
      color: #363636;
    }

    .btn-group-justified {
      padding-left: 15px;
    }

    select {
      height: 35px;
      border-radius: 5px;
      max-width: 280px;
      width: 100%;
    }

    .findings select{
      max-width: 150px;
      margin-top: -3px;
    }
    .fixed-keydiagram {
      position: fixed !important;
      float: right;
      padding-right: 0px !important;
      margin-right: 10px;
      padding-left: 25px !important;
    }

    .center-align {
      text-align: center;
      width: 160px !important;
      padding: 0px !important;
    }

    .center-align div {
      width: 200px;
      margin-left: -10px;
    }

    .findings div {
      color: #363636 !important;
      margin-left: 100px !important;
      margin-top: -23.5px !important;
      height: 30px;
    }

    .findings div select {
      text-transform: capitalize;
    }

    .modal-backdrop {
      top: 10000px !important;
    }

    .tooltip-arrow {
      display: none !important;
    }

    .other-reportSection {
      font-weight: normal;
      margin-top: -10px;
      margin-left: 15px;
    }

    a:hover {
      text-decoration: none !important;
    }

    .no-btm-margin-table {
      margin-bottom: 0px !important;
    }

    .adjust-diagram {
      margin-top: 56px;
      right: 20px !important;
    }

    .adjust-diagram-image {
      top: 0px !important;
      margin-top: 0px !important;
    }

    .reportText-panel {
      width: 90%;
      margin-left: 2%;
    }

    .reportText-body {
      margin-left: 2%;
    }

    .top-Index {
      z-index: 99999 !important;
    }


    /* Master Styles */

    h1 {
      color: #369;
      font-family: Arial, Helvetica, sans-serif;
      font-size: 250%;
    }

    h2,
    h3 {
      color: #444;
      font-family: Arial, Helvetica, sans-serif;
      font-weight: lighter;
    }

    .div-simulator-container {
      margin: 0;
    }


    /*Apply background color for div having checked radio button*/

    .div-simulator-container input[type="radio"]:checked+div {
      background-color: #1e89b5 !important;
      border: 1px solid #9b9b9b;
      color: #ffffff;
    }


    /*Apply background color for div having no checked radio button*/

    .div-simulator-container input[type="radio"]+div {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
    }

    .div-simulator-container .checkbox>label {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
      height: 25px;
      line-height: 25px;
    }

    .div-simulator-container .checkbox>label>input[type="checkbox"] {
      margin-left: -15px;
      margin-top: 6px;
    }

    .div-simulator-container .full-width span {
      font-weight: bold;
    }


    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;
        border: 1px solid #9B9B9B;
        }*/

    .div-simulator-container .DEElement {
      color: #363636;
      letter-spacing: -0.37px;
      word-wrap: break-word;
    }

    .div-simulator-container .DEValues {
      /*font-size: 12px;*/
      color: #4a4a4a;
      letter-spacing: -0.29px;
    }


    /* CHECKBOX OVERWRITE STYLES */

    .div-simulator-container .rad {
      cursor: pointer;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
      -webkit-user-select: none;
      -webkit-touch-callout: none;
    }

    .div-simulator-container .rad>input {
      /* HIDE ORG RADIO & CHECKBOX */
      visibility: hidden;
      position: absolute;
    }

    .div-simulator-container [type="radio"]+span::before {
      content: "";
      display: inline-block;
      width: 9px;
      height: 9px;
      border-radius: 1em;
      border: 0.1px solid #fff;
      -webkit-box-shadow: 0 0 0 1px #57aed0;
              box-shadow: 0 0 0 1px #57aed0;
      margin-right: 4px;
      -webkit-transition: 0.5s ease all;
      transition: 0.5s ease all;
      margin-left: -15px;
    }

    [type="radio"]:checked+span::before {
      background: #57aed0;
      -webkit-box-shadow: 0 0 0 2px #57aed0;
              box-shadow: 0 0 0 2px #57aed0;
      margin-top: auto;
      /*margin-left:-15px;*/
    }

    .div-simulator-container .reportText {
      font-size: 14px;
      color: #363636;
      letter-spacing: -0.49px;
    }

    .div-simulator-container button:hover,
    .div-simulator-container button:focus,
    .div-simulator-container button.active,
    .div-simulator-container .btn-default:hover,
    .btn-default:focus,
    .div-simulator-container .item.active,
    .div-simulator-container .btn-default.active {
      background: #1e89b5 !important;
      color: #ffffff !important;
    }

    .div-simulator-container .hideInput {
      visibility: hidden;
      margin-left: 5px !important;
    }

    .div-simulator-container .panel {
      background-color: transparent;
    }

    .logo {
      height: 30px;
      width: 250px;
    }

    .navbar-blue {
      background-color: #00205b !important;
      color: #fff;
    }

    .navbar-brand-text {
      font-size: 30px;
      color: #fff;
      font-weight: normal;
      margin-top: 10px;
    }

    .div-simulator-container .close {
      margin-top: -20px !important;
    }


    /*.full-width {
            width: 320px !important;
        }*/

    #myNav.affix {
      width: 483px;
      top: 100;
    }

    #Can-ImgMap {
      pointer-events: none;
      position: absolute;
      opacity: 0.5;
    }


    /* Styles for Assist bootstrap*/

    .div-simulator-container .control-label {
      text-align: left !important;
    }

    .div-simulator-container .box-style {
      text-decoration: none;
      color: #363636 !important;
      border-radius: 3px;
      padding: 5px;
      font-weight: bold !important;
      width: 75%;
    }

    .div-simulator-container .findings {
      color: #ffffff !important;
      background-color: #5295b1 !important;
      border-color: #5295b1 !important;
      background-image: none !important;
      font-weight: bold;
      text-transform: capitalize;
      height: 40px;
    }

    .div-simulator-container .table-row {
      display: table-row;
      width: auto;
      clear: both;
    }

    .div-simulator-container .table-cell {
      display: table-cell;
      width: 475px;
      font-size: 12px;
      background-color: transparent;
      color: black;
      height: 25px;
      line-height: 25px;
      padding: 1px;
      border-bottom: none;
    }

    .div-simulator-container .imgMap-table-cell {
      width: 10% !important;
      vertical-align: middle;
    }

    .div-simulator-container .panel-default {
      min-width: 600px;
      margin: 0 !important;
      background-color: white;
    }

    .div-simulator-container .footerBlock {
      position: fixed;
      bottom: 55px;
    }

    .div-simulator-container .row-style {
      bottom: 5px;
      position: fixed;
      top: 55px;
      overflow: auto;
      width: 100%;
    }

    .div-simulator-container .modal-dialog {
      top: 100px;
      /*margin-left: 50% !important;*/
      margin-left: 0 !important;
    }

    .div-simulator-container .required-field {
      border: 1px solid #edd1d1;
      border-radius: 5px;
      padding: 5px;
      font-size: 12px;
      color: #cd5c5c;
      width: 125px;
    }

    .div-simulator-container .col-per-10 {
      border: 1px solid blue;
      padding: 15px 10px 15px 10px;
      border-radius: 10px;
      height: auto;
      width: 10%;
      float: left;
      position: fixed;
      min-height: 1px;
    }

    .div-simulator-container .btn-group>.btn:first-child {
      margin-left: 0;
      width: 165px;
      margin-top: 10px;
    }

    .div-simulator-container .col-md-10 {
      left: 200px;
    }

    .div-simulator-container .module-header {
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
      margin-left: -135px;
      margin-top: -15px;
      font-size: 14px;
      font-weight: bold;
      color: #363636;
    }

    .div-simulator-container .btn-group-justified {
      padding-left: 15px;
    }

    .div-simulator-container select {
      height: 28px;
      border-radius: 5px;
    }

    .div-simulator-container .panel-body {
      padding: 10px !important;
    }

    .div-simulator-container .fixed-keydiagram {
      position: fixed !important;
      float: right;
      padding-right: 0px !important;
      margin-right: 10px;
      padding-left: 25px !important;
    }

    .div-simulator-container .center-align {
      text-align: center;
      width: 160px !important;
      padding: 0px !important;
    }

    .div-simulator-container .center-align div {
      width: 200px;
      margin-left: -10px;
    }

    .div-simulator-container .findings div {
      color: #363636 !important;
      margin-left: 97px !important;
      margin-top: -29.5px !important;
      height: 30px;
    }

    .div-simulator-container .findings div select {
      text-transform: capitalize;
    }

    .div-simulator-container .modal-backdrop {
      top: 10000px !important;
    }

    .div-simulator-container .tooltip-arrow {
      display: none !important;
    }

    .div-simulator-container .other-reportSection {
      font-weight: normal;
      margin-top: -10px;
      margin-left: 15px;
    }

    .div-simulator-container a:hover {
      text-decoration: none !important;
    }

    .div-simulator-container .no-btm-margin-table {
      margin-bottom: 0px !important;
    }

    .div-simulator-container .adjust-diagram {
      margin-top: 56px;
      right: 20px !important;
    }

    .adjust-diagram-image {
      top: 0px !important;
      margin-top: 0px !important;
    }

    @media only screen and (min-width: 1224px) {
      .tab-content {
        padding: 5px;
      }
    }

    @media (min-width: 768px) {
      #page-content-wrapper {
        padding: 0px 20px;
        margin-top: 15px;
      }
    }

    #sidebar-wrapper {
      left: 175px;
      margin-left: -175px;
    }

    #rowContent {
      padding-bottom: 120px;
    }

    @media only screen and (min-width: 1224px) {
      .fixed-reportText {
        width: 1064px;
      }
    }

    @media only screen and (min-width: 1824px) {
      .fixed-reportText {
        width: 1260px;
      }
    }

    @media only screen and (min-width: 1224px) {
      .modal-lg {
        left: 0;
        /* left: -250px; */
      }
    }

    .form-group {
      margin-bottom: 15px;
    }

    .control-label {
      margin-top: 0;
      margin-left: 0;
    }

    .div-simulator-container .checkbox>label {
      height: 30px;
      line-height: 30px;
    }

    .div-simulator-container .checkbox>label>input[type="checkbox"] {
      margin-top: 8px;
    }

    .div-simulator-container select {
      height: 30px;
      border-radius: 5px;
      font-size: 12px;
      width: 280px;
    }

    .div-simulator-container .input-group {
      width: 280px;
    }

    .div-simulator-container .input-group .form-control {
      border-radius: 5px;
      -webkit-box-shadow: none;
              box-shadow: none;
      border: 1px solid #969696;
    }

    .div-simulator-container .imgMap-table-cell {
      padding-left: 10px;
    }

    @media (min-width: 1224px) {
      .modal-lg {
        width: 630px;
      }
    }

    .tableImagemap {
      table-layout: fixed;
    }

    @media (min-width: 1850px) {
      .modal-lg {
        width: 900px;
      }
      .tableImagemap {
        table-layout: inherit;
      }
    }

    .col-centered {
      float: none;
      margin: 0 auto;
    }

    .checkbox {
      max-width: 280px;
    }

    [type="number"] {
      max-width: 280px;
      /*margin-left: -15px;*/
    }

    .input-group {
      width: 100%;
    }

    @media (min-width:1441px) {
      .DEValues {
        /*min-width: 280px;
        max-width: 280px;*/
        height: auto;
      }
    }

    @media (max-width:1024px) {
      .adjust-diagram-image {
        width: 50%;
      }
    }

    @media (min-width:1921px) {
      .adjust-diagram-image {
        width: 50%;
      }
    }

    .row {
      font-weight: bold;
    }

    .carousel-item.item img {
      width: 100% !important;
    }

    .carousel-indicators {
      display: none !important;
    }

    .display-inline {
      display: inline;
    }

    .font-weight-normal {
      font-weight: normal;
    }

    .font-weight-bold {
      font-weight: bold;
    }

    .color-white {
      color: #ffffff;
    }

    .bottom-margin{
      margin-bottom: 25px;
    }

    .reportText-content {
      white-space: pre-line; 
      font-weight: bold;
      margin: -40px 0px;
      height: -webkit-fit-content;
      height: -moz-fit-content;
      height: fit-content;
    }

    .no-bottom-margin {
      margin-bottom: 0px !important;
    }
    .reportText-main-content{
      font-size: 16px;
    }

    .split-length-word {
      word-break: break-all;
      text-align: left;
      margin: 0px 0px;
    }

    .img-max-width {
      width: 70% !important;
    }

    .keydiagram {
      text-align: center;
      margin-top: 10px;
    }

    .report-text-top-margin {
      margin-top: 15px;
    }

    input[type=number]::-webkit-inner-spin-button, 
    input[type=number]::-webkit-outer-spin-button { 
        -webkit-appearance: none;
        -moz-appearance: none;
        margin: 0; 
    }

    input[type="number"]:hover,
    input[type="number"]:focus,
    input[type="number"] {
        -moz-appearance: textfield;
    }

    .numeric-align {
      display: inline;
    }

    input[type="text"] {
    max-width: 280px;
    margin-left: 0px !important;
    border-radius: 5px !important;
    text-transform: capitalize;
    }

    .all-reporttext-heading {
      text-decoration: underline;
      font-weight: bold;
      text-transform: capitalize;
      font-size: 18px;
      margin-top: -50px;
      text-align: left;
    }

    .all-reportText-content {
      margin-top: -10px;
    }

    .split-length-word.all-reportText-content {
      text-align: justify;
      word-break: unset;
    }

    .fixed-report-text-sidebar {
      position: fixed;
      right: 0;
      width: 45%;
    }

    .fixed-report-text-footer {
      position: fixed;
      left: 15 !important;
      bottom: 0;
      background-color: white;
    }

    .left-margin {
      margin-left: 60px;
      width: 90%;
    }

    .overflow {
      /* max-height: 500px; */
      overflow-x: hidden;
    }

    @media (max-width: 650px) {
  

      .left-margin {
        margin-left: 20px;
      }

      .keydiagram {
        width: 100%;
        margin-left: 4%;
      } 
      .row.content-area {
        padding: 0px 5px;
      }

      .text-right.border-0 > h4 {
        padding-right: 20px;
      }

      .keydiagram {
        width: 100%;
        text-align: center;
        margin-left: 0px !important;
      }
    }
    @media (max-width: 1024px) {
      .keydiagram {
        width: 100%;
        margin-left: 9%;
      }
      .img-max-width {
        width: 80% !important;
      }
    }
    @media (max-width: 1023px) {
      .fixed-report-text-sidebar {
        position: relative;
      }
    }

    .upload-button-size {
    	font-size: 100% !important;
    }
  
  `]
            },] },
];
/**
 * @nocollapse
 */
AssistMultiChoiceElementComponent.ctorParameters = () => [
    { type: FormBuilder, },
    { type: SimulatorEngineService, },
];
AssistMultiChoiceElementComponent.propDecorators = {
    'multiChoiceElement': [{ type: Input },],
    'imagePath': [{ type: Input },],
    'returnMultiChoice': [{ type: Output },],
};

class ImageMapComponent {
    constructor() {
        this.$ = require('jquery');
        this.DataElements = {};
        this.FormValues = {};
        this.imageExist = true;
        this.SelectionValue = '';
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        if (this.DataElement === undefined) {
            return;
        }
        // const request = new XMLHttpRequest();
        // request.open('HEAD',  this.imagePath + '/' + this.DataElement.imageMap.location, false);
        // request.send();
        // if (request.status === 200) {
        //   this.imageExist = true;
        // } else {
        //   this.imageExist = false;
        // }
        this.displayValue('');
    }
    /**
     * @param {?} mouseX
     * @param {?} mouseY
     * @param {?} Coordinates
     * @return {?}
     */
    isInRectangle(mouseX, mouseY, Coordinates) {
        const /** @type {?} */ COArray = Coordinates.split(',');
        if (COArray[0] < mouseX
            && (COArray[0] + COArray[2]) > mouseX
            && COArray[1] < mouseY
            && (COArray[1] + COArray[3]) > mouseY) {
            return true;
        }
        return false;
    }
    /**
     * @param {?} mouseX
     * @param {?} mouseY
     * @param {?} Coordinates
     * @return {?}
     */
    isInCircle(mouseX, mouseY, Coordinates) {
        const /** @type {?} */ COArray = Coordinates.split(',');
        if (Math.sqrt(Math.pow((mouseX - COArray[0]), 2) + Math.pow((mouseY - COArray[1]), 2)) < COArray[2]) {
            return true;
        }
        else {
            return false;
        }
    }
    /**
     * @param {?} x
     * @param {?} y
     * @param {?} Coordinates
     * @return {?}
     */
    isInPolygon(x, y, Coordinates) {
        const /** @type {?} */ COArray = Coordinates.split(',');
        const /** @type {?} */ vs = [];
        for (let /** @type {?} */ i = 0; i < COArray.length; i++) {
            const /** @type {?} */ point = [];
            point.push(COArray[i]);
            point.push(COArray[i + 1]);
            i += 1;
            vs.push(point);
        }
        let /** @type {?} */ inside = false;
        for (let /** @type {?} */ i = 0, /** @type {?} */ j = vs.length - 1; i < vs.length; j = i++) {
            const /** @type {?} */ xi = vs[i][0], /** @type {?} */ yi = vs[i][1];
            const /** @type {?} */ xj = vs[j][0], /** @type {?} */ yj = vs[j][1];
            const /** @type {?} */ intersect = ((yi > y) !== (yj > y))
                && (x < (xj - xi) * (y - yi) / (yj - yi) + xi);
            if (intersect) {
                inside = !inside;
            }
        }
        return inside;
    }
    /**
     * @param {?} e
     * @param {?} dataElement
     * @return {?}
     */
    imageClick(e, dataElement) {
        const /** @type {?} */ O_height = dataElement.ImageProp.height;
        const /** @type {?} */ O_width = dataElement.ImageProp.width;
        const /** @type {?} */ $elem = this.$(e.target);
        const /** @type {?} */ N_height = $elem.height();
        const /** @type {?} */ N_width = $elem.width();
        const /** @type {?} */ offset = $elem.offset();
        const /** @type {?} */ offset_t = offset.top - this.$(window).scrollTop();
        const /** @type {?} */ offset_l = offset.left - this.$(window).scrollLeft();
        const /** @type {?} */ x = e.clientX - offset_l;
        const /** @type {?} */ y = e.clientY - offset_t;
        for (const /** @type {?} */ opt of dataElement.ImageOptions) {
            if (opt.Shape === 'rect') {
                if (this.isInRectangle(x, y, opt.Coordinates)) {
                    this.FormValues[dataElement.ID] = opt.Value;
                    break;
                }
            }
            else if (opt.Shape === 'circle') {
                if (this.isInCircle(x, y, opt.Coordinates)) {
                    this.FormValues[dataElement.ID] = opt.Value;
                    break;
                }
            }
            else if (opt.Shape === 'poly') {
                if (this.isInPolygon(x, y, opt.Coordinates)) {
                    this.FormValues[dataElement.ID] = opt.Value;
                    break;
                }
            }
        }
    }
    /**
     * @param {?} val
     * @return {?}
     */
    setValue(val) {
        for (const /** @type {?} */ optValue of this.DataElement.choiceInfo) {
            if (this.DataElement.choiceInfo.length <= 5 && this.DataElement.choiceInfo.length > 0) {
                if (optValue.value === val) {
                    this.$('#' + val + '_' + this.DataElement.id).prop('checked', true);
                    break;
                }
                else {
                    this.$('#' + optValue.value + '_' + this.DataElement.id).prop('checked', false);
                }
            }
            else {
                if (optValue.value === val) {
                    this.$('#' + this.DataElement.id).val(optValue.value);
                    const /** @type {?} */ customEvent = document.createEvent('Event');
                    customEvent.initEvent('change', true, true);
                    this.$('#' + this.DataElement.id)[0].dispatchEvent(customEvent);
                    break;
                }
            }
        }
        this.DataElement.currentValue = val;
        // this.FormValues[this.DataElement.id] = val;
    }
    /**
     * @param {?} val
     * @return {?}
     */
    displayValue(val) {
        if (val === '') {
            this.SelectionValue = 'Image Map Diagram';
        }
        else {
            this.SelectionValue = 'Selected Value : ' + val;
        }
    }
}
ImageMapComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-image-map',
                template: `
    <div class="row">
      <div class="col-sm-4 text-center">
        OR
      </div>
    </div>
    <div class="row">
      <div class="col-sm-12 text-left">
        Select value from image:-
          <button type="button" class="btn btn-default" data-toggle="modal" attr.data-target="#{{'imgMap_Modal_'+DataElement.id}}">
          <span class="glyphicon glyphicon-picture" aria-hidden="true" data-toggle="tooltip" data-placement="top" title="Image Map"></span>
        </button>
      </div>
    </div>

    <ng-container *ngIf="imagePath != undefined">
      <div class="modal fade img-modal" tabindex="-1" role="dialog" attr.id="{{'imgMap_Modal_'+DataElement.id}}" aria-labelledby="mySmallModalLabel">
        <div class="modal-dialog modal-lg" role="document">
          <!-- <div class="modal-dialog modal-lg" role="document" [ngStyle]="{'width':DataElement.ImagePath.width + 30}"> -->
          <div class="modal-content">
            <div class="modal-header">
              <h4 class="modal-title">
                {{SelectionValue}}
              </h4>
              <button type="button" class="close" data-dismiss="modal" aria-label="Close">
                <span aria-hidden="true">×</span>
              </button>
            </div>
            <div class="modal-body">
              <div class="row">
                <div class="col-md-12">
                  <ng-container *ngIf="imageExist == true">
                    <img class="ImgOption danger" alt="No Image Available!!!" data-dismiss="modal" attr.id="{{'imgMap_Img_'+DataElement.id}}"
                      (click)="imageClick($event,DataElement);" attr.data-elementID="{{DataElement.id}}" attr.usemap="#{{'imgMap_'+DataElement.id}}"
                      src="{{imagePath}}/{{DataElement.imageMap.location}}">
                    <map name="{{'imgMap_'+DataElement.id}}">
                      <ng-container *ngFor="let imgOpt of DataElement.imageMap.map.areas">
                        <area attr.shape="{{imgOpt.shape}}" attr.imgID="{{'imgMap_Img_'+DataElement.id}}" attr.coords="{{imgOpt.coords}}" attr.alt="{{imgOpt.choiceValue}}"
                          (mouseover)='displayValue(imgOpt.choiceValue);' (mouseout)='displayValue("");'
                          (click)="setValue(imgOpt.choiceValue);" data-dismiss="modal">
                      </ng-container>
                    </map>
                  </ng-container>

                  <ng-container *ngIf="imageExist == false">
                    <div class="">
                      No Image Map Available...
                    </div>
                  </ng-container>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </ng-container>
  `,
                styles: [`
    input[type=file].inputfile {
      width: 0.1px;
      height: 0.1px;
      opacity: 0;
      overflow: hidden;
      position: absolute;
      z-index: -1;
      margin: 0;
    }

    input[type=file].inputfile+label:active,
    input[type=file].inputfile+label {
      max-width: 100%;
      font-size: 1.5rem;
      font-weight: 700;
      text-overflow: ellipsis;
      white-space: nowrap;
      cursor: pointer;
      display: inline-block;
      overflow: hidden;
      display: inline-block;
      color: #f1e5e6;
      background-color: #d3394c;
      text-indent: 0px;
      width: 130px;
    }

    input[type=file].inputfile+label:hover {
      background-color: #722040;
    }

    input[type=file].inputfile+label {
      cursor: pointer;
      /* "hand" cursor */
    }

    input[type=file].inputfile:hover+label {
      outline: 1px dotted #000;
      outline: -webkit-focus-ring-color auto 5px;
    }

    .right-fixed {
      position: fixed;
      right: 0px;
    }

    .row.report-text-top-margin.right-align{
      width: 80%;
      margin-left: 135px;
    }

    /* Master Styles */

    h1 {
      color: #369;
      font-family: Arial, Helvetica, sans-serif;
      font-size: 250%;
    }

    h2,
    h3 {
      color: #444;
      font-family: Arial, Helvetica, sans-serif;
      font-weight: lighter;
    }

    body {
      margin: 2em;
    }


    /*Apply background color for div having checked radio button*/

    input[type="radio"]:checked+div {
      background-color: #1e89b5 !important;
      border: 1px solid #9b9b9b;
      color: #ffffff;
    }


    /*Apply background color for div having no checked radio button*/

    input[type="radio"]+div {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
    }

    .checkbox>label {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
      height: auto;
      line-height: 25px;
      width: 100%;
      font-weight: bold;
    }

    .checkbox>label>input[type="checkbox"] {
      margin-left: -15px;
      margin-top: 6px;
    }

    .full-width span {
      font-weight: bold;
    }


    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;
        border: 1px solid #9B9B9B;
        }*/

    .DEElement {
      color: #363636;
      letter-spacing: -0.37px;
      word-wrap: break-word;
    }

    .DEValues {
      /*font-size: 12px;*/
      color: #4a4a4a;
      letter-spacing: -0.29px;
      width: 100%;
      min-width: 180px;
      max-width: 280px;
    }


    /* CHECKBOX OVERWRITE STYLES */

    .rad {
      cursor: pointer;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
      -webkit-user-select: none;
      -webkit-touch-callout: none;
    }

    .rad>input {
      /* HIDE ORG RADIO & CHECKBOX */
      visibility: hidden;
      position: absolute;
    }

    [type="radio"]+span::before {
      content: "";
      display: inline-block;
      width: 9px;
      height: 9px;
      border-radius: 1em;
      border: 0.1px solid #fff;
      -webkit-box-shadow: 0 0 0 1px #57aed0;
              box-shadow: 0 0 0 1px #57aed0;
      margin-right: 4px;
      -webkit-transition: 0.5s ease all;
      transition: 0.5s ease all;
      margin-left: -15px;
    }

    [type="radio"]:checked+span::before {
      background: #57aed0;
      -webkit-box-shadow: 0 0 0 2px #57aed0;
              box-shadow: 0 0 0 2px #57aed0;
      margin-top: auto;
      /*margin-left:-15px;*/
    }

    .reportText {
      font-size: 14px;
      color: #363636;
      letter-spacing: -0.49px;
      margin-top: 5px;
    }

    button:hover,
    button:focus,
    button.active,
    .btn-default:hover,
    .btn-default:focus,
    .item.active,
    .btn-default.active {
      background: #1e89b5 !important;
      color: #ffffff !important;
    }

    .hideInput {
      visibility: hidden;
      margin-left: 5px !important;
    }

    .panel {
      background-color: transparent;
    }

    .logo {
      height: 30px;
      width: 250px;
    }

    .navbar-blue {
      background-color: #00205b !important;
      color: #fff;
    }

    .navbar-brand-text {
      font-size: 30px;
      color: #fff;
      font-weight: normal;
      margin-top: 10px;
    }

    .close {
      margin-top: -20px !important;
    }


    /*.full-width {
            width: 320px !important;
        }*/

    #myNav.affix {
      width: 483px;
      top: 100;
    }

    #Can-ImgMap {
      pointer-events: none;
      position: absolute;
      opacity: 0.5;
    }


    /* Styles for Assist bootstrap*/

    .control-label {
      text-align: left !important;
    }

    .box-style {
      text-decoration: none;
      color: #363636 !important;
      border-radius: 3px;
      padding: 5px;
      font-weight: bold !important;
      width: 75%;
    }

    .findings {
      color: #ffffff !important;
      background-color: #5295b1 !important;
      border-color: #5295b1 !important;
      background-image: none !important;
      font-weight: bold;
      text-transform: capitalize;
      height: 45px;
      font-size: 16px;
      text-align: left;
    }

    .table-row {
      display: table-row;
      width: auto;
      clear: both;
    }

    .table-cell {
      display: table-cell;
      width: 475px;
      font-size: 12px;
      background-color: transparent;
      color: black;
      height: 25px;
      line-height: 25px;
      padding: 1px;
    }

    .imgMap-table-cell {
      width: 10% !important;
      vertical-align: middle;
    }

    .panel-default {
      min-width: 100%;
    }

    #footer {
      position: fixed;
      bottom: 0;
    }

    .row-style {
      bottom: 5px;
      position: fixed;
      top: 55px;
      overflow: auto;
      width: 100%;
    }

    .modal-dialog {
      top: 100px;
      margin-left: 50% !important;
    }

    .required-field {
      /* border: 1px solid red; */
      /* border-radius: 5px; */
      padding: 5px;
      font-size: 16px;
      color: red;
      /* width: 120px; */
      display: inline-block;
      font-weight: bold;
    }

    .xml-only-msg {
      border: 1px solid red;
      border-radius: 5px;
      padding: 5px;
      font-size: 12px;
      color: white;
      width: 223px;
      display: inline-block;
      font-weight: bold;
    }

    @media (min-width: 400px) and (max-width: 1024px) {
      .xml-only-msg {
        width: 120px;
      }
    }

    @media (max-width: 475px)  {
      .xml-only-msg {
        color: #000000
      }
    }
    .col-per-10 {
      border: 1px solid blue;
      padding: 15px 10px 15px 10px;
      border-radius: 10px;
      height: auto;
      width: 10%;
      float: left;
      position: fixed;
      min-height: 1px;
    }

    .btn-group>.btn:first-child {
      margin-left: 0;
      width: 165px;
      margin-top: 10px;
    }

    .col-md-10 {
      left: 200px;
    }

    .module-header {
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
      margin-left: -135px;
      margin-top: -15px;
      font-size: 14px;
      font-weight: bold;
      color: #363636;
    }

    .btn-group-justified {
      padding-left: 15px;
    }

    select {
      height: 35px;
      border-radius: 5px;
      max-width: 280px;
      width: 100%;
    }

    .findings select{
      max-width: 150px;
      margin-top: -3px;
    }
    .fixed-keydiagram {
      position: fixed !important;
      float: right;
      padding-right: 0px !important;
      margin-right: 10px;
      padding-left: 25px !important;
    }

    .center-align {
      text-align: center;
      width: 160px !important;
      padding: 0px !important;
    }

    .center-align div {
      width: 200px;
      margin-left: -10px;
    }

    .findings div {
      color: #363636 !important;
      margin-left: 100px !important;
      margin-top: -23.5px !important;
      height: 30px;
    }

    .findings div select {
      text-transform: capitalize;
    }

    .modal-backdrop {
      top: 10000px !important;
    }

    .tooltip-arrow {
      display: none !important;
    }

    .other-reportSection {
      font-weight: normal;
      margin-top: -10px;
      margin-left: 15px;
    }

    a:hover {
      text-decoration: none !important;
    }

    .no-btm-margin-table {
      margin-bottom: 0px !important;
    }

    .adjust-diagram {
      margin-top: 56px;
      right: 20px !important;
    }

    .adjust-diagram-image {
      top: 0px !important;
      margin-top: 0px !important;
    }

    .reportText-panel {
      width: 90%;
      margin-left: 2%;
    }

    .reportText-body {
      margin-left: 2%;
    }

    .top-Index {
      z-index: 99999 !important;
    }


    /* Master Styles */

    h1 {
      color: #369;
      font-family: Arial, Helvetica, sans-serif;
      font-size: 250%;
    }

    h2,
    h3 {
      color: #444;
      font-family: Arial, Helvetica, sans-serif;
      font-weight: lighter;
    }

    .div-simulator-container {
      margin: 0;
    }


    /*Apply background color for div having checked radio button*/

    .div-simulator-container input[type="radio"]:checked+div {
      background-color: #1e89b5 !important;
      border: 1px solid #9b9b9b;
      color: #ffffff;
    }


    /*Apply background color for div having no checked radio button*/

    .div-simulator-container input[type="radio"]+div {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
    }

    .div-simulator-container .checkbox>label {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
      height: 25px;
      line-height: 25px;
    }

    .div-simulator-container .checkbox>label>input[type="checkbox"] {
      margin-left: -15px;
      margin-top: 6px;
    }

    .div-simulator-container .full-width span {
      font-weight: bold;
    }


    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;
        border: 1px solid #9B9B9B;
        }*/

    .div-simulator-container .DEElement {
      color: #363636;
      letter-spacing: -0.37px;
      word-wrap: break-word;
    }

    .div-simulator-container .DEValues {
      /*font-size: 12px;*/
      color: #4a4a4a;
      letter-spacing: -0.29px;
    }


    /* CHECKBOX OVERWRITE STYLES */

    .div-simulator-container .rad {
      cursor: pointer;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
      -webkit-user-select: none;
      -webkit-touch-callout: none;
    }

    .div-simulator-container .rad>input {
      /* HIDE ORG RADIO & CHECKBOX */
      visibility: hidden;
      position: absolute;
    }

    .div-simulator-container [type="radio"]+span::before {
      content: "";
      display: inline-block;
      width: 9px;
      height: 9px;
      border-radius: 1em;
      border: 0.1px solid #fff;
      -webkit-box-shadow: 0 0 0 1px #57aed0;
              box-shadow: 0 0 0 1px #57aed0;
      margin-right: 4px;
      -webkit-transition: 0.5s ease all;
      transition: 0.5s ease all;
      margin-left: -15px;
    }

    [type="radio"]:checked+span::before {
      background: #57aed0;
      -webkit-box-shadow: 0 0 0 2px #57aed0;
              box-shadow: 0 0 0 2px #57aed0;
      margin-top: auto;
      /*margin-left:-15px;*/
    }

    .div-simulator-container .reportText {
      font-size: 14px;
      color: #363636;
      letter-spacing: -0.49px;
    }

    .div-simulator-container button:hover,
    .div-simulator-container button:focus,
    .div-simulator-container button.active,
    .div-simulator-container .btn-default:hover,
    .btn-default:focus,
    .div-simulator-container .item.active,
    .div-simulator-container .btn-default.active {
      background: #1e89b5 !important;
      color: #ffffff !important;
    }

    .div-simulator-container .hideInput {
      visibility: hidden;
      margin-left: 5px !important;
    }

    .div-simulator-container .panel {
      background-color: transparent;
    }

    .logo {
      height: 30px;
      width: 250px;
    }

    .navbar-blue {
      background-color: #00205b !important;
      color: #fff;
    }

    .navbar-brand-text {
      font-size: 30px;
      color: #fff;
      font-weight: normal;
      margin-top: 10px;
    }

    .div-simulator-container .close {
      margin-top: -20px !important;
    }


    /*.full-width {
            width: 320px !important;
        }*/

    #myNav.affix {
      width: 483px;
      top: 100;
    }

    #Can-ImgMap {
      pointer-events: none;
      position: absolute;
      opacity: 0.5;
    }


    /* Styles for Assist bootstrap*/

    .div-simulator-container .control-label {
      text-align: left !important;
    }

    .div-simulator-container .box-style {
      text-decoration: none;
      color: #363636 !important;
      border-radius: 3px;
      padding: 5px;
      font-weight: bold !important;
      width: 75%;
    }

    .div-simulator-container .findings {
      color: #ffffff !important;
      background-color: #5295b1 !important;
      border-color: #5295b1 !important;
      background-image: none !important;
      font-weight: bold;
      text-transform: capitalize;
      height: 40px;
    }

    .div-simulator-container .table-row {
      display: table-row;
      width: auto;
      clear: both;
    }

    .div-simulator-container .table-cell {
      display: table-cell;
      width: 475px;
      font-size: 12px;
      background-color: transparent;
      color: black;
      height: 25px;
      line-height: 25px;
      padding: 1px;
      border-bottom: none;
    }

    .div-simulator-container .imgMap-table-cell {
      width: 10% !important;
      vertical-align: middle;
    }

    .div-simulator-container .panel-default {
      min-width: 600px;
      margin: 0 !important;
      background-color: white;
    }

    .div-simulator-container .footerBlock {
      position: fixed;
      bottom: 55px;
    }

    .div-simulator-container .row-style {
      bottom: 5px;
      position: fixed;
      top: 55px;
      overflow: auto;
      width: 100%;
    }

    .div-simulator-container .modal-dialog {
      top: 100px;
      /*margin-left: 50% !important;*/
      margin-left: 0 !important;
    }

    .div-simulator-container .required-field {
      border: 1px solid #edd1d1;
      border-radius: 5px;
      padding: 5px;
      font-size: 12px;
      color: #cd5c5c;
      width: 125px;
    }

    .div-simulator-container .col-per-10 {
      border: 1px solid blue;
      padding: 15px 10px 15px 10px;
      border-radius: 10px;
      height: auto;
      width: 10%;
      float: left;
      position: fixed;
      min-height: 1px;
    }

    .div-simulator-container .btn-group>.btn:first-child {
      margin-left: 0;
      width: 165px;
      margin-top: 10px;
    }

    .div-simulator-container .col-md-10 {
      left: 200px;
    }

    .div-simulator-container .module-header {
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
      margin-left: -135px;
      margin-top: -15px;
      font-size: 14px;
      font-weight: bold;
      color: #363636;
    }

    .div-simulator-container .btn-group-justified {
      padding-left: 15px;
    }

    .div-simulator-container select {
      height: 28px;
      border-radius: 5px;
    }

    .div-simulator-container .panel-body {
      padding: 10px !important;
    }

    .div-simulator-container .fixed-keydiagram {
      position: fixed !important;
      float: right;
      padding-right: 0px !important;
      margin-right: 10px;
      padding-left: 25px !important;
    }

    .div-simulator-container .center-align {
      text-align: center;
      width: 160px !important;
      padding: 0px !important;
    }

    .div-simulator-container .center-align div {
      width: 200px;
      margin-left: -10px;
    }

    .div-simulator-container .findings div {
      color: #363636 !important;
      margin-left: 97px !important;
      margin-top: -29.5px !important;
      height: 30px;
    }

    .div-simulator-container .findings div select {
      text-transform: capitalize;
    }

    .div-simulator-container .modal-backdrop {
      top: 10000px !important;
    }

    .div-simulator-container .tooltip-arrow {
      display: none !important;
    }

    .div-simulator-container .other-reportSection {
      font-weight: normal;
      margin-top: -10px;
      margin-left: 15px;
    }

    .div-simulator-container a:hover {
      text-decoration: none !important;
    }

    .div-simulator-container .no-btm-margin-table {
      margin-bottom: 0px !important;
    }

    .div-simulator-container .adjust-diagram {
      margin-top: 56px;
      right: 20px !important;
    }

    .adjust-diagram-image {
      top: 0px !important;
      margin-top: 0px !important;
    }

    @media only screen and (min-width: 1224px) {
      .tab-content {
        padding: 5px;
      }
    }

    @media (min-width: 768px) {
      #page-content-wrapper {
        padding: 0px 20px;
        margin-top: 15px;
      }
    }

    #sidebar-wrapper {
      left: 175px;
      margin-left: -175px;
    }

    #rowContent {
      padding-bottom: 120px;
    }

    @media only screen and (min-width: 1224px) {
      .fixed-reportText {
        width: 1064px;
      }
    }

    @media only screen and (min-width: 1824px) {
      .fixed-reportText {
        width: 1260px;
      }
    }

    @media only screen and (min-width: 1224px) {
      .modal-lg {
        left: 0;
        /* left: -250px; */
      }
    }

    .form-group {
      margin-bottom: 15px;
    }

    .control-label {
      margin-top: 0;
      margin-left: 0;
    }

    .div-simulator-container .checkbox>label {
      height: 30px;
      line-height: 30px;
    }

    .div-simulator-container .checkbox>label>input[type="checkbox"] {
      margin-top: 8px;
    }

    .div-simulator-container select {
      height: 30px;
      border-radius: 5px;
      font-size: 12px;
      width: 280px;
    }

    .div-simulator-container .input-group {
      width: 280px;
    }

    .div-simulator-container .input-group .form-control {
      border-radius: 5px;
      -webkit-box-shadow: none;
              box-shadow: none;
      border: 1px solid #969696;
    }

    .div-simulator-container .imgMap-table-cell {
      padding-left: 10px;
    }

    @media (min-width: 1224px) {
      .modal-lg {
        width: 630px;
      }
    }

    .tableImagemap {
      table-layout: fixed;
    }

    @media (min-width: 1850px) {
      .modal-lg {
        width: 900px;
      }
      .tableImagemap {
        table-layout: inherit;
      }
    }

    .col-centered {
      float: none;
      margin: 0 auto;
    }

    .checkbox {
      max-width: 280px;
    }

    [type="number"] {
      max-width: 280px;
      /*margin-left: -15px;*/
    }

    .input-group {
      width: 100%;
    }

    @media (min-width:1441px) {
      .DEValues {
        /*min-width: 280px;
        max-width: 280px;*/
        height: auto;
      }
    }

    @media (max-width:1024px) {
      .adjust-diagram-image {
        width: 50%;
      }
    }

    @media (min-width:1921px) {
      .adjust-diagram-image {
        width: 50%;
      }
    }

    .row {
      font-weight: bold;
    }

    .carousel-item.item img {
      width: 100% !important;
    }

    .carousel-indicators {
      display: none !important;
    }

    .display-inline {
      display: inline;
    }

    .font-weight-normal {
      font-weight: normal;
    }

    .font-weight-bold {
      font-weight: bold;
    }

    .color-white {
      color: #ffffff;
    }

    .bottom-margin{
      margin-bottom: 25px;
    }

    .reportText-content {
      white-space: pre-line; 
      font-weight: bold;
      margin: -40px 0px;
      height: -webkit-fit-content;
      height: -moz-fit-content;
      height: fit-content;
    }

    .no-bottom-margin {
      margin-bottom: 0px !important;
    }
    .reportText-main-content{
      font-size: 16px;
    }

    .split-length-word {
      word-break: break-all;
      text-align: left;
      margin: 0px 0px;
    }

    .img-max-width {
      width: 70% !important;
    }

    .keydiagram {
      text-align: center;
      margin-top: 10px;
    }

    .report-text-top-margin {
      margin-top: 15px;
    }

    input[type=number]::-webkit-inner-spin-button, 
    input[type=number]::-webkit-outer-spin-button { 
        -webkit-appearance: none;
        -moz-appearance: none;
        margin: 0; 
    }

    input[type="number"]:hover,
    input[type="number"]:focus,
    input[type="number"] {
        -moz-appearance: textfield;
    }

    .numeric-align {
      display: inline;
    }

    input[type="text"] {
    max-width: 280px;
    margin-left: 0px !important;
    border-radius: 5px !important;
    text-transform: capitalize;
    }

    .all-reporttext-heading {
      text-decoration: underline;
      font-weight: bold;
      text-transform: capitalize;
      font-size: 18px;
      margin-top: -50px;
      text-align: left;
    }

    .all-reportText-content {
      margin-top: -10px;
    }

    .split-length-word.all-reportText-content {
      text-align: justify;
      word-break: unset;
    }

    .fixed-report-text-sidebar {
      position: fixed;
      right: 0;
      width: 45%;
    }

    .fixed-report-text-footer {
      position: fixed;
      left: 15 !important;
      bottom: 0;
      background-color: white;
    }

    .left-margin {
      margin-left: 60px;
      width: 90%;
    }

    .overflow {
      /* max-height: 500px; */
      overflow-x: hidden;
    }

    @media (max-width: 650px) {
  

      .left-margin {
        margin-left: 20px;
      }

      .keydiagram {
        width: 100%;
        margin-left: 4%;
      } 
      .row.content-area {
        padding: 0px 5px;
      }

      .text-right.border-0 > h4 {
        padding-right: 20px;
      }

      .keydiagram {
        width: 100%;
        text-align: center;
        margin-left: 0px !important;
      }
    }
    @media (max-width: 1024px) {
      .keydiagram {
        width: 100%;
        margin-left: 9%;
      }
      .img-max-width {
        width: 80% !important;
      }
    }
    @media (max-width: 1023px) {
      .fixed-report-text-sidebar {
        position: relative;
      }
    }

    .upload-button-size {
    	font-size: 100% !important;
    }
  
  `]
            },] },
];
/**
 * @nocollapse
 */
ImageMapComponent.ctorParameters = () => [];
ImageMapComponent.propDecorators = {
    'DataElement': [{ type: Input },],
    'DataElements': [{ type: Input },],
    'FormValues': [{ type: Input },],
    'imagePath': [{ type: Input },],
};

class ComputedDataElement extends BaseDataElement {
}

class ComputedDataElementCreationService extends DataElementCreationBaseService {
    /**
     * @param {?} diagramService
     * @param {?} arrayCheckerService
     * @param {?} computedValueCreationService
     * @param {?} decisionPointsCreationService
     */
    constructor(diagramService, arrayCheckerService, computedValueCreationService, decisionPointsCreationService) {
        super(diagramService);
        this.arrayCheckerService = arrayCheckerService;
        this.computedValueCreationService = computedValueCreationService;
        this.decisionPointsCreationService = decisionPointsCreationService;
        this.elementType = 'ComputedDataElement';
    }
    /**
     * @param {?} data
     * @return {?}
     */
    createElement(data) {
        const /** @type {?} */ dataElement = new ComputedDataElement();
        super.populateBasicData(data, dataElement);
        dataElement.computeValue = this.computedValueCreationService.createComputedValue(data);
        if (data.DecisionPoint) {
            dataElement.decisionPoints = this.decisionPointsCreationService.createDecisionPoints(data.DecisionPoint);
        }
        return dataElement;
    }
}
ComputedDataElementCreationService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
ComputedDataElementCreationService.ctorParameters = () => [
    { type: DiagramService, },
    { type: ArrayCheckerService, },
    { type: ComputedValueCreationService, },
    { type: DecisionPointsCreationService, },
];

const $$4 = require('jquery');
class AssistReportTextComponent {
    constructor() {
        this.allReportTexts = [];
        this.sections = [];
        setInterval(() => {
        }, 1000);
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    ngOnChanges(changes) {
        this.mainReportTexts = new MainReportText();
        this.onSelect(this.selectedSectionId);
    }
    /**
     * @param {?} sectionId
     * @return {?}
     */
    onSelect(sectionId) {
        this.selectedSectionId = sectionId;
        this.sections = [];
        this.selectedSection = null;
        for (const /** @type {?} */ section in this.reportText.allReportText) {
            if (this.reportText.allReportText[section].reportText !== '') {
                this.sections.push(section);
            }
        }
        if (this.sections.length > 1) {
            if (sectionId === 'undefined' || sectionId === undefined || sectionId === 'All') {
                this.allTextReport = [];
                for (const /** @type {?} */ section in this.reportText.allReportText) {
                    if (this.reportText.allReportText[section].reportText !== '') {
                        const /** @type {?} */ textReport = new AllTextReport();
                        textReport.heading = section;
                        textReport.content = this.removeEmptyLine(this.reportText.allReportText[section].reportText);
                        this.allTextReport.push(textReport);
                    }
                }
                // $('#allTextReport').html(allText);
                this.selectedSectionId = 'All';
            }
        }
        else {
            sectionId = this.sections[0];
        }
        for (const /** @type {?} */ section in this.reportText.allReportText) {
            if (this.reportText.allReportText[section].sectionId === sectionId) {
                this.selectedSection = this.reportText.allReportText[section].reportText;
                this.selectedSection = this.reportText.reportTextMainContent + ((this.selectedSection !== undefined && this.selectedSection !== '') ? this.removeEmptyLine(this.selectedSection) : '');
                break;
            }
        }
        this.mainReportTexts = new MainReportText();
        this.allReportTexts = [];
        for (const /** @type {?} */ section in this.reportText.allReportText) {
            const /** @type {?} */ allreportText = new AllReportText();
            allreportText.reportText = this.removeEmptyLine(this.reportText.allReportText[section].reportText);
            allreportText.sectionId = this.reportText.allReportText[section].sectionId;
            this.allReportTexts.push(allreportText);
        }
        this.mainReportTexts.allReportText = this.allReportTexts;
        this.mainReportTexts.reportTextMainContent = this.reportText.reportTextMainContent;
    }
    /**
     * @param {?} inputText
     * @return {?}
     */
    removeEmptyLine(inputText) {
        if (inputText.trim().length !== 0) {
            const /** @type {?} */ lines = inputText.split('\n');
            const /** @type {?} */ uniquelines = [];
            lines.forEach(function (line, i) {
                if (line.trim().length !== 0) {
                    uniquelines.push(line);
                }
            });
            return uniquelines.join('\n');
        }
    }
}
AssistReportTextComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-assist-report-text',
                template: `
    <ng-container>
        <div class="panel panel-group panel-default no-bottom-margin">
            <div class="panel-heading findings">Report Text: 
                <div>
                    <select id="ddlSections" (change)="onSelect($event.target.value)" style="text-transform: capitalize">
                        <option *ngIf="sections.length > 1" [value]="All" [selected]="All">All</option>
                        <option *ngFor="let Section of sections" [value]="Section" >{{Section}}</option>
                    </select>
                </div>
            </div>
            <div class="panel-body" >
                <div class="reportText-content">
                    <ng-container *ngIf="selectedSectionId !=='All'">
                        <div [innerHTML]="selectedSection"  class="split-length-word all-reportText-content">
                        </div>
                    </ng-container>
                    <ng-container *ngIf="selectedSectionId ==='All'">
                        <ng-container *ngFor="let textReport of allTextReport">
                            <div class="all-reporttext-heading">
                                {{textReport.heading}}
                            </div>
                            <div [innerHTML]="textReport.content"  class="split-length-word all-reportText-content">
                            </div> 
                        </ng-container>
                    </ng-container>
                </div>
            </div>
        </div>
    </ng-container>
  `,
                styles: [`
    input[type=file].inputfile {
      width: 0.1px;
      height: 0.1px;
      opacity: 0;
      overflow: hidden;
      position: absolute;
      z-index: -1;
      margin: 0;
    }

    input[type=file].inputfile+label:active,
    input[type=file].inputfile+label {
      max-width: 100%;
      font-size: 1.5rem;
      font-weight: 700;
      text-overflow: ellipsis;
      white-space: nowrap;
      cursor: pointer;
      display: inline-block;
      overflow: hidden;
      display: inline-block;
      color: #f1e5e6;
      background-color: #d3394c;
      text-indent: 0px;
      width: 130px;
    }

    input[type=file].inputfile+label:hover {
      background-color: #722040;
    }

    input[type=file].inputfile+label {
      cursor: pointer;
      /* "hand" cursor */
    }

    input[type=file].inputfile:hover+label {
      outline: 1px dotted #000;
      outline: -webkit-focus-ring-color auto 5px;
    }

    .right-fixed {
      position: fixed;
      right: 0px;
    }

    .row.report-text-top-margin.right-align{
      width: 80%;
      margin-left: 135px;
    }

    /* Master Styles */

    h1 {
      color: #369;
      font-family: Arial, Helvetica, sans-serif;
      font-size: 250%;
    }

    h2,
    h3 {
      color: #444;
      font-family: Arial, Helvetica, sans-serif;
      font-weight: lighter;
    }

    body {
      margin: 2em;
    }


    /*Apply background color for div having checked radio button*/

    input[type="radio"]:checked+div {
      background-color: #1e89b5 !important;
      border: 1px solid #9b9b9b;
      color: #ffffff;
    }


    /*Apply background color for div having no checked radio button*/

    input[type="radio"]+div {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
    }

    .checkbox>label {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
      height: auto;
      line-height: 25px;
      width: 100%;
      font-weight: bold;
    }

    .checkbox>label>input[type="checkbox"] {
      margin-left: -15px;
      margin-top: 6px;
    }

    .full-width span {
      font-weight: bold;
    }


    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;
        border: 1px solid #9B9B9B;
        }*/

    .DEElement {
      color: #363636;
      letter-spacing: -0.37px;
      word-wrap: break-word;
    }

    .DEValues {
      /*font-size: 12px;*/
      color: #4a4a4a;
      letter-spacing: -0.29px;
      width: 100%;
      min-width: 180px;
      max-width: 280px;
    }


    /* CHECKBOX OVERWRITE STYLES */

    .rad {
      cursor: pointer;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
      -webkit-user-select: none;
      -webkit-touch-callout: none;
    }

    .rad>input {
      /* HIDE ORG RADIO & CHECKBOX */
      visibility: hidden;
      position: absolute;
    }

    [type="radio"]+span::before {
      content: "";
      display: inline-block;
      width: 9px;
      height: 9px;
      border-radius: 1em;
      border: 0.1px solid #fff;
      -webkit-box-shadow: 0 0 0 1px #57aed0;
              box-shadow: 0 0 0 1px #57aed0;
      margin-right: 4px;
      -webkit-transition: 0.5s ease all;
      transition: 0.5s ease all;
      margin-left: -15px;
    }

    [type="radio"]:checked+span::before {
      background: #57aed0;
      -webkit-box-shadow: 0 0 0 2px #57aed0;
              box-shadow: 0 0 0 2px #57aed0;
      margin-top: auto;
      /*margin-left:-15px;*/
    }

    .reportText {
      font-size: 14px;
      color: #363636;
      letter-spacing: -0.49px;
      margin-top: 5px;
    }

    button:hover,
    button:focus,
    button.active,
    .btn-default:hover,
    .btn-default:focus,
    .item.active,
    .btn-default.active {
      background: #1e89b5 !important;
      color: #ffffff !important;
    }

    .hideInput {
      visibility: hidden;
      margin-left: 5px !important;
    }

    .panel {
      background-color: transparent;
    }

    .logo {
      height: 30px;
      width: 250px;
    }

    .navbar-blue {
      background-color: #00205b !important;
      color: #fff;
    }

    .navbar-brand-text {
      font-size: 30px;
      color: #fff;
      font-weight: normal;
      margin-top: 10px;
    }

    .close {
      margin-top: -20px !important;
    }


    /*.full-width {
            width: 320px !important;
        }*/

    #myNav.affix {
      width: 483px;
      top: 100;
    }

    #Can-ImgMap {
      pointer-events: none;
      position: absolute;
      opacity: 0.5;
    }


    /* Styles for Assist bootstrap*/

    .control-label {
      text-align: left !important;
    }

    .box-style {
      text-decoration: none;
      color: #363636 !important;
      border-radius: 3px;
      padding: 5px;
      font-weight: bold !important;
      width: 75%;
    }

    .findings {
      color: #ffffff !important;
      background-color: #5295b1 !important;
      border-color: #5295b1 !important;
      background-image: none !important;
      font-weight: bold;
      text-transform: capitalize;
      height: 45px;
      font-size: 16px;
      text-align: left;
    }

    .table-row {
      display: table-row;
      width: auto;
      clear: both;
    }

    .table-cell {
      display: table-cell;
      width: 475px;
      font-size: 12px;
      background-color: transparent;
      color: black;
      height: 25px;
      line-height: 25px;
      padding: 1px;
    }

    .imgMap-table-cell {
      width: 10% !important;
      vertical-align: middle;
    }

    .panel-default {
      min-width: 100%;
    }

    #footer {
      position: fixed;
      bottom: 0;
    }

    .row-style {
      bottom: 5px;
      position: fixed;
      top: 55px;
      overflow: auto;
      width: 100%;
    }

    .modal-dialog {
      top: 100px;
      margin-left: 50% !important;
    }

    .required-field {
      /* border: 1px solid red; */
      /* border-radius: 5px; */
      padding: 5px;
      font-size: 16px;
      color: red;
      /* width: 120px; */
      display: inline-block;
      font-weight: bold;
    }

    .xml-only-msg {
      border: 1px solid red;
      border-radius: 5px;
      padding: 5px;
      font-size: 12px;
      color: white;
      width: 223px;
      display: inline-block;
      font-weight: bold;
    }

    @media (min-width: 400px) and (max-width: 1024px) {
      .xml-only-msg {
        width: 120px;
      }
    }

    @media (max-width: 475px)  {
      .xml-only-msg {
        color: #000000
      }
    }
    .col-per-10 {
      border: 1px solid blue;
      padding: 15px 10px 15px 10px;
      border-radius: 10px;
      height: auto;
      width: 10%;
      float: left;
      position: fixed;
      min-height: 1px;
    }

    .btn-group>.btn:first-child {
      margin-left: 0;
      width: 165px;
      margin-top: 10px;
    }

    .col-md-10 {
      left: 200px;
    }

    .module-header {
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
      margin-left: -135px;
      margin-top: -15px;
      font-size: 14px;
      font-weight: bold;
      color: #363636;
    }

    .btn-group-justified {
      padding-left: 15px;
    }

    select {
      height: 35px;
      border-radius: 5px;
      max-width: 280px;
      width: 100%;
    }

    .findings select{
      max-width: 150px;
      margin-top: -3px;
    }
    .fixed-keydiagram {
      position: fixed !important;
      float: right;
      padding-right: 0px !important;
      margin-right: 10px;
      padding-left: 25px !important;
    }

    .center-align {
      text-align: center;
      width: 160px !important;
      padding: 0px !important;
    }

    .center-align div {
      width: 200px;
      margin-left: -10px;
    }

    .findings div {
      color: #363636 !important;
      margin-left: 100px !important;
      margin-top: -23.5px !important;
      height: 30px;
    }

    .findings div select {
      text-transform: capitalize;
    }

    .modal-backdrop {
      top: 10000px !important;
    }

    .tooltip-arrow {
      display: none !important;
    }

    .other-reportSection {
      font-weight: normal;
      margin-top: -10px;
      margin-left: 15px;
    }

    a:hover {
      text-decoration: none !important;
    }

    .no-btm-margin-table {
      margin-bottom: 0px !important;
    }

    .adjust-diagram {
      margin-top: 56px;
      right: 20px !important;
    }

    .adjust-diagram-image {
      top: 0px !important;
      margin-top: 0px !important;
    }

    .reportText-panel {
      width: 90%;
      margin-left: 2%;
    }

    .reportText-body {
      margin-left: 2%;
    }

    .top-Index {
      z-index: 99999 !important;
    }


    /* Master Styles */

    h1 {
      color: #369;
      font-family: Arial, Helvetica, sans-serif;
      font-size: 250%;
    }

    h2,
    h3 {
      color: #444;
      font-family: Arial, Helvetica, sans-serif;
      font-weight: lighter;
    }

    .div-simulator-container {
      margin: 0;
    }


    /*Apply background color for div having checked radio button*/

    .div-simulator-container input[type="radio"]:checked+div {
      background-color: #1e89b5 !important;
      border: 1px solid #9b9b9b;
      color: #ffffff;
    }


    /*Apply background color for div having no checked radio button*/

    .div-simulator-container input[type="radio"]+div {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
    }

    .div-simulator-container .checkbox>label {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
      height: 25px;
      line-height: 25px;
    }

    .div-simulator-container .checkbox>label>input[type="checkbox"] {
      margin-left: -15px;
      margin-top: 6px;
    }

    .div-simulator-container .full-width span {
      font-weight: bold;
    }


    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;
        border: 1px solid #9B9B9B;
        }*/

    .div-simulator-container .DEElement {
      color: #363636;
      letter-spacing: -0.37px;
      word-wrap: break-word;
    }

    .div-simulator-container .DEValues {
      /*font-size: 12px;*/
      color: #4a4a4a;
      letter-spacing: -0.29px;
    }


    /* CHECKBOX OVERWRITE STYLES */

    .div-simulator-container .rad {
      cursor: pointer;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
      -webkit-user-select: none;
      -webkit-touch-callout: none;
    }

    .div-simulator-container .rad>input {
      /* HIDE ORG RADIO & CHECKBOX */
      visibility: hidden;
      position: absolute;
    }

    .div-simulator-container [type="radio"]+span::before {
      content: "";
      display: inline-block;
      width: 9px;
      height: 9px;
      border-radius: 1em;
      border: 0.1px solid #fff;
      -webkit-box-shadow: 0 0 0 1px #57aed0;
              box-shadow: 0 0 0 1px #57aed0;
      margin-right: 4px;
      -webkit-transition: 0.5s ease all;
      transition: 0.5s ease all;
      margin-left: -15px;
    }

    [type="radio"]:checked+span::before {
      background: #57aed0;
      -webkit-box-shadow: 0 0 0 2px #57aed0;
              box-shadow: 0 0 0 2px #57aed0;
      margin-top: auto;
      /*margin-left:-15px;*/
    }

    .div-simulator-container .reportText {
      font-size: 14px;
      color: #363636;
      letter-spacing: -0.49px;
    }

    .div-simulator-container button:hover,
    .div-simulator-container button:focus,
    .div-simulator-container button.active,
    .div-simulator-container .btn-default:hover,
    .btn-default:focus,
    .div-simulator-container .item.active,
    .div-simulator-container .btn-default.active {
      background: #1e89b5 !important;
      color: #ffffff !important;
    }

    .div-simulator-container .hideInput {
      visibility: hidden;
      margin-left: 5px !important;
    }

    .div-simulator-container .panel {
      background-color: transparent;
    }

    .logo {
      height: 30px;
      width: 250px;
    }

    .navbar-blue {
      background-color: #00205b !important;
      color: #fff;
    }

    .navbar-brand-text {
      font-size: 30px;
      color: #fff;
      font-weight: normal;
      margin-top: 10px;
    }

    .div-simulator-container .close {
      margin-top: -20px !important;
    }


    /*.full-width {
            width: 320px !important;
        }*/

    #myNav.affix {
      width: 483px;
      top: 100;
    }

    #Can-ImgMap {
      pointer-events: none;
      position: absolute;
      opacity: 0.5;
    }


    /* Styles for Assist bootstrap*/

    .div-simulator-container .control-label {
      text-align: left !important;
    }

    .div-simulator-container .box-style {
      text-decoration: none;
      color: #363636 !important;
      border-radius: 3px;
      padding: 5px;
      font-weight: bold !important;
      width: 75%;
    }

    .div-simulator-container .findings {
      color: #ffffff !important;
      background-color: #5295b1 !important;
      border-color: #5295b1 !important;
      background-image: none !important;
      font-weight: bold;
      text-transform: capitalize;
      height: 40px;
    }

    .div-simulator-container .table-row {
      display: table-row;
      width: auto;
      clear: both;
    }

    .div-simulator-container .table-cell {
      display: table-cell;
      width: 475px;
      font-size: 12px;
      background-color: transparent;
      color: black;
      height: 25px;
      line-height: 25px;
      padding: 1px;
      border-bottom: none;
    }

    .div-simulator-container .imgMap-table-cell {
      width: 10% !important;
      vertical-align: middle;
    }

    .div-simulator-container .panel-default {
      min-width: 600px;
      margin: 0 !important;
      background-color: white;
    }

    .div-simulator-container .footerBlock {
      position: fixed;
      bottom: 55px;
    }

    .div-simulator-container .row-style {
      bottom: 5px;
      position: fixed;
      top: 55px;
      overflow: auto;
      width: 100%;
    }

    .div-simulator-container .modal-dialog {
      top: 100px;
      /*margin-left: 50% !important;*/
      margin-left: 0 !important;
    }

    .div-simulator-container .required-field {
      border: 1px solid #edd1d1;
      border-radius: 5px;
      padding: 5px;
      font-size: 12px;
      color: #cd5c5c;
      width: 125px;
    }

    .div-simulator-container .col-per-10 {
      border: 1px solid blue;
      padding: 15px 10px 15px 10px;
      border-radius: 10px;
      height: auto;
      width: 10%;
      float: left;
      position: fixed;
      min-height: 1px;
    }

    .div-simulator-container .btn-group>.btn:first-child {
      margin-left: 0;
      width: 165px;
      margin-top: 10px;
    }

    .div-simulator-container .col-md-10 {
      left: 200px;
    }

    .div-simulator-container .module-header {
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
      margin-left: -135px;
      margin-top: -15px;
      font-size: 14px;
      font-weight: bold;
      color: #363636;
    }

    .div-simulator-container .btn-group-justified {
      padding-left: 15px;
    }

    .div-simulator-container select {
      height: 28px;
      border-radius: 5px;
    }

    .div-simulator-container .panel-body {
      padding: 10px !important;
    }

    .div-simulator-container .fixed-keydiagram {
      position: fixed !important;
      float: right;
      padding-right: 0px !important;
      margin-right: 10px;
      padding-left: 25px !important;
    }

    .div-simulator-container .center-align {
      text-align: center;
      width: 160px !important;
      padding: 0px !important;
    }

    .div-simulator-container .center-align div {
      width: 200px;
      margin-left: -10px;
    }

    .div-simulator-container .findings div {
      color: #363636 !important;
      margin-left: 97px !important;
      margin-top: -29.5px !important;
      height: 30px;
    }

    .div-simulator-container .findings div select {
      text-transform: capitalize;
    }

    .div-simulator-container .modal-backdrop {
      top: 10000px !important;
    }

    .div-simulator-container .tooltip-arrow {
      display: none !important;
    }

    .div-simulator-container .other-reportSection {
      font-weight: normal;
      margin-top: -10px;
      margin-left: 15px;
    }

    .div-simulator-container a:hover {
      text-decoration: none !important;
    }

    .div-simulator-container .no-btm-margin-table {
      margin-bottom: 0px !important;
    }

    .div-simulator-container .adjust-diagram {
      margin-top: 56px;
      right: 20px !important;
    }

    .adjust-diagram-image {
      top: 0px !important;
      margin-top: 0px !important;
    }

    @media only screen and (min-width: 1224px) {
      .tab-content {
        padding: 5px;
      }
    }

    @media (min-width: 768px) {
      #page-content-wrapper {
        padding: 0px 20px;
        margin-top: 15px;
      }
    }

    #sidebar-wrapper {
      left: 175px;
      margin-left: -175px;
    }

    #rowContent {
      padding-bottom: 120px;
    }

    @media only screen and (min-width: 1224px) {
      .fixed-reportText {
        width: 1064px;
      }
    }

    @media only screen and (min-width: 1824px) {
      .fixed-reportText {
        width: 1260px;
      }
    }

    @media only screen and (min-width: 1224px) {
      .modal-lg {
        left: 0;
        /* left: -250px; */
      }
    }

    .form-group {
      margin-bottom: 15px;
    }

    .control-label {
      margin-top: 0;
      margin-left: 0;
    }

    .div-simulator-container .checkbox>label {
      height: 30px;
      line-height: 30px;
    }

    .div-simulator-container .checkbox>label>input[type="checkbox"] {
      margin-top: 8px;
    }

    .div-simulator-container select {
      height: 30px;
      border-radius: 5px;
      font-size: 12px;
      width: 280px;
    }

    .div-simulator-container .input-group {
      width: 280px;
    }

    .div-simulator-container .input-group .form-control {
      border-radius: 5px;
      -webkit-box-shadow: none;
              box-shadow: none;
      border: 1px solid #969696;
    }

    .div-simulator-container .imgMap-table-cell {
      padding-left: 10px;
    }

    @media (min-width: 1224px) {
      .modal-lg {
        width: 630px;
      }
    }

    .tableImagemap {
      table-layout: fixed;
    }

    @media (min-width: 1850px) {
      .modal-lg {
        width: 900px;
      }
      .tableImagemap {
        table-layout: inherit;
      }
    }

    .col-centered {
      float: none;
      margin: 0 auto;
    }

    .checkbox {
      max-width: 280px;
    }

    [type="number"] {
      max-width: 280px;
      /*margin-left: -15px;*/
    }

    .input-group {
      width: 100%;
    }

    @media (min-width:1441px) {
      .DEValues {
        /*min-width: 280px;
        max-width: 280px;*/
        height: auto;
      }
    }

    @media (max-width:1024px) {
      .adjust-diagram-image {
        width: 50%;
      }
    }

    @media (min-width:1921px) {
      .adjust-diagram-image {
        width: 50%;
      }
    }

    .row {
      font-weight: bold;
    }

    .carousel-item.item img {
      width: 100% !important;
    }

    .carousel-indicators {
      display: none !important;
    }

    .display-inline {
      display: inline;
    }

    .font-weight-normal {
      font-weight: normal;
    }

    .font-weight-bold {
      font-weight: bold;
    }

    .color-white {
      color: #ffffff;
    }

    .bottom-margin{
      margin-bottom: 25px;
    }

    .reportText-content {
      white-space: pre-line; 
      font-weight: bold;
      margin: -40px 0px;
      height: -webkit-fit-content;
      height: -moz-fit-content;
      height: fit-content;
    }

    .no-bottom-margin {
      margin-bottom: 0px !important;
    }
    .reportText-main-content{
      font-size: 16px;
    }

    .split-length-word {
      word-break: break-all;
      text-align: left;
      margin: 0px 0px;
    }

    .img-max-width {
      width: 70% !important;
    }

    .keydiagram {
      text-align: center;
      margin-top: 10px;
    }

    .report-text-top-margin {
      margin-top: 15px;
    }

    input[type=number]::-webkit-inner-spin-button, 
    input[type=number]::-webkit-outer-spin-button { 
        -webkit-appearance: none;
        -moz-appearance: none;
        margin: 0; 
    }

    input[type="number"]:hover,
    input[type="number"]:focus,
    input[type="number"] {
        -moz-appearance: textfield;
    }

    .numeric-align {
      display: inline;
    }

    input[type="text"] {
    max-width: 280px;
    margin-left: 0px !important;
    border-radius: 5px !important;
    text-transform: capitalize;
    }

    .all-reporttext-heading {
      text-decoration: underline;
      font-weight: bold;
      text-transform: capitalize;
      font-size: 18px;
      margin-top: -50px;
      text-align: left;
    }

    .all-reportText-content {
      margin-top: -10px;
    }

    .split-length-word.all-reportText-content {
      text-align: justify;
      word-break: unset;
    }

    .fixed-report-text-sidebar {
      position: fixed;
      right: 0;
      width: 45%;
    }

    .fixed-report-text-footer {
      position: fixed;
      left: 15 !important;
      bottom: 0;
      background-color: white;
    }

    .left-margin {
      margin-left: 60px;
      width: 90%;
    }

    .overflow {
      /* max-height: 500px; */
      overflow-x: hidden;
    }

    @media (max-width: 650px) {
  

      .left-margin {
        margin-left: 20px;
      }

      .keydiagram {
        width: 100%;
        margin-left: 4%;
      } 
      .row.content-area {
        padding: 0px 5px;
      }

      .text-right.border-0 > h4 {
        padding-right: 20px;
      }

      .keydiagram {
        width: 100%;
        text-align: center;
        margin-left: 0px !important;
      }
    }
    @media (max-width: 1024px) {
      .keydiagram {
        width: 100%;
        margin-left: 9%;
      }
      .img-max-width {
        width: 80% !important;
      }
    }
    @media (max-width: 1023px) {
      .fixed-report-text-sidebar {
        position: relative;
      }
    }

    .upload-button-size {
    	font-size: 100% !important;
    }
  
  `]
            },] },
];
/**
 * @nocollapse
 */
AssistReportTextComponent.ctorParameters = () => [];
AssistReportTextComponent.propDecorators = {
    'reportText': [{ type: Input },],
};

const components = [AcrAssistSimulatorComponent, AssistDataElementComponent, HintDiagramComponent, SlideComponent, CarouselComponent,
    AssistNumericElementComponent, AssistChoiceElementComponent, AssistMultiChoiceElementComponent, ImageMapComponent, AssistReportTextComponent];
class AcrAssistSimulatorModule {
}
AcrAssistSimulatorModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule,
                    CoreModule,
                    FormsModule,
                    ReactiveFormsModule
                ],
                declarations: components,
                providers: [TemplateManagerService,
                    DiagramService,
                    CarouselConfig,
                    ArrayCheckerService,
                    ConditionsCreationService,
                    DecisionPointsCreationService,
                    ComputedValueCreationService,
                    SimulatorEngineService,
                    { provide: CreationServiceInjectorToken, useClass: ChoiceDataElementCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: MultipleChoiceDataElementCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: NumericDataElementCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: IntegerDataElementCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: GlobalValueCreationService, multi: true },
                    { provide: CreationServiceInjectorToken, useClass: ComputedDataElementCreationService, multi: true }
                ],
                exports: components
            },] },
];
/**
 * @nocollapse
 */
AcrAssistSimulatorModule.ctorParameters = () => [];

class Dictionary {
    constructor() {
        this.items = {};
        this.count = 0;
    }
    /**
     * @param {?} key
     * @return {?}
     */
    ContainsKey(key) {
        return this.items.hasOwnProperty(key);
    }
    /**
     * @return {?}
     */
    Count() {
        return this.count;
    }
    /**
     * @param {?} key
     * @param {?} value
     * @return {?}
     */
    Add(key, value) {
        if (!this.items.hasOwnProperty(key)) {
            this.count++;
        }
        this.items[key] = value;
    }
    /**
     * @param {?} key
     * @return {?}
     */
    Remove(key) {
        const /** @type {?} */ val = this.items[key];
        delete this.items[key];
        this.count--;
        return val;
    }
    /**
     * @param {?} key
     * @return {?}
     */
    Item(key) {
        return this.items[key];
    }
    /**
     * @return {?}
     */
    Keys() {
        const /** @type {?} */ keySet = [];
        for (const /** @type {?} */ prop in this.items) {
            if (this.items.hasOwnProperty(prop)) {
                keySet.push(prop);
            }
        }
        return keySet;
    }
    /**
     * @return {?}
     */
    Values() {
        const /** @type {?} */ values = [];
        for (const /** @type {?} */ prop in this.items) {
            if (this.items.hasOwnProperty(prop)) {
                values.push(this.items[prop]);
            }
        }
        return values;
    }
}

class GlobalsService {
    /**
     * @param {?} http
     */
    constructor(http$$1) {
        this.http = http$$1;
        this.defaultModule = 'assets/XMLFIles/Hello_RADS/Hello_RADS.xml';
        this.XMLList = new Dictionary();
    }
    /**
     * @return {?}
     */
    getDefaultModulePath() {
        return this.http.get(this.defaultModule).map(res => res.text());
    }
}
GlobalsService.decorators = [
    { type: Injectable },
];
/**
 * @nocollapse
 */
GlobalsService.ctorParameters = () => [
    { type: Http, },
];

const $$5 = require('jquery');
class ViewUploadLoaderComponent {
    /**
     * @param {?} globalsService
     */
    constructor(globalsService) {
        this.onFileSelected = new EventEmitter();
        this.globalsService = globalsService;
    }
    /**
     * @param {?} fileDetails
     * @return {?}
     */
    onFileContentRead(fileDetails) {
        this.selectedXML = fileDetails;
        if (this.globalsService.XMLList.ContainsKey(fileDetails.fileLabel)) {
            this.globalsService.XMLList.Remove(fileDetails.fileLabel);
        }
        this.globalsService.XMLList.Add(fileDetails.fileLabel, fileDetails);
        this.onFileSelected.emit(fileDetails);
    }
    /**
     * @param {?} fileDetails
     * @return {?}
     */
    onFileClick(fileDetails) {
        this.selectedXML = fileDetails;
        this.onFileSelected.emit(fileDetails);
        $$5('#xmlOnlyMsg').hide();
    }
}
ViewUploadLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-view-upload-loader',
                template: `

      <ul class="nav nav-sidebar">
        <li class="header">Want to try your assist module?</li>
    
        <li class="fileUploader">
          <acr-file-upload-loader (onFileContentRead)="onFileContentRead($event)"></acr-file-upload-loader>
        </li>
      </ul>
      <ul class="nav nav-sidebar">
        <li [ngClass]="{'active':(selectedXML != 'undefined' && selectedXML.fileLabel == file.fileLabel)}" *ngFor="let file of globalsService.XMLList.Values().reverse()">
            <a href="#" (click)="onFileClick(file)">{{file.fileLabel}}</a>
    
        </li>

      </ul>
  `,
                styles: [`

    /* Sidebar navigation */

    .nav-sidebar {
      background-color: #2e3752;
    }

    .nav-sidebar>li>a {
      padding: 0px !important;
      color: white;
      border-left: 3px solid transparent;
      border-bottom: 1px solid #464850;
      margin-top: 5px; 
    }

    .nav-sidebar>.active>a {
      border-left-color: white ;
    }

    .nav-sidebar>.active>a,
    .nav-sidebar>.active>a:hover,
    .nav-sidebar>.active>a:focus,
    .nav-sidebar>li>a:hover {
      color: #fff;
      background-color: #1e282c;
      font-weight: bold;
    }
    .nav-sidebar>li.fileUploader {
      text-align: center;
      padding: 10px 25px 1px 15px;
      font-size: 12px;
      top: 7px;
    }
    .nav-sidebar>li.header {
      color:white;
      background: #5c5d5f;
      padding: 0px 33px 0px 11px;
      font-size: 13px;
    }

    .nav-sidebar>li.header.module-header {
      font-size: 16px;
        font-weight: bold;
        text-align: center;
    }

    .col-centered {
      float: none;
      margin: 0 auto;
    }

    .cursor {
      cursor: pointer;
    }

    .navbar-fixed-top {
      border: 0;
    }
    @media (min-width: 768px) {
      .sidebar {
        position: fixed;
        top: 51px;
        bottom: 0;
        left: 0;
        z-index: 1000;
        display: block;
        padding: 20px;
        overflow-x: hidden;
        overflow-y: auto;
        /* Scrollable contents if viewport is shorter than content. */
        background-color: #2e3752;
        border-right: 1px solid #eee;
      }
    }



    .navbar-blue {
      background-color: #2e3752;
    }

    .navbar-blue .navbar-brand {
      color: #fff;
    }


    /*
     * Main content
     */

    .main {
      padding: 0px;
    }

    @media (min-width: 768px) {
      .main {
        padding-right: 40px;
        padding-left: 40px;
      }
    }

    .main .page-header {
      margin-top: 0;
    }
  `]
            },] },
];
/**
 * @nocollapse
 */
ViewUploadLoaderComponent.ctorParameters = () => [
    { type: GlobalsService, },
];
ViewUploadLoaderComponent.propDecorators = {
    'onFileSelected': [{ type: Output },],
};

class FileDetails {
    /**
     * @param {?} fileLabel
     * @param {?} fileName
     * @param {?} fileContents
     */
    constructor(fileLabel, fileName, fileContents) {
        this.fileLabel = fileLabel;
        this.fileName = fileName;
        this.fileContents = fileContents;
    }
}

const $$6 = require('jquery');
class FileUploadLoaderComponent {
    /**
     * @param {?} configService
     */
    constructor(configService) {
        this.configService = configService;
        this.onFileContentRead = new EventEmitter();
        this.fileReader = new FileReader();
    }
    /**
     * @return {?}
     */
    ngOnInit() {
        this.hideMessage();
        this.showDefaultModule();
    }
    /**
     * @param {?} $event
     * @return {?}
     */
    changeListener($event) {
        let /** @type {?} */ fileName;
        fileName = $event.target.value;
        if (fileName.includes('.xml') || fileName.includes('.Xml') || fileName.includes('.XML') ||
            fileName.includes('.zip') || fileName.includes('.Zip') || fileName.includes('.ZIP')) {
            this.hideMessage();
            this.readThis($event.target);
        }
        else {
            if (fileName !== '' && fileName !== undefined) {
                $$6('#xmlOnlyMsg').show();
            }
        }
    }
    /**
     * @return {?}
     */
    hideMessage() {
        $$6('#xmlOnlyMsg').hide();
    }
    /**
     * @param {?} inputValue
     * @return {?}
     */
    readThis(inputValue) {
        this.readFile = inputValue.files[0];
        const /** @type {?} */ self = this;
        const /** @type {?} */ extensionStartPosition = self.readFile.name.lastIndexOf('.');
        this.fileReader.onloadend = (e) => {
            self.onFileContentRead.emit(new FileDetails(self.readFile.name.substring(0, extensionStartPosition), self.readFile.name, this.fileReader.result));
        };
        this.fileReader.readAsText(this.readFile);
    }
    /**
     * @return {?}
     */
    showDefaultModule() {
        this.configService.getDefaultModulePath()
            .subscribe(data => {
            const /** @type {?} */ self = this;
            self.onFileContentRead.emit(new FileDetails('Hello RADS', 'Hello_RADS.xml', data));
        });
    }
}
FileUploadLoaderComponent.decorators = [
    { type: Component, args: [{
                selector: 'acr-file-upload-loader',
                template: `
    <!-- <div class = "row">
      <div class= "col-sm-12">
          <div class="panel panel-default">
              <div class="panel-heading"><strong>Select  the Template file</strong></div>
              <div class="panel-body">
                  <div class="row">
                        <div class="col-sm-12 col-md-4 col-xs-12"> Select the file to be uploaded</div>
                        <div class="col-sm-12 col-md-8 col-xs-12"><input type="file" accept=".xml" (change)="changeListener($event)"></div>
                  </div>
              </div>
            </div>
      </div>
    </div> -->

    <input id="xmlFileUpload" class="inputfile" type="file" accept=".xml" (change)="changeListener($event)" (click)="hideMessage()">
    <label for="xmlFileUpload" class="upload-button-size" title="Choose a Module">Choose a Module</label><br>
    <div id="xmlOnlyMsg" class="xml-only-msg"> Only XML files are supported !!!</div>
  `,
                styles: [`
    input[type=file].inputfile {
      width: 0.1px;
      height: 0.1px;
      opacity: 0;
      overflow: hidden;
      position: absolute;
      z-index: -1;
      margin: 0;
    }

    input[type=file].inputfile+label:active,
    input[type=file].inputfile+label {
      max-width: 100%;
      font-size: 1.5rem;
      font-weight: 700;
      text-overflow: ellipsis;
      white-space: nowrap;
      cursor: pointer;
      display: inline-block;
      overflow: hidden;
      display: inline-block;
      color: #f1e5e6;
      background-color: #d3394c;
      text-indent: 0px;
      width: 130px;
    }

    input[type=file].inputfile+label:hover {
      background-color: #722040;
    }

    input[type=file].inputfile+label {
      cursor: pointer;
      /* "hand" cursor */
    }

    input[type=file].inputfile:hover+label {
      outline: 1px dotted #000;
      outline: -webkit-focus-ring-color auto 5px;
    }

    .right-fixed {
      position: fixed;
      right: 0px;
    }

    .row.report-text-top-margin.right-align{
      width: 80%;
      margin-left: 135px;
    }

    /* Master Styles */

    h1 {
      color: #369;
      font-family: Arial, Helvetica, sans-serif;
      font-size: 250%;
    }

    h2,
    h3 {
      color: #444;
      font-family: Arial, Helvetica, sans-serif;
      font-weight: lighter;
    }

    body {
      margin: 2em;
    }


    /*Apply background color for div having checked radio button*/

    input[type="radio"]:checked+div {
      background-color: #1e89b5 !important;
      border: 1px solid #9b9b9b;
      color: #ffffff;
    }


    /*Apply background color for div having no checked radio button*/

    input[type="radio"]+div {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
    }

    .checkbox>label {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
      height: auto;
      line-height: 25px;
      width: 100%;
      font-weight: bold;
    }

    .checkbox>label>input[type="checkbox"] {
      margin-left: -15px;
      margin-top: 6px;
    }

    .full-width span {
      font-weight: bold;
    }


    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;
        border: 1px solid #9B9B9B;
        }*/

    .DEElement {
      color: #363636;
      letter-spacing: -0.37px;
      word-wrap: break-word;
    }

    .DEValues {
      /*font-size: 12px;*/
      color: #4a4a4a;
      letter-spacing: -0.29px;
      width: 100%;
      min-width: 180px;
      max-width: 280px;
    }


    /* CHECKBOX OVERWRITE STYLES */

    .rad {
      cursor: pointer;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
      -webkit-user-select: none;
      -webkit-touch-callout: none;
    }

    .rad>input {
      /* HIDE ORG RADIO & CHECKBOX */
      visibility: hidden;
      position: absolute;
    }

    [type="radio"]+span::before {
      content: "";
      display: inline-block;
      width: 9px;
      height: 9px;
      border-radius: 1em;
      border: 0.1px solid #fff;
      -webkit-box-shadow: 0 0 0 1px #57aed0;
              box-shadow: 0 0 0 1px #57aed0;
      margin-right: 4px;
      -webkit-transition: 0.5s ease all;
      transition: 0.5s ease all;
      margin-left: -15px;
    }

    [type="radio"]:checked+span::before {
      background: #57aed0;
      -webkit-box-shadow: 0 0 0 2px #57aed0;
              box-shadow: 0 0 0 2px #57aed0;
      margin-top: auto;
      /*margin-left:-15px;*/
    }

    .reportText {
      font-size: 14px;
      color: #363636;
      letter-spacing: -0.49px;
      margin-top: 5px;
    }

    button:hover,
    button:focus,
    button.active,
    .btn-default:hover,
    .btn-default:focus,
    .item.active,
    .btn-default.active {
      background: #1e89b5 !important;
      color: #ffffff !important;
    }

    .hideInput {
      visibility: hidden;
      margin-left: 5px !important;
    }

    .panel {
      background-color: transparent;
    }

    .logo {
      height: 30px;
      width: 250px;
    }

    .navbar-blue {
      background-color: #00205b !important;
      color: #fff;
    }

    .navbar-brand-text {
      font-size: 30px;
      color: #fff;
      font-weight: normal;
      margin-top: 10px;
    }

    .close {
      margin-top: -20px !important;
    }


    /*.full-width {
            width: 320px !important;
        }*/

    #myNav.affix {
      width: 483px;
      top: 100;
    }

    #Can-ImgMap {
      pointer-events: none;
      position: absolute;
      opacity: 0.5;
    }


    /* Styles for Assist bootstrap*/

    .control-label {
      text-align: left !important;
    }

    .box-style {
      text-decoration: none;
      color: #363636 !important;
      border-radius: 3px;
      padding: 5px;
      font-weight: bold !important;
      width: 75%;
    }

    .findings {
      color: #ffffff !important;
      background-color: #5295b1 !important;
      border-color: #5295b1 !important;
      background-image: none !important;
      font-weight: bold;
      text-transform: capitalize;
      height: 45px;
      font-size: 16px;
      text-align: left;
    }

    .table-row {
      display: table-row;
      width: auto;
      clear: both;
    }

    .table-cell {
      display: table-cell;
      width: 475px;
      font-size: 12px;
      background-color: transparent;
      color: black;
      height: 25px;
      line-height: 25px;
      padding: 1px;
    }

    .imgMap-table-cell {
      width: 10% !important;
      vertical-align: middle;
    }

    .panel-default {
      min-width: 100%;
    }

    #footer {
      position: fixed;
      bottom: 0;
    }

    .row-style {
      bottom: 5px;
      position: fixed;
      top: 55px;
      overflow: auto;
      width: 100%;
    }

    .modal-dialog {
      top: 100px;
      margin-left: 50% !important;
    }

    .required-field {
      /* border: 1px solid red; */
      /* border-radius: 5px; */
      padding: 5px;
      font-size: 16px;
      color: red;
      /* width: 120px; */
      display: inline-block;
      font-weight: bold;
    }

    .xml-only-msg {
      border: 1px solid red;
      border-radius: 5px;
      padding: 5px;
      font-size: 12px;
      color: white;
      width: 223px;
      display: inline-block;
      font-weight: bold;
    }

    @media (min-width: 400px) and (max-width: 1024px) {
      .xml-only-msg {
        width: 120px;
      }
    }

    @media (max-width: 475px)  {
      .xml-only-msg {
        color: #000000
      }
    }
    .col-per-10 {
      border: 1px solid blue;
      padding: 15px 10px 15px 10px;
      border-radius: 10px;
      height: auto;
      width: 10%;
      float: left;
      position: fixed;
      min-height: 1px;
    }

    .btn-group>.btn:first-child {
      margin-left: 0;
      width: 165px;
      margin-top: 10px;
    }

    .col-md-10 {
      left: 200px;
    }

    .module-header {
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
      margin-left: -135px;
      margin-top: -15px;
      font-size: 14px;
      font-weight: bold;
      color: #363636;
    }

    .btn-group-justified {
      padding-left: 15px;
    }

    select {
      height: 35px;
      border-radius: 5px;
      max-width: 280px;
      width: 100%;
    }

    .findings select{
      max-width: 150px;
      margin-top: -3px;
    }
    .fixed-keydiagram {
      position: fixed !important;
      float: right;
      padding-right: 0px !important;
      margin-right: 10px;
      padding-left: 25px !important;
    }

    .center-align {
      text-align: center;
      width: 160px !important;
      padding: 0px !important;
    }

    .center-align div {
      width: 200px;
      margin-left: -10px;
    }

    .findings div {
      color: #363636 !important;
      margin-left: 100px !important;
      margin-top: -23.5px !important;
      height: 30px;
    }

    .findings div select {
      text-transform: capitalize;
    }

    .modal-backdrop {
      top: 10000px !important;
    }

    .tooltip-arrow {
      display: none !important;
    }

    .other-reportSection {
      font-weight: normal;
      margin-top: -10px;
      margin-left: 15px;
    }

    a:hover {
      text-decoration: none !important;
    }

    .no-btm-margin-table {
      margin-bottom: 0px !important;
    }

    .adjust-diagram {
      margin-top: 56px;
      right: 20px !important;
    }

    .adjust-diagram-image {
      top: 0px !important;
      margin-top: 0px !important;
    }

    .reportText-panel {
      width: 90%;
      margin-left: 2%;
    }

    .reportText-body {
      margin-left: 2%;
    }

    .top-Index {
      z-index: 99999 !important;
    }


    /* Master Styles */

    h1 {
      color: #369;
      font-family: Arial, Helvetica, sans-serif;
      font-size: 250%;
    }

    h2,
    h3 {
      color: #444;
      font-family: Arial, Helvetica, sans-serif;
      font-weight: lighter;
    }

    .div-simulator-container {
      margin: 0;
    }


    /*Apply background color for div having checked radio button*/

    .div-simulator-container input[type="radio"]:checked+div {
      background-color: #1e89b5 !important;
      border: 1px solid #9b9b9b;
      color: #ffffff;
    }


    /*Apply background color for div having no checked radio button*/

    .div-simulator-container input[type="radio"]+div {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
    }

    .div-simulator-container .checkbox>label {
      background-color: #f5f5f5 !important;
      border: 1px solid #9b9b9b;
      border-radius: 5px;
      height: 25px;
      line-height: 25px;
    }

    .div-simulator-container .checkbox>label>input[type="checkbox"] {
      margin-left: -15px;
      margin-top: 6px;
    }

    .div-simulator-container .full-width span {
      font-weight: bold;
    }


    /*.checkbox > label > input[type=checkbox]:checked + span {background-color: #FAAF3A !important;
        border: 1px solid #9B9B9B;
        }*/

    .div-simulator-container .DEElement {
      color: #363636;
      letter-spacing: -0.37px;
      word-wrap: break-word;
    }

    .div-simulator-container .DEValues {
      /*font-size: 12px;*/
      color: #4a4a4a;
      letter-spacing: -0.29px;
    }


    /* CHECKBOX OVERWRITE STYLES */

    .div-simulator-container .rad {
      cursor: pointer;
      -moz-user-select: none;
       -ms-user-select: none;
           user-select: none;
      -webkit-user-select: none;
      -webkit-touch-callout: none;
    }

    .div-simulator-container .rad>input {
      /* HIDE ORG RADIO & CHECKBOX */
      visibility: hidden;
      position: absolute;
    }

    .div-simulator-container [type="radio"]+span::before {
      content: "";
      display: inline-block;
      width: 9px;
      height: 9px;
      border-radius: 1em;
      border: 0.1px solid #fff;
      -webkit-box-shadow: 0 0 0 1px #57aed0;
              box-shadow: 0 0 0 1px #57aed0;
      margin-right: 4px;
      -webkit-transition: 0.5s ease all;
      transition: 0.5s ease all;
      margin-left: -15px;
    }

    [type="radio"]:checked+span::before {
      background: #57aed0;
      -webkit-box-shadow: 0 0 0 2px #57aed0;
              box-shadow: 0 0 0 2px #57aed0;
      margin-top: auto;
      /*margin-left:-15px;*/
    }

    .div-simulator-container .reportText {
      font-size: 14px;
      color: #363636;
      letter-spacing: -0.49px;
    }

    .div-simulator-container button:hover,
    .div-simulator-container button:focus,
    .div-simulator-container button.active,
    .div-simulator-container .btn-default:hover,
    .btn-default:focus,
    .div-simulator-container .item.active,
    .div-simulator-container .btn-default.active {
      background: #1e89b5 !important;
      color: #ffffff !important;
    }

    .div-simulator-container .hideInput {
      visibility: hidden;
      margin-left: 5px !important;
    }

    .div-simulator-container .panel {
      background-color: transparent;
    }

    .logo {
      height: 30px;
      width: 250px;
    }

    .navbar-blue {
      background-color: #00205b !important;
      color: #fff;
    }

    .navbar-brand-text {
      font-size: 30px;
      color: #fff;
      font-weight: normal;
      margin-top: 10px;
    }

    .div-simulator-container .close {
      margin-top: -20px !important;
    }


    /*.full-width {
            width: 320px !important;
        }*/

    #myNav.affix {
      width: 483px;
      top: 100;
    }

    #Can-ImgMap {
      pointer-events: none;
      position: absolute;
      opacity: 0.5;
    }


    /* Styles for Assist bootstrap*/

    .div-simulator-container .control-label {
      text-align: left !important;
    }

    .div-simulator-container .box-style {
      text-decoration: none;
      color: #363636 !important;
      border-radius: 3px;
      padding: 5px;
      font-weight: bold !important;
      width: 75%;
    }

    .div-simulator-container .findings {
      color: #ffffff !important;
      background-color: #5295b1 !important;
      border-color: #5295b1 !important;
      background-image: none !important;
      font-weight: bold;
      text-transform: capitalize;
      height: 40px;
    }

    .div-simulator-container .table-row {
      display: table-row;
      width: auto;
      clear: both;
    }

    .div-simulator-container .table-cell {
      display: table-cell;
      width: 475px;
      font-size: 12px;
      background-color: transparent;
      color: black;
      height: 25px;
      line-height: 25px;
      padding: 1px;
      border-bottom: none;
    }

    .div-simulator-container .imgMap-table-cell {
      width: 10% !important;
      vertical-align: middle;
    }

    .div-simulator-container .panel-default {
      min-width: 600px;
      margin: 0 !important;
      background-color: white;
    }

    .div-simulator-container .footerBlock {
      position: fixed;
      bottom: 55px;
    }

    .div-simulator-container .row-style {
      bottom: 5px;
      position: fixed;
      top: 55px;
      overflow: auto;
      width: 100%;
    }

    .div-simulator-container .modal-dialog {
      top: 100px;
      /*margin-left: 50% !important;*/
      margin-left: 0 !important;
    }

    .div-simulator-container .required-field {
      border: 1px solid #edd1d1;
      border-radius: 5px;
      padding: 5px;
      font-size: 12px;
      color: #cd5c5c;
      width: 125px;
    }

    .div-simulator-container .col-per-10 {
      border: 1px solid blue;
      padding: 15px 10px 15px 10px;
      border-radius: 10px;
      height: auto;
      width: 10%;
      float: left;
      position: fixed;
      min-height: 1px;
    }

    .div-simulator-container .btn-group>.btn:first-child {
      margin-left: 0;
      width: 165px;
      margin-top: 10px;
    }

    .div-simulator-container .col-md-10 {
      left: 200px;
    }

    .div-simulator-container .module-header {
      font-family: "Helvetica Neue", Helvetica, Arial, sans-serif !important;
      margin-left: -135px;
      margin-top: -15px;
      font-size: 14px;
      font-weight: bold;
      color: #363636;
    }

    .div-simulator-container .btn-group-justified {
      padding-left: 15px;
    }

    .div-simulator-container select {
      height: 28px;
      border-radius: 5px;
    }

    .div-simulator-container .panel-body {
      padding: 10px !important;
    }

    .div-simulator-container .fixed-keydiagram {
      position: fixed !important;
      float: right;
      padding-right: 0px !important;
      margin-right: 10px;
      padding-left: 25px !important;
    }

    .div-simulator-container .center-align {
      text-align: center;
      width: 160px !important;
      padding: 0px !important;
    }

    .div-simulator-container .center-align div {
      width: 200px;
      margin-left: -10px;
    }

    .div-simulator-container .findings div {
      color: #363636 !important;
      margin-left: 97px !important;
      margin-top: -29.5px !important;
      height: 30px;
    }

    .div-simulator-container .findings div select {
      text-transform: capitalize;
    }

    .div-simulator-container .modal-backdrop {
      top: 10000px !important;
    }

    .div-simulator-container .tooltip-arrow {
      display: none !important;
    }

    .div-simulator-container .other-reportSection {
      font-weight: normal;
      margin-top: -10px;
      margin-left: 15px;
    }

    .div-simulator-container a:hover {
      text-decoration: none !important;
    }

    .div-simulator-container .no-btm-margin-table {
      margin-bottom: 0px !important;
    }

    .div-simulator-container .adjust-diagram {
      margin-top: 56px;
      right: 20px !important;
    }

    .adjust-diagram-image {
      top: 0px !important;
      margin-top: 0px !important;
    }

    @media only screen and (min-width: 1224px) {
      .tab-content {
        padding: 5px;
      }
    }

    @media (min-width: 768px) {
      #page-content-wrapper {
        padding: 0px 20px;
        margin-top: 15px;
      }
    }

    #sidebar-wrapper {
      left: 175px;
      margin-left: -175px;
    }

    #rowContent {
      padding-bottom: 120px;
    }

    @media only screen and (min-width: 1224px) {
      .fixed-reportText {
        width: 1064px;
      }
    }

    @media only screen and (min-width: 1824px) {
      .fixed-reportText {
        width: 1260px;
      }
    }

    @media only screen and (min-width: 1224px) {
      .modal-lg {
        left: 0;
        /* left: -250px; */
      }
    }

    .form-group {
      margin-bottom: 15px;
    }

    .control-label {
      margin-top: 0;
      margin-left: 0;
    }

    .div-simulator-container .checkbox>label {
      height: 30px;
      line-height: 30px;
    }

    .div-simulator-container .checkbox>label>input[type="checkbox"] {
      margin-top: 8px;
    }

    .div-simulator-container select {
      height: 30px;
      border-radius: 5px;
      font-size: 12px;
      width: 280px;
    }

    .div-simulator-container .input-group {
      width: 280px;
    }

    .div-simulator-container .input-group .form-control {
      border-radius: 5px;
      -webkit-box-shadow: none;
              box-shadow: none;
      border: 1px solid #969696;
    }

    .div-simulator-container .imgMap-table-cell {
      padding-left: 10px;
    }

    @media (min-width: 1224px) {
      .modal-lg {
        width: 630px;
      }
    }

    .tableImagemap {
      table-layout: fixed;
    }

    @media (min-width: 1850px) {
      .modal-lg {
        width: 900px;
      }
      .tableImagemap {
        table-layout: inherit;
      }
    }

    .col-centered {
      float: none;
      margin: 0 auto;
    }

    .checkbox {
      max-width: 280px;
    }

    [type="number"] {
      max-width: 280px;
      /*margin-left: -15px;*/
    }

    .input-group {
      width: 100%;
    }

    @media (min-width:1441px) {
      .DEValues {
        /*min-width: 280px;
        max-width: 280px;*/
        height: auto;
      }
    }

    @media (max-width:1024px) {
      .adjust-diagram-image {
        width: 50%;
      }
    }

    @media (min-width:1921px) {
      .adjust-diagram-image {
        width: 50%;
      }
    }

    .row {
      font-weight: bold;
    }

    .carousel-item.item img {
      width: 100% !important;
    }

    .carousel-indicators {
      display: none !important;
    }

    .display-inline {
      display: inline;
    }

    .font-weight-normal {
      font-weight: normal;
    }

    .font-weight-bold {
      font-weight: bold;
    }

    .color-white {
      color: #ffffff;
    }

    .bottom-margin{
      margin-bottom: 25px;
    }

    .reportText-content {
      white-space: pre-line; 
      font-weight: bold;
      margin: -40px 0px;
      height: -webkit-fit-content;
      height: -moz-fit-content;
      height: fit-content;
    }

    .no-bottom-margin {
      margin-bottom: 0px !important;
    }
    .reportText-main-content{
      font-size: 16px;
    }

    .split-length-word {
      word-break: break-all;
      text-align: left;
      margin: 0px 0px;
    }

    .img-max-width {
      width: 70% !important;
    }

    .keydiagram {
      text-align: center;
      margin-top: 10px;
    }

    .report-text-top-margin {
      margin-top: 15px;
    }

    input[type=number]::-webkit-inner-spin-button, 
    input[type=number]::-webkit-outer-spin-button { 
        -webkit-appearance: none;
        -moz-appearance: none;
        margin: 0; 
    }

    input[type="number"]:hover,
    input[type="number"]:focus,
    input[type="number"] {
        -moz-appearance: textfield;
    }

    .numeric-align {
      display: inline;
    }

    input[type="text"] {
    max-width: 280px;
    margin-left: 0px !important;
    border-radius: 5px !important;
    text-transform: capitalize;
    }

    .all-reporttext-heading {
      text-decoration: underline;
      font-weight: bold;
      text-transform: capitalize;
      font-size: 18px;
      margin-top: -50px;
      text-align: left;
    }

    .all-reportText-content {
      margin-top: -10px;
    }

    .split-length-word.all-reportText-content {
      text-align: justify;
      word-break: unset;
    }

    .fixed-report-text-sidebar {
      position: fixed;
      right: 0;
      width: 45%;
    }

    .fixed-report-text-footer {
      position: fixed;
      left: 15 !important;
      bottom: 0;
      background-color: white;
    }

    .left-margin {
      margin-left: 60px;
      width: 90%;
    }

    .overflow {
      /* max-height: 500px; */
      overflow-x: hidden;
    }

    @media (max-width: 650px) {
  

      .left-margin {
        margin-left: 20px;
      }

      .keydiagram {
        width: 100%;
        margin-left: 4%;
      } 
      .row.content-area {
        padding: 0px 5px;
      }

      .text-right.border-0 > h4 {
        padding-right: 20px;
      }

      .keydiagram {
        width: 100%;
        text-align: center;
        margin-left: 0px !important;
      }
    }
    @media (max-width: 1024px) {
      .keydiagram {
        width: 100%;
        margin-left: 9%;
      }
      .img-max-width {
        width: 80% !important;
      }
    }
    @media (max-width: 1023px) {
      .fixed-report-text-sidebar {
        position: relative;
      }
    }

    .upload-button-size {
    	font-size: 100% !important;
    }
  
  `]
            },] },
];
/**
 * @nocollapse
 */
FileUploadLoaderComponent.ctorParameters = () => [
    { type: GlobalsService, },
];
FileUploadLoaderComponent.propDecorators = {
    'onFileContentRead': [{ type: Output },],
};

const components$1 = [FileUploadLoaderComponent, ViewUploadLoaderComponent];
class SimulatorLoaderModule {
}
SimulatorLoaderModule.decorators = [
    { type: NgModule, args: [{
                imports: [
                    CommonModule
                ],
                declarations: [components$1],
                providers: [GlobalsService],
                exports: [components$1]
            },] },
];
/**
 * @nocollapse
 */
SimulatorLoaderModule.ctorParameters = () => [];

/**
 * Generated bundle index. Do not edit.
 */

export { AcrAssistSimulatorModule, SimulatorLoaderModule, AcrAssistSimulatorComponent as ɵc, AssistChoiceElementComponent as ɵo, AssistDataElementComponent as ɵl, AssistMultiChoiceElementComponent as ɵp, AssistNumericElementComponent as ɵn, HintDiagramComponent as ɵm, ImageMapComponent as ɵq, AssistReportTextComponent as ɵr, CreationServiceInjectorToken as ɵe, ArrayCheckerService as ɵg, ChoiceDataElementCreationService as ɵs, ComputedDataElementCreationService as ɵx, ComputedValueCreationService as ɵk, ConditionsCreationService as ɵj, DataElementCreationBaseService as ɵh, DecisionPointsCreationService as ɵi, DiagramService as ɵf, GlobalValueCreationService as ɵw, IntegerDataElementCreationService as ɵv, MultipleChoiceDataElementCreationService as ɵt, NumericDataElementCreationService as ɵu, TemplateManagerService as ɵd, CoreModule as ɵa, SimulatorEngineService as ɵb, FileUploadLoaderComponent as ɵy, GlobalsService as ɵz, ViewUploadLoaderComponent as ɵba };
//# sourceMappingURL=acr-assist-simulator-test.js.map
